<?php

namespace Mobicommerce\GeoFencing\Controller\Adminhtml\Index;

use Magento\Backend\App\Action;
use Magento\Framework\View\Result\PageFactory;
use Magento\Store\Model\WebsiteFactory;

class Edit extends Action
{
    public const ADMIN_RESOURCE = 'Mobicommerce_GeoFencing::configure';

    /**
     * @var bool|PageFactory
     */
    protected $resultPageFactory = false;

    /**
     * @var WebsiteFactory
     */
    private WebsiteFactory $websiteFactory;

    /**
     * Constructor
     *
     * @param Action\Context $context
     * @param PageFactory $resultPageFactory
     * @param WebsiteFactory $websiteFactory
     * @param Registry $registry
     */
    public function __construct(
        Action\Context $context,
        PageFactory $resultPageFactory,
        WebsiteFactory $websiteFactory
    ) {
        parent::__construct($context);
        $this->resultPageFactory = $resultPageFactory;
        $this->websiteFactory = $websiteFactory;
    }

    /**
     * @inheirtDoc
     */
    public function execute()
    {
        $id = $this->getRequest()->getParam('website_id');

        $modal = $this->websiteFactory->create();

        if ($id) {
            $modal->load($id);
            if (!$modal->getId()) {
                $this->messageManager->addErrorMessage(__('This item no longer exists.'));
                $resultRedirect = $this->resultRedirectFactory->create();
                return $resultRedirect->setPath('*/*/');
            }
        } else {
            $resultRedirect = $this->resultRedirectFactory->create();
            return $resultRedirect->setPath('*/*/');
        }

        $resultPage = $this->resultPageFactory->create();
        $resultPage->setActiveMenu('Mobicommerce_GeoFencing::configure');
        $resultPage->getConfig()->getTitle()->prepend($modal->getName() ?? __('Configure GEO Fencing'));

        return $resultPage;
    }
}
