<?php

namespace Mobicommerce\GeoFencing\Controller\Adminhtml\Index;

use Magento\Backend\App\Action;
use Magento\Backend\App\Action\Context;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\App\Action\HttpPostActionInterface as HttpPostActionInterface;
use Magento\Store\Model\WebsiteFactory;
use Mobicommerce\GeoFencing\Model\Mapping;

class Save extends Action implements HttpPostActionInterface
{
    public const ADMIN_RESOURCE = 'Mobicommerce_GeoFencing::configure';

    /**
     * @var WebsiteFactory
     */
    private WebsiteFactory $websiteFactory;

    /**
     * @var MappingFactory
     */
    private MappingFactory $mappingFactory;

    /**
     * Constructor
     *
     * @param Context $context
     * @param WebsiteFactory $websiteFactory
     * @param Mapping $mapping
     */
    public function __construct(
        Action\Context $context,
        WebsiteFactory $websiteFactory,
        Mapping $mapping
    ) {
        parent::__construct($context);
        $this->websiteFactory = $websiteFactory;
        $this->mapping = $mapping;
    }

    /**
     * @inheirtDoc
     */
    public function execute()
    {
        $resultRedirect = $this->resultRedirectFactory->create();

        $data = $this->getRequest()->getPostValue();
        if ($data) {
            $model = $this->websiteFactory->create();

            $websiteId = $this->getRequest()->getParam('website_id');

            try {
                $model->load($websiteId);
            } catch (LocalizedException $e) {
                $this->messageManager->addErrorMessage(__('This item no longer exists.'));
                return $resultRedirect->setPath('*/*/');
            }

            try {
                $locations = $data['locations'] ?? [];
                $this->mapping->saveLocations($websiteId, $locations);

                $this->messageManager->addSuccessMessage(__('You saved the Item.'));

                if ($this->getRequest()->getParam('back')) {
                    return $resultRedirect->setPath('*/*/edit', [
                        'website_id' => $model->getId(),
                        '_current' => true
                    ]);
                }
            } catch (\Exception $e) {
                $this->messageManager->addErrorMessage(__($e->getMessage()));

                return $resultRedirect->setPath('*/*/edit', [
                    'website_id' => $this->getRequest()->getParam('website_id')
                ]);
            }
        }

        return $resultRedirect->setPath('*/*/');
    }
}
