<?php

namespace Mobicommerce\GeoFencing\Model;

use Magento\Framework\DataObject\IdentityInterface;
use Magento\Framework\Model\AbstractModel;

class Mapping extends AbstractModel implements IdentityInterface
{
    public const CACHE_TAG = 'mc_gf_mapping';

    /**
     * @var string
     */
    protected $_cacheTag = self::CACHE_TAG;

    /**
     * @var string
     */
    protected $_eventPrefix = self::CACHE_TAG;

    /**
     * Initialize resource model
     *
     * @return void
     */
    protected function _construct()
    {
        $this->_init(
            \Mobicommerce\GeoFencing\Model\ResourceModel\Mapping::class
        );
    }

    /**
     * Get identities
     *
     * @return array
     */
    public function getIdentities()
    {
        return [self::CACHE_TAG . '_' . $this->getId()];
    }

    public function saveLocations($websiteId, $locations)
    {
        $connection = $this->_getResource()->getConnection();
        $table = $this->_getResource()->getTable("mc_gf_mapping");

        if ($locations) {
            $locationIdsToKeep = [];
            foreach ($locations as $location) {
                $rowData = $location;
                $rowData['website_id'] = $websiteId;
                $rowData['latitude'] = $rowData['position']['latitude'];
                $rowData['longitude'] = $rowData['position']['longitude'];

                foreach ([
                    'location_search',
                    'initialize',
                    'record_id',
                    'position'
                 ] as $key) {
                    unset($rowData[$key]);
                }

                $locationId = $location['id'] ?? null;
                if ($locationId) {
                    $connection->update(
                        $table,
                        $rowData,
                        ['id = ?' => $locationId]
                    );
                } else {
                    $connection->insert(
                        $table,
                        $rowData
                    );
                    $locationId = $connection->lastInsertId($table);
                }

                $locationIdsToKeep[] = $locationId;
            }

            $connection->delete($table, [
                'website_id = ?' => $websiteId,
                'id NOT IN (?)' => $locationIdsToKeep
            ]);
        } else {
            $connection->delete($table, [
                'website_id = ?' => $websiteId
            ]);
        }
    }

    public function getLocations($websiteId)
    {
        $data = [];

        $connection = $this->_getResource()->getConnection();
        $table = $this->_getResource()->getTable("mc_gf_mapping");
        $select = $connection->select()
            ->from(
                ['main_table' => $table]
            )->where('website_id = ?', $websiteId)
            ->order('id ASC');

        $result = $connection->fetchAll($select);

        if ($result) {
            foreach ($result as $item) {
                $item['position']['latitude'] = $item['latitude'];
                $item['position']['longitude'] = $item['longitude'];

                $data[] = $item;
            }
        }

        return $data;
    }
}
