<?php
/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */
declare(strict_types=1);

namespace Mobicommerce\GeoFencing\Model\Resolver;

use Magento\Customer\Model\Customer;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\GraphQl\Schema\Type\ResolveInfo;
use Magento\Framework\GraphQl\Config\Element\Field;
use Magento\Framework\GraphQl\Query\ResolverInterface;
use Magento\CustomerGraphQl\Model\Customer\Address\ExtractCustomerAddressData;


use Mobicommerce\GeoFencing\Helper\Data as Helper;
use Magento\Store\Model\StoreManagerInterface;
use Magento\Customer\Api\AddressRepositoryInterface;
/**
 * Customers addresses field resolver
 */
class CustomerWebsiteAddress implements ResolverInterface
{
    /**
     * @var ExtractCustomerAddressData
     */
    private $extractCustomerAddressData;

    /**
     * @param ExtractCustomerAddressData $extractCustomerAddressData
     */
    public function __construct(
        Helper $helper,
        StoreManagerInterface $storeManager,
        AddressRepositoryInterface $addressRepository,
        ExtractCustomerAddressData $extractCustomerAddressData
    ) {
        $this->helper = $helper;
        $this->storeManager = $storeManager;
        $this->addressRepository = $addressRepository;
        $this->extractCustomerAddressData = $extractCustomerAddressData;
    }

    /**
     * @inheritdoc
     */
    public function resolve(
        Field $field,
        $context,
        ResolveInfo $info,
        array $value = null,
        array $args = null
    ) {
        if (!isset($value['model'])) {
            throw new LocalizedException(__('"model" value should be specified'));
        }
        /** @var Customer $customer */
        $customer = $value['model'];

        $addressesData = [];
        $addresses = $customer->getAddresses();

        if (count($addresses)) {
            foreach ($addresses as $address) {

                $latitude = '';
                $longitude = '';

               
                if ($address->getCustomAttribute('mc_latitude')) {
                    $latitude = $address->getCustomAttribute('mc_latitude')->getValue();
                }

                if ($address->getCustomAttribute('mc_longitude')) {
                    $longitude = $address->getCustomAttribute('mc_longitude')->getValue();
                }
              

                $websiteId = $this->helper->getWebsiteIdFromLatLng($latitude, $longitude);

                if ($websiteId == $this->storeManager->getStore()->getWebsiteId()) {
                    $addressesData[] = $this->extractCustomerAddressData->execute($address);
                }
            }
        }
        return $addressesData;
    }
}
