<?php
/**
 * Mobicommerce
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_GeoFencing
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\GeoFencing\Observer;

use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\Event\Observer;
use Psr\Log\LoggerInterface;
use Mobicommerce\GeoFencing\Model\ResourceModel\Mapping\CollectionFactory as LocationCollectionFactory;
use Magento\Store\Model\StoreManagerInterface;

class SaveShippingInfoToOrder implements ObserverInterface
{
    /**
     * @var LoggerInterface
     */
    private LoggerInterface $logger;

    /**
     * @var LocationCollectionFactory
     */
    private LocationCollectionFactory $locationCollectionFactory;

    /**
     * @var StoreManagerInterface
     */
    private StoreManagerInterface $storeManager;

    /**
     * Constructor
     *
     * @param LoggerInterface $logger
     * @param LocationCollectionFactory $locationCollectionFactory
     * @param StoreManagerInterface $storeManager
     */
    public function __construct(
        LoggerInterface $logger,
        LocationCollectionFactory $locationCollectionFactory,
        StoreManagerInterface $storeManager
    ) {
        $this->logger = $logger;
        $this->locationCollectionFactory = $locationCollectionFactory;
        $this->storeManager = $storeManager;
    }

    public function execute(Observer $observer)
    {
        try {
            $quote = $observer->getEvent()->getQuote();
            $order = $observer->getEvent()->getOrder();

            $latitude = $quote->getShippingAddress()->getMcLatitude();
            $longitude = $quote->getShippingAddress()->getMcLongitude();

            $latlng = $latitude . ' ' . $longitude;
            $websiteId = (int) $this->storeManager->getStore($quote->getStoreId())->getWebsiteId();
            $locationCollection = $this->locationCollectionFactory->create();
            $locationCollection->addFieldToFilter('website_id', $websiteId);
            $locationCollection->getSelect()
                ->where(new \Zend_Db_Expr("is_exclude = 0"))
                ->where(new \Zend_Db_Expr("poly IS NOT NULL"))
                ->where(new \Zend_Db_Expr("poly != ''"))
                ->where(new \Zend_Db_Expr("MBRContains(ST_GeomFromText(`poly`),ST_GeomFromText('Point($latlng)'))"));;
            if ($locationCollection->getSize() > 0) {
                $locationCode = $locationCollection->getFirstItem()->getCode();
                $order->setData('mc_gf_location_code', $locationCode);
            }

            $order->getShippingAddress()->setMcLatitude($latitude);
            $order->getShippingAddress()->setMcLongitude($longitude);

            $order->getBillingAddress()->setMcLatitude($quote->getBillingAddress()->getLatitude());
            $order->getBillingAddress()->setMcLongitude($quote->getBillingAddress()->getMcLongitude());

            return $this;
        } catch (\Exception $e) {
            $this->logger->critical($e->getMessage());
        }
    }
}
