<?php

namespace Mobicommerce\GeoFencing\Plugin\Magento\Quote\Model;

use Magento\Framework\Exception\LocalizedException;
use Magento\Quote\Api\Data\AddressInterface;
use Magento\Quote\Api\Data\CartInterface;
use Mobicommerce\GeoFencing\Helper\Data as Helper;
use Magento\Store\Model\StoreManagerInterface;
use Magento\Customer\Api\AddressRepositoryInterface;

class QuoteAddressValidator
{
    /**
     * @var Helper
     */
    private Helper $helper;

    /**
     * @var StoreManagerInterface
     */
    private StoreManagerInterface $storeManager;

    /**
     * @var AddressRepositoryInterface
     */
    private AddressRepositoryInterface $addressRepository;

    /**
     * Constructor
     *
     * @param Helper $helper
     * @param StoreManagerInterface $storeManager
     * @param AddressRepositoryInterface $addressRepository
     */
    public function __construct(
        Helper $helper,
        StoreManagerInterface $storeManager,
        AddressRepositoryInterface $addressRepository
    ) {
        $this->helper = $helper;
        $this->storeManager = $storeManager;
        $this->addressRepository = $addressRepository;
    }

    /**
     * Validates address against latitude and longitude
     *
     * @param \Magento\Quote\Model\QuoteAddressValidator $subject
     * @param mixed $result
     * @param CartInterface $cart
     * @param AddressInterface $address
     * @return mixed
     * @throws LocalizedException
     */
    public function afterValidateForCart($subject, $result, CartInterface $cart, AddressInterface $address)
    {
        $latitude = '';
        $longitude = '';
	
	if (!in_array(get_class_methods($address), ['getData'])) {
		return;
	}
        if ($address->getData('customer_address_id')) {
            $address = $this->addressRepository->getById($address->getData('customer_address_id'));

            if ($address->getCustomAttribute('mc_latitude')) {
                $latitude = $address->getCustomAttribute('mc_latitude')->getValue();
            }

            if ($address->getCustomAttribute('mc_longitude')) {
                $longitude = $address->getCustomAttribute('mc_longitude')->getValue();
            }
        }

        if (!$latitude || !$longitude) {
            $latitude = $address->getData('mc_latitude');
            $longitude = $address->getData('mc_longitude');
        }

        if ($latitude && $longitude) {
            $websiteId = $this->helper->getWebsiteIdFromLatLng($latitude, $longitude);
            if ($websiteId != $this->storeManager->getStore($cart->getStoreId())->getWebsiteId()) {
                throw new LocalizedException(__('You cannot place order for current address under current store'));
            }
        }
    }
}
