<?php

namespace Mobicommerce\GeoFencing\Setup\Patch\Data;

use Magento\Eav\Model\Config;
use Magento\Eav\Setup\EavSetupFactory;
use Magento\Framework\Setup\ModuleDataSetupInterface;
use Magento\Framework\Setup\Patch\DataPatchInterface;
use Magento\Framework\Exception\LocalizedException;
use Magento\Eav\Model\Entity\Attribute\SetFactory;

class CreateAddressLatLngAttributesPatch implements DataPatchInterface
{
    /**
     * @var ModuleDataSetupInterface
     */
    private $moduleDataSetup;

    /**
     * @var Config
     */
    private $eavConfig;

    /**
     * @var EavSetupFactory
     */
    private $eavSetupFactory;

    /**
     * @var SetFactory
     */
    private $setFactory;

    /**
     * Constructor
     *
     * @param ModuleDataSetupInterface $moduleDataSetup
     * @param Config $eavConfig
     * @param EavSetupFactory $eavSetupFactory
     * @param SetFactory $setFactory
     */
    public function __construct(
        ModuleDataSetupInterface $moduleDataSetup,
        Config $eavConfig,
        EavSetupFactory $eavSetupFactory,
        SetFactory $setFactory
    ) {
        $this->moduleDataSetup = $moduleDataSetup;
        $this->eavConfig = $eavConfig;
        $this->eavSetupFactory = $eavSetupFactory;
        $this->setFactory = $setFactory;
    }

    /**
     * @inheirtDoc
     */
    public static function getDependencies(): array
    {
        return [];
    }

    /**
     * @inheirtDoc
     */
    public function apply()
    {
        $this->moduleDataSetup->getConnection()->startSetup();

        $this->createAttribute([
            'code' => 'mc_latitude',
            'label' => 'Latitude',
            'position' => 501
        ]);

        $this->createAttribute([
            'code' => 'mc_longitude',
            'label' => 'Longitude',
            'position' => 502
        ]);

        $this->moduleDataSetup->getConnection()->endSetup();
    }

    /**
     * Code to create attribute
     *
     * @param array $params
     * @return void
     * @throws LocalizedException
     */
    private function createAttribute(array $params)
    {
        $eavSetup = $this->eavSetupFactory->create();

        $eavSetup->addAttribute('customer_address', $params['code'], [
            'type'              => 'varchar',
            'input'             => 'text',
            'label'             => $params['label'],
            'visible'           => true,
            'unique'            => false,
            'required'          => false,
            'user_defined'      => true,
            'system'            => false,
            'position'          => $params['position'],
            //'group'             => 'General',
            'global'            => true,
            'visible_on_front'  => true,
            'is_used_in_grid'   => false,
            'is_filterable_in_grid' => false
        ]);

        $attribute = $this->eavConfig->getAttribute('customer_address', $params['code']);

        $attribute->setData(
            'used_in_forms',
            [
                'adminhtml_customer_address',
                'customer_register_address',
                'customer_address_edit'
            ]
        );
        $attribute->save();

        $addressEntity = $this->eavConfig->getEntityType('customer_address');
        $attributeSetId = $addressEntity->getDefaultAttributeSetId();

        $attributeSet = $this->setFactory->create();
        $attributeGroupId = $attributeSet->getDefaultGroupId($attributeSetId);

        $attribute->addData([
            'attribute_set_id' => $attributeSetId,
            'attribute_group_id' => $attributeGroupId
        ]);

        $attribute->save();
    }

    /**
     * @inheirtDoc
     */
    public function getAliases() : array
    {
        return [];
    }
}
