<?php

namespace Mobicommerce\GeoFencing\Ui\DataProvider\GeoFencing\Form;

use Magento\Ui\DataProvider\AbstractDataProvider;
use Magento\Store\Model\ResourceModel\Website\CollectionFactory;
use Magento\Ui\DataProvider\Modifier\PoolInterface;
use Mobicommerce\GeoFencing\Model\MappingFactory;

class GeoFencingDataProvider extends AbstractDataProvider
{
    /**
     * @var MappingFactory
     */
    private MappingFactory $mappingFactory;

    /**
     * @param string $name
     * @param string $primaryFieldName
     * @param string $requestFieldName
     * @param CollectionFactory $collectionFactory
     * @param PoolInterface $pool
     * @param MappingFactory $mappingFactory
     * @param array $meta
     * @param array $data
     */
    public function __construct(
        $name,
        $primaryFieldName,
        $requestFieldName,
        CollectionFactory $collectionFactory,
        PoolInterface $pool,
        MappingFactory $mappingFactory,
        array $meta = [],
        array $data = []
    ) {
        parent::__construct($name, $primaryFieldName, $requestFieldName, $meta, $data);
        $this->collection = $collectionFactory->create();
        $this->pool = $pool;
        $this->mappingFactory = $mappingFactory;
    }

    /**
     * {@inheritdoc}
     * @since 101.0.0
     */
    public function getData()
    {
        if ($items = $this->collection->getItems()) {
            foreach ($items as $item) {
                $this->data[$item->getId()] = $item->getData();
                $this->data[$item->getId()]['locations'] = $this->mappingFactory->create()->getLocations($item->getId());
            }
        }

        /** @var ModifierInterface $modifier */
        foreach ($this->pool->getModifiersInstances() as $modifier) {
            $this->data = $modifier->modifyData($this->data);
        }

        return $this->data;
    }

    /**
     * {@inheritdoc}
     * @since 101.0.0
     */
    public function getMeta()
    {
        $meta = parent::getMeta();

        /** @var ModifierInterface $modifier */
        foreach ($this->pool->getModifiersInstances() as $modifier) {
            $meta = $modifier->modifyMeta($meta);
        }

        return $meta;
    }
}
