<?php

namespace Mobicommerce\GeoWebsite\Model\Resolver;

use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\GraphQl\Config\Element\Field;
use Magento\Framework\GraphQl\Exception\GraphQlInputException;
use Magento\Framework\GraphQl\Query\ResolverInterface;
use Magento\Framework\GraphQl\Schema\Type\ResolveInfo;
use Magento\Store\Model\ScopeInterface;
use Magento\Store\Model\StoreManagerInterface;
use Mobicommerce\GeoFencing\Helper\Data as Helper;

class Website implements ResolverInterface
{
    /**
     * @var Helper
     */
    private Helper $helper;

    /**
     * @var StoreManagerInterface
     */
    private StoreManagerInterface $storeManager;

    /**
     * @var ScopeConfigInterface
     */
    private ScopeConfigInterface $scopeConfig;

    /**
     * Constructor
     *
     * @param Helper $helper
     * @param StoreManagerInterface $storeManager
     * @param ScopeConfigInterface $scopeConfig
     */
    public function __construct(
        Helper $helper,
        StoreManagerInterface $storeManager,
        ScopeConfigInterface $scopeConfig
    ) {
        $this->helper = $helper;
        $this->storeManager = $storeManager;
        $this->scopeConfig = $scopeConfig;
    }

    /**
     * @inheritdoc
     */
    public function resolve(
        Field $field,
        $context,
        ResolveInfo $info,
        array $value = null,
        array $args = null
    ) {
        $result = [
            'result' => null
        ];

        $latitude = $args['latitude'] ?? false;
        $longitude = $args['longitude'] ?? false;
        $all = $args['all'] ?? false;

        if (!$latitude) {
            throw new GraphQlInputException(__('You must pass latitude'));
        }

        if (!$longitude) {
            throw new GraphQlInputException(__('You must pass longitude'));
        }

        $language = $this->scopeConfig->getValue(
            "general/locale/code",
            ScopeInterface::SCOPE_STORE,
            $context->getExtensionAttributes()->getStore()->getId()
        );

        $websiteId = $this->helper->getWebsiteIdFromLatLng($latitude, $longitude);

        if ($websiteId) {
            //$result['result'] = $this->helper->getDestinationWebsiteStore($websiteId, $language);
            $result = $this->helper->getDestinationWebsiteStore($websiteId, $language);
        }

        if ($all) {
            $result['all'] = $this->helper->getAllWebsites($language);
        }

        return $result;
    }
}
