<?php

namespace Mobicommerce\InappPayment\Controller\Checkout;

use Magento\Framework\App\ActionInterface;
use Magento\Framework\Controller\Result\Redirect;
use Magento\Framework\Controller\Result\RedirectFactory;
use Magento\Framework\App\RequestInterface;
use Magento\Customer\Api\CustomerRepositoryInterface;
use Magento\Customer\Model\CustomerFactory;
use Magento\Customer\Model\Session as CustomerSession;
use Magento\Checkout\Model\Session as CheckoutSession;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\Exception\NoSuchEntityException;
use Magento\Framework\UrlInterface;
use Magento\Framework\Message\ManagerInterface;
use Magento\Integration\Model\ResourceModel\Oauth\Token\CollectionFactory as TokenCollectionFactory;
use Magento\Quote\Model\MaskedQuoteIdToQuoteIdInterface;

class Index implements ActionInterface
{
    /**
     * @var RedirectFactory
     */
    private RedirectFactory $redirectFactory;

    /**
     * @var RequestInterface
     */
    private RequestInterface $request;

    /**
     * @var CustomerRepositoryInterface
     */
    private CustomerRepositoryInterface $customerRepository;

    /**
     * @var CustomerSession
     */
    private CustomerSession $customerSession;

    /**
     * @var CheckoutSession
     */
    private CheckoutSession $checkoutSession;

    /**
     * @var UrlInterface
     */
    private UrlInterface $url;

    /**
     * @var ManagerInterface
     */
    private ManagerInterface $messageManager;

    /**
     * @var TokenCollectionFactory
     */
    private TokenCollectionFactory $tokenCollectionFactory;

    /**
     * @var MaskedQuoteIdToQuoteIdInterface
     */
    private MaskedQuoteIdToQuoteIdInterface $maskedQuoteIdToQuoteId;

    /**
     * Constructor
     *
     * @param RedirectFactory $redirectFactory
     * @param RequestInterface $request
     * @param CustomerRepositoryInterface $customerRepository
     * @param CustomerSession $customerSession
     * @param CheckoutSession $checkoutSession
     * @param UrlInterface $url
     * @param ManagerInterface $messageManager
     * @param TokenCollectionFactory $tokenCollectionFactory
     * @param MaskedQuoteIdToQuoteIdInterface $maskedQuoteIdToQuoteId
     */
    public function __construct(
        RedirectFactory $redirectFactory,
        RequestInterface $request,
        CustomerRepositoryInterface $customerRepository,
        CustomerSession $customerSession,
        CheckoutSession $checkoutSession,
        UrlInterface $url,
        ManagerInterface $messageManager,
        TokenCollectionFactory $tokenCollectionFactory,
        MaskedQuoteIdToQuoteIdInterface $maskedQuoteIdToQuoteId
    ) {
        $this->redirectFactory = $redirectFactory;
        $this->request = $request;
        $this->customerRepository = $customerRepository;
        $this->customerSession = $customerSession;
        $this->checkoutSession = $checkoutSession;
        $this->url = $url;
        $this->messageManager = $messageManager;
        $this->tokenCollectionFactory = $tokenCollectionFactory;
        $this->maskedQuoteIdToQuoteId = $maskedQuoteIdToQuoteId;
    }

    /**
     * Set session variable for either guest cart or customer cart based on request
     *
     * @return Redirect
     */
    public function execute()
    {
        $result = $this->redirectFactory->create();

        try {
            $this->setCheckoutSession();
            $checkoutUrl = $this->url->getUrl('checkout');
            $result->setUrl($checkoutUrl . '#payment');
        } catch (\Exception $e) {
            $this->messageManager->addErrorMessage($e->getMessage());
            $result->setPath('checkout/cart');
        }

        return $result;
    }

    /**
     * Actual implementation to set cart session
     *
     * @return void
     * @throws LocalizedException
     * @throws NoSuchEntityException
     */
    private function setCheckoutSession() : void
    {
        $token = $this->request->getParam('token', false);
        $maskedId = $this->request->getParam('masked_id', false);
        $appType = $this->request->getParam('app_type', "mobileapps");
        if ($token) {
            /**
             * For newer Magento versions, use below class
             * use Magento\Authorization\Model\UserContextInterface;
             * use Magento\Integration\Api\UserTokenReaderInterface;
             * $tokenData = $this->userTokenReader->read($token);
             * if ($tokenData->getUserContext()->getUserType() == UserContextInterface::USER_TYPE_CUSTOMER
             */
            $tokenCollection = $this->tokenCollectionFactory->create();
            $tokenCollection->addFieldToFilter('token', $token)
                ->addFieldToFilter('revoked', 0)
                ->addFieldToFilter('user_type', 3);

            $tokenCollection->getSelect()->where(new \Zend_Db_Expr('customer_id IS NOT NULL'));
            if ($tokenCollection->getSize() > 0) {
                $customerId = $tokenCollection->getFirstItem()->getCustomerId();
                $customer = $this->customerRepository->getById($customerId);
                $this->customerSession->setCustomerDataAsLoggedIn($customer);
                $this->customerSession->setUsername($customer->getEmail());
                $this->checkoutSession->setMobiInAppPayment(true);
                $this->checkoutSession->setMobiStripeAppType($appType);
            } else {
                throw new LocalizedException(__('Invalid token provided'));
            }
        } elseif ($maskedId) {
            $email = $this->request->getParam('email', false);

            $quoteId = $this->maskedQuoteIdToQuoteId->execute($maskedId);
            $this->checkoutSession->setQuoteId($quoteId);

            $quote = $this->checkoutSession->getQuote();
            // $email = $quote->getBillingAddress()->getEmail();
            $quote->getShippingAddress()->setEmail($email)->save();
            $this->checkoutSession->setMobiInAppPayment(true);
            $this->checkoutSession->setMobiStripeAppType($appType);
        } else {
            throw new LocalizedException(__('Incorrect information supplied'));
        }
    }
}
