<?php
/**
 * Mobicommerce
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Block\Adminhtml\Deeplink\Container\Tab;

use Mobicommerce\Mobiapp\Model\Config\Source\MobicommerceCmsPageType;

class Cmspage extends \Magento\Backend\Block\Widget\Grid\Extended
{
    /**
     * @var \Magento\Cms\Model\PageFactory $cmsPageFactory
     */
    protected $cmsPageFactory;

    /**
     * Cmspage constructor.
     *
     * @param \Magento\Backend\Block\Template\Context $context
     * @param \Magento\Backend\Helper\Data $backendHelper
     * @param \Magento\Cms\Model\PageFactory $cmsPageFactory
     * @param Mobicommerce\Mobiapp\Model\Config\Source\MobicommerceCmsPageType $mobicommerceCmsPageType
     * @param array $data
     */
    public function __construct(
        \Magento\Backend\Block\Template\Context $context,
        \Magento\Backend\Helper\Data $backendHelper,
        \Magento\Cms\Model\PageFactory $cmsPageFactory,
        MobicommerceCmsPageType $mobicommerceCmsPageType,
        array $data = []
    ) {
        parent::__construct($context, $backendHelper, $data);
        $this->cmsPageFactory = $cmsPageFactory;
        $this->mobicommerceCmsPageType = $mobicommerceCmsPageType;
    }

    /**
     * Construct
     *
     * @return void
     */
    protected function _construct()
    {
        parent::_construct();
        $this->setId('deepink_cmspages');
        $this->setDefaultSort('entity_id');
        $this->setUseAjax(true);
    }

    /**
     * Prepare collection
     *
     * @return Grid
     */
    protected function _prepareCollection()
    {
        $collection = $this->cmsPageFactory->create()->getCollection()
            ->addFieldToFilter('is_active', 1);

        $this->setCollection($collection);

        return parent::_prepareCollection();
    }

    /**
     * Prepare columns
     *
     * @return Extended
     */
    protected function _prepareColumns()
    {
        $this->addColumn(
            'entity_id',
            [
                'header'           => __('ID'),
                'sortable'         => true,
                'type'             => 'number',
                'index'            => 'page_id',
                'header_css_class' => 'col-id',
                'column_css_class' => 'col-id'
            ]
        );
        
        $this->addColumn('title', [
            'header' => __('Title'),
            'index' => 'title'
        ]);

        $this->addColumn('identifier', [
            'header' => __('URL Key'),
            'index' => 'identifier'
        ]);

        $this->addColumn('mobicommerce_page_type', [
            'header' => __('CMS Page Type'),
            'index' => 'mobicommerce_page_type',
            'sortable' => false,
            'type' => 'options',
            'options' => $this->mobicommerceCmsPageType->getTypes()
        ]);

        return parent::_prepareColumns();
    }

    /**
     * Get grid url
     *
     * @return string
     */
    public function getGridUrl()
    {
        return $this->getUrl('mobicommerce/deeplink/cmspagegrid', ['_current' => true]);
    }
}
