<?php
/**
 * Mobicommerce
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Block\Adminhtml\Image\Edit\Buttons;

use Magento\Backend\Block\Widget\Context;
use Magento\Framework\Exception\NoSuchEntityException;
use Mobicommerce\Mobiapp\Model\ImageFactory;

class GenericButton
{
    /**
     * @var Context
     */
    protected $context;

    /**
     * @var ImageFactory
     */
    protected $imageFactory;

    /**
     * GenericButton constructor.
     *
     * @param Magento\Backend\Block\Widget\Context $context
     * @param Mobicommerce\Mobiapp\Model\ImageFactory $imageFactory
     */
    public function __construct(
        Context $context,
        ImageFactory $imageFactory
    ) {
        $this->context = $context;
        $this->imageFactory = $imageFactory;
    }

    /**
     * Get Image ID
     *
     * @return int|null
     */
    public function getImageId()
    {
        try {
            return $this->imageFactory->create()->load(
                $this->context->getRequest()->getParam('id')
            )->getId();
        } catch (NoSuchEntityException $e) {
            return null;
        }
        return null;
    }

    /**
     * Get ID
     *
     * @return int|null
     */
    public function getId()
    {
        try {
            return $this->context->getRequest()->getParam('id', false);
        } catch (NoSuchEntityException $e) {
            return null;
        }
        return null;
    }

    /**
     * Generate url by route and parameters
     *
     * @param   string $route
     * @param   array $params
     * @return  string
     */
    public function getUrl($route = '', $params = [])
    {
        return $this->context->getUrlBuilder()->getUrl($route, $params);
    }
}
