<?php
/**
 * Mobicommerce
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Block\Adminhtml\Language;

use Magento\Backend\Block\Template\Context;
use Magento\Framework\Locale\ListsInterface;
use Magento\Config\Model\ResourceModel\Config\Data\CollectionFactory as ScopeCollectionFactory;

class Switcher extends \Magento\Backend\Block\Template
{
    /**
     * Switcher constructor.
     *
     * @param Magento\Backend\Block\Template\Context $context
     * @param Magento\Framework\Locale\ListsInterface $localeLists
     * @param Magento\Config\Model\ResourceModel\Config\Data\CollectionFactory $scopeCollectionFactory
     */
    public function __construct(
        Context $context,
        ListsInterface $localeLists,
        ScopeCollectionFactory $scopeCollectionFactory
    ) {
        parent::__construct($context);
        $this->localeLists = $localeLists;
        $this->scopeCollectionFactory = $scopeCollectionFactory;
    }
    /**
     * Block template filename
     *
     * @var string
     */
    protected $_template = 'Mobicommerce_Mobiapp::language/switcher.phtml';

    /**
     * Get language var name
     *
     * @return string
     */
    public function getLanguageVarName()
    {
        return "language";
    }

     /**
      * Get store locales
      *
      * @return string
      */
    public function getStoreLocales()
    {
        $storeLocales = $this->scopeCollectionFactory->create();
        $storeLocales->addFieldToFilter('path', 'general/locale/code');
        $storeLocales->getSelect()
            ->reset(\Magento\Framework\DB\Select::COLUMNS)
            ->columns(['value' => 'GROUP_CONCAT(DISTINCT(value))']);

        $value = false;
        if ($storeLocales->getSize() && $value = $storeLocales->getFirstItem()->getValue()) {
            $value = explode(',', $value);
        }
        
        if (!$value) {
            $value = [];
        }

        return $value;
    }

     /**
      * Get languages
      *
      * @return string
      */
    public function getLanguages()
    {
        if (!$this->hasData('locales')) {
            $locales = [];

            $storeLocales = $this->getStoreLocales();
            foreach ($this->localeLists->getOptionLocales() as $locale) {
                if (in_array($locale['value'], $storeLocales)) {
                    $locales[$locale['value']] = $locale['label'];
                }
            }

            $this->setData('locales', $locales);
        }
        
        return $this->getData('locales');
    }

    /**
     * Get languages code
     *
     * @return string
     */
    public function getLanguageCode()
    {
        if (!$this->hasData('language_code')) {
            $this->setData('language_code', $this->getRequest()->getParam($this->getLanguageVarName()));
        }
        return $this->getData('language_code');
    }

    /**
     * Get Current selection name
     *
     * @return string
     */
    public function getCurrentSelectionName()
    {
        foreach ($this->getLanguages() as $code => $label) {
            if ($code == $this->getLanguageCode()) {
                return $label;
            }
        }
        return __("None Selected");
    }

     /**
      * Check whether language switch enabled
      *
      * @return boolean
      */
    public function isLanguageSwitchEnabled()
    {
        return count($this->getLanguages()) ? true : false;
    }

    /**
     * Check whether language selected
     *
     * @param string $code
     * @return boolean
     */
    public function isLanguageSelected($code)
    {
        return $code == $this->getLanguageCode();
    }
}
