<?php
/**
 * Mobicommerce
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Block\Adminhtml\PageBuilder\Container\Tab;

use Magento\Backend\Block\Widget\Grid;
use Magento\Backend\Block\Widget\Grid\Column;
use Magento\Backend\Block\Widget\Grid\Extended;
use Magento\Catalog\Model\ResourceModel\Category\CollectionFactory;

class CategoryPosition extends \Magento\Backend\Block\Widget\Grid\Extended
{
    /**
     * Collection object
     *
     * @var \Magento\Framework\Data\Collection
     */
    protected $_collection;

    /**
     * CategoryPosition constructor
     *
     * @param \Magento\Backend\Block\Template\Context $context
     * @param \Magento\Backend\Helper\Data $backendHelper
     * @param \Magento\Framework\Registry $registry
     * @param CollectionFactory $collectionFactory
     * @param array $data
     * @return void
     */
    public function __construct(
        \Magento\Backend\Block\Template\Context $context,
        \Magento\Backend\Helper\Data $backendHelper,
        \Magento\Framework\Registry $registry,
        CollectionFactory $collectionFactory,
        array $data = []
    ) {
        $this->registry = $registry;
        $this->collectionFactory = $collectionFactory;
        parent::__construct($context, $backendHelper, $data);
    }

    /**
     * Construct
     *
     * @return void
     */
    protected function _construct()
    {
        parent::_construct();
        $this->setId('mobicommerce_pagebuilder_categoryposition');
        $this->setDefaultSort('position');
        $this->setUseAjax(true);
    }

    /**
     * Set collection object
     *
     * @param \Magento\Framework\Data\Collection $collection
     * @return void
     */
    public function setCollection($collection)
    {
        $this->_collection = $collection;
    }

    /**
     * Get collection object
     *
     * @return \Magento\Framework\Data\Collection
     */
    public function getCollection()
    {
        return $this->_collection;
    }

    /**
     * Prepare collection
     *
     * @return Grid
     */
    protected function _prepareCollection()
    {
        $pageBuilderId = (int)$this->getRequest()->getParam('id', 0);
        $collection = $this->collectionFactory->create();
        $collection->addAttributeToSelect('name');
        $collection->getSelect()->join(
            ['mapping' => $collection->getResource()->getTable(
                'mobicommerce_page_builder_category_mapping'
            )],
            'mapping.category_id = e.entity_id AND mapping.page_builder_id = '.$pageBuilderId,
            ['mapping.position']
        );
        $this->setCollection($collection);
        return parent::_prepareCollection();
    }

    /**
     * Prepare columns
     *
     * @return Extended
     */
    protected function _prepareColumns()
    {
        $this->addColumn(
            'id',
            [
                'header'           => __('ID'),
                'sortable'         => true,
                'index'            => 'entity_id',
                'type'             => 'number',
                'header_css_class' => 'col-id',
                'column_css_class' => 'col-id'
            ]
        );
        
        $this->addColumn('name', [
            'header' => __('Name'),
            'index' => 'name'
        ]);

        $this->addColumn(
            'position',
            [
                'header' => __('Position'),
                'type' => 'number',
                'index' => 'position',
                'validate_class' => 'validate-number',
                'editable' => true
            ]
        );
        return parent::_prepareColumns();
    }

    /**
     * Get grid url
     *
     * @return string
     */
    public function getGridUrl()
    {
        return $this->getUrl('mobicommerce/pagebuilder/categorypositiongrid', ['_current' => true]);
    }

    /**
     * Get Page builder
     *
     * @return array|null
     */
    public function getPageBuilder()
    {
        return $this->registry->registry('mobicommerce_page_builder');
    }

    /**
     * Get multiple rows
     *
     * @param array $item
     * @return boolean
     * override of parent class method
     * becuase category collection class already have getChildren method
     * which is breaking behaviour of this class
     */
    public function getMultipleRows($item)
    {
        return 0;
    }
}
