<?php
/**
 * Mobicommerce
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Block\Adminhtml\PageBuilder\Edit\Buttons;

use Magento\Framework\View\Element\UiComponent\Control\ButtonProviderInterface;
use Magento\Backend\Block\Widget\Context;
use Mobicommerce\Mobiapp\Model\PageBuilderFactory;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Mobicommerce\Mobiapp\Helper\Config;

class PreviewButton extends GenericButton implements ButtonProviderInterface
{
    /**
     * PreviewButton constructor
     *
     * @param Context $context
     * @param PageBuilderFactory $pageBuilderFactory
     * @param ScopeConfigInterface $scopeConfig
     * @return array
     */
    public function __construct(
        Context $context,
        PageBuilderFactory $pageBuilderFactory,
        ScopeConfigInterface $scopeConfig,
        Config $mobiconfig
    ) {
        parent::__construct($context, $pageBuilderFactory);
        $this->scopeConfig = $scopeConfig;
        $this->mobiconfig = $mobiconfig;
    }

    /**
     * Get button data
     *
     * @return array
     */
    public function getButtonData()
    {
        if ($id = $this->getPageBuilderId()) {
            if ($this->ifHeadlessFrontendEnabled() && $headlessUrl = $this->getHeadlessUrl()) {
                if (substr($headlessUrl, -1) != '/') {
                    $headlessUrl .= '/';
                }
                $headlessUrl .= Config::PAGEBUILDER_PREVIEW_SLUG;
                $headlessUrl .= '?pageid=' . $id;

                return [
                    'label' => __('Preview'),
                    'on_click' => sprintf("window.open('%s' ,'_blank');", $headlessUrl),
                    'class' => '',
                    'sort_order' => 12
                ];
            }
        }
        
        return null;
    }

    /**
     * Check if headless frontend enabled
     *
     * @return array
     */
    public function ifHeadlessFrontendEnabled()
    {
        return $this->scopeConfig->getValue(
            'mobi_basic/headless/is_enable'
        );
    }

    /**
     * Get headless url
     *
     * @return array
     */
    public function getHeadlessUrl()
    {
        /*return $this->scopeConfig->getValue(
            'mobi_basic/headless/frontend_url'
        );*/
        return $this->mobiconfig->getStoreUrl();
    }
}
