<?php
/**
 * Mobicommerce
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Block\Adminhtml\System\Form\Field;

use Magento\Config\Block\System\Config\Form\Field\FieldArray\AbstractFieldArray;
use Magento\Framework\DataObject;
use Magento\Framework\Exception\LocalizedException;

class DynamicRowsCmsPages extends AbstractFieldArray
{
    /**
     * @var cmsPageRenderer
     */
    private $cmsPageRenderer;

    /**
     * Prepare rendering the new field by adding all the needed columns
     */
    protected function _prepareToRender()
    {
        $this->addColumn('cms_page', [
            'label' => __('CMS Page'),
            'renderer' => $this->getCmsPagesRenderer()
        ]);

        $this->addColumn('position', [
            'label' => __('Position'),
            'class' => 'required-entry validate-number'
        ]);

        $this->_addAfter = false;
        $this->_addButtonLabel = __('Add');
    }

    /**
     * Prepare existing row data object
     *
     * @param DataObject $row
     * @throws LocalizedException
     */
    protected function _prepareArrayRow(DataObject $row): void
    {
        $options = [];

        $cmsPage = $row->getCmsPage();
        if ($cmsPage !== null) {
            $options['option_' . $this->getCmsPagesRenderer()->calcOptionHash($cmsPage)] = 'selected="selected"';
        }

        $row->setData('option_extra_attrs', $options);
    }

    /**
     * Get cms pages renderer
     *
     * @return CmsPageColumn
     * @throws LocalizedException
     */
    private function getCmsPagesRenderer()
    {
        if (!$this->cmsPageRenderer) {
            $this->cmsPageRenderer = $this->getLayout()->createBlock(
                DynamicRows\CmsPages::class,
                '',
                ['data' => ['is_render_to_js_template' => true]]
            );
        }
        return $this->cmsPageRenderer;
    }
}
