<?php
/**
 * Mobicommerce
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Block\Adminhtml\Widget\Container;

use Magento\Framework\Serialize\Serializer\Serialize;
use Magento\Framework\App\ResourceConnection;

class AssignCategoryPosition extends \Magento\Backend\Block\Template
{
    /**
     * Block template
     *
     * @var string
     */
    protected $_template = 'widget/container/assign_category_position.phtml';

    /**
     * @var \Magento\Catalog\Block\Adminhtml\Category\Tab\Product
     */
    protected $blockGrid;

    /**
     * AssignProducts constructor.
     *
     * @param \Magento\Backend\Block\Template\Context $context
     * @param \Magento\Framework\Registry $registry
     * @param Serialize $serialize
     * @param \Magento\Framework\Json\EncoderInterface $jsonEncoder
     * @param ResourceConnection $resourceConnection
     * @param array $data
     */
    public function __construct(
        \Magento\Backend\Block\Template\Context $context,
        \Magento\Framework\Registry $registry,
        Serialize $serialize,
        \Magento\Framework\Json\EncoderInterface $jsonEncoder,
        ResourceConnection $resourceConnection,
        array $data = []
    ) {
        $this->registry = $registry;
        $this->serialize = $serialize;
        $this->jsonEncoder = $jsonEncoder;
        $this->resourceConnection = $resourceConnection;
        parent::__construct($context, $data);
    }

    /**
     * Retrieve instance of grid block
     *
     * @return \Magento\Framework\View\Element\BlockInterface
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function getBlockGrid()
    {
        if (null === $this->blockGrid) {
            $this->blockGrid = $this->getLayout()->createBlock(
                \Mobicommerce\Mobiapp\Block\Adminhtml\Widget\Container\Tab\CategoryPosition::class,
                'widget.categoryposition.grid'
            );
        }
        return $this->blockGrid;
    }

    /**
     * Return HTML of grid block
     *
     * @return string
     */
    public function getGridHtml()
    {
        return $this->getBlockGrid()->toHtml();
    }

    /**
     * Get category position json
     *
     * @return string
     */
    public function getCategoryPositionJson()
    {
        $widgetId = $this->getWidget()->getId();
        if ($widgetId) {
            $categories = [];
            $connection = $this->resourceConnection->getConnection();

            $table = $this->resourceConnection->getTableName("mobicommerce_widget_category_mapping");
            $select = $connection->select()
                ->from(
                    ['mapping' => $table]
                )->where('widget_id = ?', $widgetId);
            $result = $connection->fetchAll($select);
            if ($result) {
                foreach ($result as $item) {
                    $categories[$item['category_id']] = $item['position'];
                }
            }

            return $this->jsonEncoder->encode($categories);
        }

        return '{}';
    }

    /**
     * Retrieve current widget instance
     *
     * @return array|null
     */
    public function getWidget()
    {
        return $this->registry->registry('mobicommerce_widget');
    }

    /**
     * Get ui component name
     *
     * @return array|null
     */
    public function getUiComponentName()
    {
        return 'mobicommerce_widget_form_' . $this->getWidget()->getType();
    }
}
