<?php
/**
 * Mobicommerce
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Block\Adminhtml\Widget\Container\Tab;

use Magento\Backend\Block\Widget\Grid;
use Magento\Backend\Block\Widget\Grid\Column;
use Magento\Backend\Block\Widget\Grid\Extended;
use Mobicommerce\Mobiapp\Model\Config\Source\MobicommerceCmsPageType;

class MobicommerceCmsPage extends \Magento\Backend\Block\Widget\Grid\Extended
{
    /**
     * Collection object
     *
     * @var \Magento\Framework\Data\Collection
     */
    protected $_collection;

    /**
     * Constructor
     *
     * @param \Magento\Backend\Block\Template\Context $context
     * @param \Magento\Backend\Helper\Data $backendHelper
     * @param \Magento\Framework\Registry $registry
     * @param \Magento\Cms\Model\PageFactory $pageFactory
     * @param  MobicommerceCmsPageType $mobicommerceCmsPageType
     * @param array $data
     */
    public function __construct(
        \Magento\Backend\Block\Template\Context $context,
        \Magento\Backend\Helper\Data $backendHelper,
        \Magento\Framework\Registry $registry,
        \Magento\Cms\Model\PageFactory $pageFactory,
        MobicommerceCmsPageType $mobicommerceCmsPageType,
        array $data = []
    ) {
        $this->registry = $registry;
        $this->pageFactory = $pageFactory;
        $this->mobicommerceCmsPageType = $mobicommerceCmsPageType;
        parent::__construct($context, $backendHelper, $data);
    }

    /**
     * Constructor
     *
     * @return void
     */
    protected function _construct()
    {
        parent::_construct();
        $this->setId('mobicommerce_widget_mobicommercecmspage');
        $this->setDefaultSort('page_id');
        $this->setUseAjax(true);
    }

    /**
     * Set collection object
     *
     * @param \Magento\Framework\Data\Collection $collection
     * @return void
     */
    public function setCollection($collection)
    {
        $this->_collection = $collection;
    }

    /**
     * Get collection object
     *
     * @return \Magento\Framework\Data\Collection
     */
    public function getCollection()
    {
        return $this->_collection;
    }

    /**
     * Prepare collection
     *
     * @return Grid
     */
    protected function _prepareCollection()
    {
        $widgetId = (int)$this->getRequest()->getParam('id', 0);
        $collection = $this->pageFactory->create()->getCollection();
        $collection->addFieldToFilter('mobicommerce_page_type', ['eq' => 'mobicommerce_product_listing_page']);
        $this->setCollection($collection);
        return parent::_prepareCollection();
    }

    /**
     * Prepare columns
     *
     * @return Extended
     */
    protected function _prepareColumns()
    {
        $this->addColumn(
            'page_id',
            [
                'header'           => __('ID'),
                'sortable'         => true,
                'index'            => 'page_id',
                'type'             => 'number',
                'header_css_class' => 'col-id',
                'column_css_class' => 'col-id'
            ]
        );
        
        $this->addColumn('title', [
            'header' => __('Title'),
            'index' => 'title'
        ]);
        
        return parent::_prepareColumns();
    }

    /**
     * Get grid url
     *
     * @return string
     */
    public function getGridUrl()
    {
        return $this->getUrl('mobicommerce/widget/mobicommercecmspagegrid', ['_current' => true]);
    }

    /**
     * Get widget
     *
     * @return array|null
     */
    public function getWidget()
    {
        return $this->registry->registry('mobicommerce_widget');
    }
}
