<?php
/**
 * Mobicommerce
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Block\Adminhtml\Widget\Edit\Buttons;

use Magento\Backend\Block\Widget\Context;
use Magento\Framework\Exception\NoSuchEntityException;
use Mobicommerce\Mobiapp\Model\WidgetFactory;

class GenericButton
{
    /**
     * @var Context
     */
    protected $context;

    /**
     * @var WidgetFactory
     */
    protected $widgetFactory;

    /**
     * Constructor
     *
     * @param Context $context
     * @param WidgetFactory $widgetFactory
     */
    public function __construct(
        Context $context,
        WidgetFactory $widgetFactory
    ) {
        $this->context = $context;
        $this->widgetFactory = $widgetFactory;
    }

    /**
     * Return Image ID
     *
     * @return int|null
     */
    public function getWidgetId()
    {
        try {
            return $this->widgetFactory->create()->load(
                $this->context->getRequest()->getParam('id')
            )->getId();
        } catch (NoSuchEntityException $e) {
            return null;
        }
        return null;
    }

    /**
     * Return ID
     *
     * @return int|null
     */
    public function getId()
    {
        try {
            return $this->context->getRequest()->getParam('id', false);
        } catch (NoSuchEntityException $e) {
            return null;
        }
        return null;
    }

    /**
     * Generate url by route and parameters
     *
     * @param   string $route
     * @param   array $params
     * @return  string
     */
    public function getUrl($route = '', $params = [])
    {
        return $this->context->getUrlBuilder()->getUrl($route, $params);
    }
}
