<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Controller\Adminhtml\Customsegment;

use Magento\Backend\App\Action;
use Magento\Backend\App\Action\Context;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\App\Action\HttpPostActionInterface as HttpPostActionInterface;
use Mobicommerce\Mobiapp\Model\CustomsegmentFactory;
use Mobicommerce\Mobiapp\Model\CustomsegmentRepository;

class Save extends Action implements HttpPostActionInterface
{
    public const ADMIN_RESOURCE = 'Mobicommerce_Mobiapp::custom_segment';

    /**
     * @var CustomsegmentFactory
     */
    private CustomsegmentFactory $customsegmentFactory;

    /**
     * @var CustomsegmentRepository
     */
    private CustomsegmentRepository $customsegmentRepository;

    /**
     * Constructor
     *
     * @param Context $context
     * @param CustomsegmentFactory $customsegmentFactory
     * @param CustomsegmentRepository $customsegmentRepository
     */
    public function __construct(
        Action\Context $context,
        CustomsegmentFactory $customsegmentFactory,
        CustomsegmentRepository $customsegmentRepository
    ) {
        parent::__construct($context);
        $this->customsegmentFactory = $customsegmentFactory;
        $this->customsegmentRepository = $customsegmentRepository;
    }

    /**
     * Execute action
     */
    public function execute()
    {
        $resultRedirect = $this->resultRedirectFactory->create();

        $data = $this->getRequest()->getPostValue();
        if ($data) {
            if (empty($data['id'])) {
                $data['id'] = null;
            }

            $model = $this->customsegmentFactory->create();

            $id = $this->getRequest()->getParam('id');
            if ($id) {
                try {
                    $model->load($id);
                } catch (LocalizedException $e) {
                    $this->messageManager->addErrorMessage(__('This item no longer exists.'));
                    return $resultRedirect->setPath('*/*/');
                }
            }

            try {
                $model->setData($data);
                $model->setTotalUsers($this->customsegmentRepository->getIndividualEmailsCount($model));
                $model->save();

                $this->messageManager->addSuccessMessage(__('You saved the Item.'));

                if ($this->getRequest()->getParam('back')) {
                    return $resultRedirect->setPath('*/*/edit', [
                        'id' => $model->getId(),
                        '_current' => true
                    ]);
                }
            } catch (\Exception $e) {
                $this->messageManager->addErrorMessage(__($e->getMessage()));

                return $resultRedirect->setPath('*/*/edit', [
                    'id' => $this->getRequest()->getParam('id')
                ]);
            }
        }

        return $resultRedirect->setPath('*/*/');
    }
}
