<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Controller\Adminhtml\Customsegmentlog;

use Magento\Backend\App\Action;
use Magento\Backend\App\Action\Context;
use Magento\Framework\View\Result\PageFactory;
use Mobicommerce\Mobiapp\Model\CustomsegmentFactory;

class Index extends Action
{
    public const ADMIN_RESOURCE = 'Mobicommerce_Mobiapp::custom_segment';

    /**
     * @var PageFactory
     */
    protected $resultPageFactory = false;

    /**
     * @var CustomsegmentFactory
     */
    private CustomsegmentFactory $customsegmentFactory;

    /**
     * Constructor
     *
     * @param Context $context
     * @param PageFactory $resultPageFactory
     * @param CustomsegmentFactory $customsegmentFactory
     */
    public function __construct(
        Action\Context $context,
        PageFactory $resultPageFactory,
        CustomsegmentFactory $customsegmentFactory
    ) {
        parent::__construct($context);
        $this->resultPageFactory = $resultPageFactory;
        $this->customsegmentFactory = $customsegmentFactory;
    }

    /**
     * Execute action
     */
    public function execute()
    {
        $id = $this->getRequest()->getParam('segment_id');

        if (!$id) {
            $this->messageManager->addErrorMessage(__('You need to pass segment ID to view the logs'));
            $resultRedirect = $this->resultRedirectFactory->create();
            return $resultRedirect->setPath('*/customsegment/index');
        }

        $model = $this->customsegmentFactory->create();
        $model->load($id);
        if (!$model->getId()) {
            $this->messageManager->addErrorMessage(__('You need to pass valid segment ID to view the logs'));
            $resultRedirect = $this->resultRedirectFactory->create();
            return $resultRedirect->setPath('*/customsegment/index');
        }

        $resultPage = $this->resultPageFactory->create();
        $resultPage->setActiveMenu('Mobicommerce_Mobiapp::custom_segment');
        $resultPage->getConfig()->getTitle()->prepend((__('Custom Segments Log')));

        return $resultPage;
    }
}
