<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Controller\Adminhtml\Image;

use Magento\Backend\App\Action;

class Edit extends Action
{
    public const ADMIN_RESOURCE = 'Mobicommerce_Mobiapp::image_collection';

    /**
     * @var PageFactory
     */
    protected $resultPageFactory = false;

    /**
     * @param Context $context
     * @param PageFactory $resultPageFactory
     * @param ImageFactory $imageFactory
     * @param Registry $registry
     */
    public function __construct(
        Action\Context $context,
        \Magento\Framework\View\Result\PageFactory $resultPageFactory,
        \Mobicommerce\Mobiapp\Model\ImageFactory $imageFactory,
        \Magento\Framework\Registry $registry
    ) {
        parent::__construct($context);
        $this->resultPageFactory = $resultPageFactory;
        $this->imageFactory = $imageFactory;
        $this->registry = $registry;
    }

    /**
     * Execute action
     */
    public function execute()
    {
        $id = $this->getRequest()->getParam('id');
        
        $image = $this->imageFactory->create();

        if ($id) {
            $image->load($id);
            if (!$image->getId()) {
                $this->messageManager->addErrorMessage(__('This item no longer exists.'));
                $resultRedirect = $this->resultRedirectFactory->create();
                return $resultRedirect->setPath('*/*/');
            }
        }

        $this->registry->register('mobicommerce_image', $image);

        $resultPage = $this->resultPageFactory->create();
        $resultPage->setActiveMenu('Mobicommerce_Mobiapp::image_collection');
        $resultPage->getConfig()->getTitle()->prepend($image->getName() ?? __('New Image'));

        return $resultPage;
    }
}
