<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Controller\Adminhtml\Image;

use Magento\Backend\App\Action;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\App\Action\HttpPostActionInterface as HttpPostActionInterface;
use Mobicommerce\Mobiapp\Model\ImageFactory;
use Mobicommerce\Mobiapp\Helper\Image as ImageHelper;

class Save extends Action implements HttpPostActionInterface
{
    public const ADMIN_RESOURCE = 'Mobicommerce_Mobiapp::image_collection';

    /**
     * @param Context $context
     * @param ImageFactory $imageFactory
     * @param ImageHelper $imageHelper
     */
    public function __construct(
        Action\Context $context,
        ImageFactory $imageFactory,
        ImageHelper $imageHelper
    ) {
        parent::__construct($context);
        $this->imageFactory = $imageFactory;
        $this->imageHelper = $imageHelper;
    }

    /**
     * Execute action
     */
    public function execute()
    {
        $resultRedirect = $this->resultRedirectFactory->create();

        $data = $this->getRequest()->getPostValue();
        if ($data) {
            if (empty($data['id'])) {
                $data['id'] = null;
            }

            $model = $this->imageFactory->create();

            $id = $this->getRequest()->getParam('id');
            if ($id) {
                try {
                    $model->load($id);
                } catch (LocalizedException $e) {
                    $this->messageManager->addErrorMessage(__('This item no longer exists.'));
                    return $resultRedirect->setPath('*/*/');
                }
            }

            try {
                $this->processDesktopimageImage($data);
                $this->processMobileimageImage($data);

                $model->setData($data);
                if (!isset($data['mobile_image'])) {
                    $model->setMobileImage("");
                }
                if (!isset($data['desktop_image'])) {
                    $model->setDesktopImage("");
                }
                $model->save();
                
                $this->messageManager->addSuccessMessage(__('You saved the Item.'));

                if ($this->getRequest()->getParam('back')) {
                    return $resultRedirect->setPath('*/*/edit', [
                        'id' => $model->getId(),
                        '_current' => true
                    ]);
                }
            } catch (\Exception $e) {
                $this->messageManager->addErrorMessage(__($e->getMessage()));

                return $resultRedirect->setPath('*/*/edit', [
                    'id' => $this->getRequest()->getParam('id')
                ]);
            }
        }

        return $resultRedirect->setPath('*/*/');
    }

    /**
     * ProcessDesktopimageImage function
     *
     * @param Array $data
     */
    private function processDesktopimageImage(&$data)
    {
        if (isset($data['desktop_image']) && is_array($data['desktop_image'])) {
            if (!empty($data['desktop_image']['delete'])) {
                $data['desktop_image'] = null;
            } else {
                if (isset($data['desktop_image'][0]['name'])) {
                    $image = $data['desktop_image'][0]['url'];
                    $image = $this->imageHelper->cleanPathBeforeSave($image);
                    $data['desktop_image'] = $image;
                } else {
                    unset($data['desktop_image']);
                }
            }
        }
    }

    /**
     * ProcessMobileimageImage function
     *
     * @param Array $data
     */
    private function processMobileimageImage(&$data)
    {
        if (isset($data['mobile_image']) && is_array($data['mobile_image'])) {
            if (!empty($data['mobile_image']['delete'])) {
                $data['mobile_image'] = null;
            } else {
                if (isset($data['mobile_image'][0]['name'])) {
                    $image = $data['mobile_image'][0]['url'];
                    $image = $this->imageHelper->cleanPathBeforeSave($image);
                    $data['mobile_image'] = $image;
                } else {
                    unset($data['mobile_image']);
                }
            }
        }
    }
}
