<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Controller\Adminhtml\Mobiapp;

use Magento\Backend\App\Action;
use Magento\Framework\Exception\LocalizedException;

class Createapp extends Action
{
    public const ADMIN_RESOURCE = 'Mobicommerce_Mobiapp::create_app';

    /**
     * @param Context $context
     * @param MobiappFactory $mobiappFactory
     */
    public function __construct(
        Action\Context $context,
        \Mobicommerce\Mobiapp\Model\MobiappFactory $mobiappFactory
    ) {
        parent::__construct($context);
        $this->mobiappFactory = $mobiappFactory;
    }

    /**
     * Execute action
     */
    public function execute()
    {
        $resultRedirect = $this->resultRedirectFactory->create();

        $data = $this->getRequest()->getPostValue();
        $data['id'] = null;

        try {
            $this->processIconImage($data);
            $this->processFaviconImage($data);
            
            $mobiapp = $this->mobiappFactory->create();
            $mobiapp->setData($data)->save();

            $this->messageManager->addSuccessMessage($mobiapp->getMobiServerSuccessMessage());
            //return $resultRedirect->setPath('*/*/edit', ['id' => $mobiapp->getId()]);
            return $resultRedirect->setPath('*/*/index');
        } catch (LocalizedException $e) {
            $this->messageManager->addErrorMessage($e->getMessage());
            return $resultRedirect->setPath('*/*/new');
        }
    }

    /**
     * ProcessIconImage function
     *
     * @param Array $data
     */
    private function processIconImage(&$data)
    {
        if (isset($data['icon']) && is_array($data['icon'])) {
            if (!empty($data['icon']['delete'])) {
                $data['icon'] = null;
            } else {
                if (isset($data['icon'][0]['name']) && isset($data['icon'][0]['tmp_name'])) {
                    $data['icon'] = $data['icon'][0]['url'];
                } else {
                    unset($data['icon']);
                }
            }
        }
    }

    /**
     * ProcessFaviconImage function
     *
     * @param Array $data
     */
    private function processFaviconImage(&$data)
    {
        if (isset($data['favicon']) && is_array($data['favicon'])) {
            if (!empty($data['favicon']['delete'])) {
                $data['favicon'] = null;
            } else {
                if (isset($data['favicon'][0]['name']) && isset($data['favicon'][0]['tmp_name'])) {
                    $data['favicon'] = $data['favicon'][0]['url'];
                } else {
                    unset($data['favicon']);
                }
            }
        }
    }
}
