<?php
/**
 * Mobicommerce
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Controller\Adminhtml\Pagebuilder;

use Magento\Backend\App\Action;

class Edit extends Action
{
    public const ADMIN_RESOURCE = 'Mobicommerce_Mobiapp::page_builder';

    /**
     * @var \Magento\Framework\View\Result\PageFactory
     */
    protected $resultPageFactory = false;

    /**
     * Newaction constructor
     *
     * @param \Action\Context $context
     * @param \Magento\Framework\View\Result\PageFactory $resultPageFactory
     * @param \Mobicommerce\Mobiapp\Model\PageBuilderFactory $pageBuilderFactory
     * @param \Magento\Framework\Registry $registry
     */
    public function __construct(
        Action\Context $context,
        \Magento\Framework\View\Result\PageFactory $resultPageFactory,
        \Mobicommerce\Mobiapp\Model\PageBuilderFactory $pageBuilderFactory,
        \Magento\Framework\Registry $registry
    ) {
        parent::__construct($context);
        $this->resultPageFactory = $resultPageFactory;
        $this->pageBuilderFactory = $pageBuilderFactory;
        $this->registry = $registry;
    }

    /**
     * Edit Pagebuilder
     */
    public function execute()
    {
        $id = $this->getRequest()->getParam('id');
        
        $pageBuilder = $this->pageBuilderFactory->create();

        if ($id) {
            $pageBuilder->load($id);
            if (!$pageBuilder->getId()) {
                $this->messageManager->addErrorMessage(__('This item no longer exists.'));
                $resultRedirect = $this->resultRedirectFactory->create();
                return $resultRedirect->setPath('*/*/');
            }
        }

        $this->registry->register('mobicommerce_page_builder', $pageBuilder);

        $resultPage = $this->resultPageFactory->create();
        $resultPage->setActiveMenu('Mobicommerce_Mobiapp::page_builder');
        $resultPage->getConfig()->getTitle()->prepend($pageBuilder->getName() ?? __('New Page Builder'));
        return $resultPage;
    }
}
