<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Controller\Adminhtml\Pagebuilder;

use Magento\Backend\App\Action;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\App\Action\HttpPostActionInterface as HttpPostActionInterface;
use Mobicommerce\Mobiapp\Model\PageBuilderFactory;
use Mobicommerce\Mobiapp\Model\PageBuilderRepository;

class Save extends Action implements HttpPostActionInterface
{
    public const ADMIN_RESOURCE = 'Mobicommerce_Mobiapp::page_builder';

    /**
     * Save constructor.
     *
     * @param Magento\Backend\App\Action\Context $context
     * @param Mobicommerce\Mobiapp\Model\PageBuilderFactory $pageBuilderFactory
     * @param Mobicommerce\Mobiapp\Model\PageBuilderRepository $pageBuilderRepository
     */
    public function __construct(
        Action\Context $context,
        PageBuilderFactory $pageBuilderFactory,
        PageBuilderRepository $pageBuilderRepository
    ) {
        parent::__construct($context);
        $this->pageBuilderFactory = $pageBuilderFactory;
        $this->pageBuilderRepository = $pageBuilderRepository;
    }

    /**
     * Save Pagebuilder
     */
    public function execute()
    {
        $resultRedirect = $this->resultRedirectFactory->create();

        $data = $this->getRequest()->getPostValue();
        if ($data) {
            if (empty($data['id'])) {
                $data['id'] = null;
            }

            $model = $this->pageBuilderFactory->create();

            $id = $this->getRequest()->getParam('id');
            if ($id) {
                try {
                    $model->load($id);
                } catch (LocalizedException $e) {
                    $this->messageManager->addErrorMessage(__('This item no longer exists.'));
                    return $resultRedirect->setPath('*/*/');
                }
            }

            try {
                $model->setData($data);
                
                if (empty($data['mobicommerce_product_collection_id'])) {
                    $model->setMobicommerceProductCollectionId(null);
                }
                
                $this->pageBuilderRepository->save($model);
                
                $this->messageManager->addSuccessMessage(__('You saved the Item.'));

                if ($this->getRequest()->getParam('back')) {
                    return $resultRedirect->setPath('*/*/edit', [
                        'id' => $model->getId(),
                        '_current' => true
                    ]);
                }
            } catch (\Exception $e) {
                $this->messageManager->addErrorMessage(__($e->getMessage()));

                return $resultRedirect->setPath('*/*/edit', [
                    'id' => $this->getRequest()->getParam('id')
                ]);
            }
        }

        return $resultRedirect->setPath('*/*/');
    }
}
