<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Controller\Adminhtml\Productcollection;

use Magento\Framework\Controller\ResultFactory;
use Magento\Backend\App\Action;
use Mobicommerce\Mobiapp\Model\ProductcollectionRepository;

class Duplicate extends Action
{
    public const ADMIN_RESOURCE = 'Mobicommerce_Mobiapp::product_collection';

    /**
     * @param Context $context
     * @param ProductcollectionRepository $productcollectionRepository
     */
    public function __construct(
        Action\Context $context,
        ProductcollectionRepository $productcollectionRepository
    ) {
        parent::__construct($context);
        $this->productcollectionRepository = $productcollectionRepository;
    }

    /**
     * Execute action
     */
    public function execute()
    {
        // check if we know what should be deleted
        $id = $this->getRequest()->getParam('id');
        /** @var \Magento\Backend\Model\View\Result\Redirect $resultRedirect */
        $resultRedirect = $this->resultRedirectFactory->create();

        if ($id) {
            try {
                $model = $this->productcollectionRepository->duplicateById($id);

                // display success message
                $this->messageManager->addSuccessMessage(__('The item has been duplicated.'));

                return $resultRedirect->setPath('*/*/edit', [
                    'id' => $model->getId()
                ]);
            } catch (\Exception $e) {
                // display error message
                $this->messageManager->addErrorMessage($e->getMessage());
                // go back to edit form
                return $resultRedirect->setPath('*/*/');
            }
        }

        // display error message
        $this->messageManager->addErrorMessage(__('We can\'t find an item to duplicate.'));

        // go to grid
        return $resultRedirect->setPath('*/*/');
    }
}
