<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Controller\Adminhtml\Productcollection;

use Magento\Backend\App\Action;

class Edit extends Action
{
    public const ADMIN_RESOURCE = 'Mobicommerce_Mobiapp::product_collection';

    /**
     * @var PageFactory
     */
    protected $resultPageFactory = false;

    /**
     * @param Context $context
     * @param PageFactory $resultPageFactory
     * @param ProductcollectionFactory $productcollectionFactory
     * @param Registry $registry
     */
    public function __construct(
        Action\Context $context,
        \Magento\Framework\View\Result\PageFactory $resultPageFactory,
        \Mobicommerce\Mobiapp\Model\ProductcollectionFactory $productcollectionFactory,
        \Magento\Framework\Registry $registry
    ) {
        parent::__construct($context);
        $this->resultPageFactory = $resultPageFactory;
        $this->productcollectionFactory = $productcollectionFactory;
        $this->registry = $registry;
    }

    /**
     * Execute action
     */
    public function execute()
    {
        $id = $this->getRequest()->getParam('id');
        
        $productcollection = $this->productcollectionFactory->create();

        if ($id) {
            $productcollection->load($id);
            if (!$productcollection->getId()) {
                $this->messageManager->addErrorMessage(__('This item no longer exists.'));
                $resultRedirect = $this->resultRedirectFactory->create();
                return $resultRedirect->setPath('*/*/');
            }
        }
        
        $productcollection->getConditions()->setFormName('mobicommerce_productcollection_form');
        $productcollection->getConditions()->setJsFormObject(
            $productcollection->getConditionsFieldSetId($productcollection->getConditions()->getFormName())
        );

        $this->registry->register('mobicommerce_productcollection', $productcollection);

        $resultPage = $this->resultPageFactory->create();
        $resultPage->setActiveMenu('Mobicommerce_Mobiapp::product_collection');
        $resultPage->getConfig()->getTitle()->prepend((__('Product Collection')));

        return $resultPage;
    }
}
