<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Controller\Adminhtml\Productcollection;

use Magento\Backend\App\Action;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\App\Action\HttpPostActionInterface as HttpPostActionInterface;
use Mobicommerce\Mobiapp\Model\ProductcollectionFactory;

class Save extends Action implements HttpPostActionInterface
{
    public const ADMIN_RESOURCE = 'Mobicommerce_Mobiapp::product_collection';

    /**
     * @param Context $context
     * @param ProductcollectionFactory $productcollectionFactory
     * @param Serializer\Json $serializer
     */
    public function __construct(
        Action\Context $context,
        ProductcollectionFactory $productcollectionFactory,
        \Magento\Framework\Serialize\Serializer\Json $serializer
    ) {
        parent::__construct($context);
        $this->productcollectionFactory = $productcollectionFactory;
        $this->serializer = $serializer;
    }

    /**
     * Execute action
     */
    public function execute()
    {
        $resultRedirect = $this->resultRedirectFactory->create();

        $data = $this->getRequest()->getPostValue();

        if ($data) {
            if (empty($data['id'])) {
                $data['id'] = null;
            }

            $model = $this->productcollectionFactory->create();

            $id = $this->getRequest()->getParam('id');
            if ($id) {
                try {
                    $model->load($id);
                } catch (LocalizedException $e) {
                    $this->messageManager->addErrorMessage(__('This item no longer exists.'));
                    return $resultRedirect->setPath('*/*/');
                }
            }

            try {
                if (isset($data['rule'])) {
                    $data['backend_conditions'] = $this->serializer->serialize(['rule' => $data['rule']]);
                    $data['conditions'] = $data['rule']['conditions'];
                    unset($data['rule']);
                }

                unset($data['conditions_serialized']);
                $model->loadPost($data);
                $data['conditions_serialized'] = $this->serializer->serialize($model->getConditions()->asArray());

                $model->setData($data);
                $model->save();
                
                $this->messageManager->addSuccessMessage(__('You saved the Item.'));

                if ($this->getRequest()->getParam('back')) {
                    return $resultRedirect->setPath('*/*/edit', [
                        'id' => $model->getId(),
                        '_current' => true
                    ]);
                }
            } catch (\Exception $e) {
                $this->messageManager->addErrorMessage(__($e->getMessage()));

                return $resultRedirect->setPath('*/*/edit', [
                    'id' => $this->getRequest()->getParam('id')
                ]);
            }
        }

        return $resultRedirect->setPath('*/*/');
    }
}
