<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Controller\Adminhtml\Section;

use Magento\Framework\Controller\ResultFactory;
use Magento\Backend\App\Action;
use Mobicommerce\Mobiapp\Model\SectionFactory;

class Delete extends Action
{
    public const ADMIN_RESOURCE = 'Mobicommerce_Mobiapp::page_builder';

    /**
     * @param Context $context
     * @param SectionFactory $sectionFactory
     */
    public function __construct(
        Action\Context $context,
        SectionFactory $sectionFactory
    ) {
        parent::__construct($context);
        $this->sectionFactory = $sectionFactory;
    }

    /**
     * Execute action
     *
     * @return \Magento\Backend\Model\View\Result\Redirect
     * @throws \Magento\Framework\Exception\LocalizedException|\Exception
     */
    public function execute()
    {
        // check if we know what should be deleted
        $id = $this->getRequest()->getParam('id');
        /** @var \Magento\Backend\Model\View\Result\Redirect $resultRedirect */
        $resultRedirect = $this->resultRedirectFactory->create();

        if ($id) {
            try {
                // init model and delete
                $model = $this->sectionFactory->create();
                $model->load($id);

                $model->delete();

                // display success message
                $this->messageManager->addSuccessMessage(__('The item has been deleted.'));

                return $resultRedirect->setPath('*/*/');
            } catch (\Exception $e) {
                // display error message
                $this->messageManager->addErrorMessage($e->getMessage());
                // go back to edit form
                return $resultRedirect->setPath('*/*/edit', ['id' => $id]);
            }
        }

        // display error message
        $this->messageManager->addErrorMessage(__('We can\'t find an item to delete.'));

        // go to grid
        return $resultRedirect->setPath('*/*/');
    }
}
