<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Controller\Adminhtml\Translation;

use Magento\Backend\App\Action;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\App\Action\HttpPostActionInterface as HttpPostActionInterface;
use Magento\Framework\Event\ManagerInterface as EventManager;
use Mobicommerce\Mobiapp\Helper\Translation as TranslationHelper;
use Mobicommerce\Mobiapp\Model\Translation as TranslationModel;

class Save extends Action implements HttpPostActionInterface
{
    public const ADMIN_RESOURCE = 'Mobicommerce_Mobiapp::translation';

    /**
     * @param Context $context
     * @param EventManager $eventManager
     * @param TranslationHelper $translationHelper
     * @param TranslationModel $translationModel
     */
    public function __construct(
        Action\Context $context,
        EventManager $eventManager,
        TranslationHelper $translationHelper,
        TranslationModel $translationModel
    ) {
        parent::__construct($context);
        $this->eventManager = $eventManager;
        $this->translationHelper = $translationHelper;
        $this->translationModel = $translationModel;
    }

    /**
     * Execute action
     */
    public function execute()
    {
        $resultRedirect = $this->resultRedirectFactory->create();

        $data = $this->getRequest()->getPostValue();
        if ($data) {
            try {
                $language = $this->getRequest()->getParam('language');
                $this->translationHelper->saveTranslationsByLocale($language, $data);
                $this->messageManager->addSuccessMessage(__('You saved the Translations.'));

                $this->eventManager->dispatch('clean_cache_by_tags', ['object' => $this->translationModel]);
            } catch (\Exception $e) {
                $this->messageManager->addErrorMessage(__($e->getMessage()));
            }
        }

        return $resultRedirect->setPath('*/*/edit');
    }
}
