<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Controller\Adminhtml\Widget;

use Magento\Backend\App\Action;

class Edit extends Action
{
    public const ADMIN_RESOURCE = 'Mobicommerce_Mobiapp::widget';

    /**
     * @var PageFactory
     */
    protected $resultPageFactory = false;

     /**
      * @param Context $context
      * @param PageFactory $resultPageFactory
      * @param WidgetFactory $widgetFactory
      * @param WidgetType $widgetType
      * @param Registry $registry
      */
    public function __construct(
        Action\Context $context,
        \Magento\Framework\View\Result\PageFactory $resultPageFactory,
        \Mobicommerce\Mobiapp\Model\WidgetFactory $widgetFactory,
        \Mobicommerce\Mobiapp\Model\Config\Source\WidgetType $widgetType,
        \Magento\Framework\Registry $registry
    ) {
        parent::__construct($context);
        $this->resultPageFactory = $resultPageFactory;
        $this->widgetFactory = $widgetFactory;
        $this->widgetType = $widgetType;
        $this->registry = $registry;
    }

    /**
     * Execute action
     */
    public function execute()
    {
        $id = $this->getRequest()->getParam('id');
        $widgetType = $this->getRequest()->getParam('type');
        
        $widget = $this->widgetFactory->create();
        $widget->setType($widgetType);
        
        if ($id) {
            $widget->load($id);
            if (!$widget->getId()) {
                $this->messageManager->addErrorMessage(__('This item no longer exists.'));
                $resultRedirect = $this->resultRedirectFactory->create();
                return $resultRedirect->setPath('*/*/');
            }

            if (empty($widgetType)) {
                $resultRedirect = $this->resultRedirectFactory->create();
                return $resultRedirect->setPath('*/*/edit', [
                    'id' => $widget->getId(),
                    'type' => $widget->getType()
                ]);
            }

            if ($widget->getType() != $widgetType) {
                $this->messageManager->addErrorMessage(__('Incorrect widget type'));
                $resultRedirect = $this->resultRedirectFactory->create();
                return $resultRedirect->setPath('*/*/');
            }
        }

        if (!$this->widgetType->isValid($widgetType)) {
            $this->messageManager->addErrorMessage(__('Incorrect widget type'));
            $resultRedirect = $this->resultRedirectFactory->create();
            return $resultRedirect->setPath('*/*/');
        }

        $this->registry->register('mobicommerce_widget', $widget);

        $resultPage = $this->resultPageFactory->create();
        $resultPage->addHandle('mobicommerce_widget_edit_' . $widgetType);
        $resultPage->setActiveMenu('Mobicommerce_Mobiapp::widget');

        $widgetTypeLabel = $this->widgetType->getLabelByType($widget->getType());
        $resultPage->getConfig()->getTitle()->prepend(
            $widget->getName() ?? __('New ' . $widgetTypeLabel . ' Widget')
        );
        return $resultPage;
    }
}
