<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Controller\Adminhtml\Widget;

use Magento\Backend\App\Action;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\App\Action\HttpPostActionInterface as HttpPostActionInterface;
use Mobicommerce\Mobiapp\Model\WidgetFactory;
use Mobicommerce\Mobiapp\Model\WidgetRepository;

class Save extends Action implements HttpPostActionInterface
{
    public const ADMIN_RESOURCE = 'Mobicommerce_Mobiapp::widget';

     /**
      * @param Context $context
      * @param WidgetFactory $widgetFactory
      * @param WidgetRepository $widgetRepository
      */
    public function __construct(
        Action\Context $context,
        WidgetFactory $widgetFactory,
        WidgetRepository $widgetRepository
    ) {
        parent::__construct($context);
        $this->widgetFactory = $widgetFactory;
        $this->widgetRepository = $widgetRepository;
    }

    /**
     * Execute action
     */
    public function execute()
    {
        $resultRedirect = $this->resultRedirectFactory->create();

        $data = $this->getRequest()->getPostValue();
        if ($data) {
            if (isset($data['general']['id'])) {
                if (empty($data['general']['id'])) {
                    $data['id'] = null;
                } else {
                    $data['id'] = $data['general']['id'];
                }
            }

            if (isset($data['id'])) {
                if (empty($data['id'])) {
                    $data['id'] = null;
                }
            }

            $model = $this->widgetFactory->create();

            $id = $this->getRequest()->getParam('id');
            if ($id) {
                try {
                    $model->load($id);
                } catch (LocalizedException $e) {
                    $this->messageManager->addErrorMessage(__('This item no longer exists.'));
                    return $resultRedirect->setPath('*/*/');
                }
            }

            try {
                $model->setData($data);

                $widgetType = $this->getRequest()->getParam('type');
                $model->setType($widgetType);
                
                $this->widgetRepository->save($model);
                
                $this->messageManager->addSuccessMessage(__('You saved the Item.'));

                if ($this->getRequest()->getParam('back')) {
                    return $resultRedirect->setPath('*/*/edit', [
                        'id' => $model->getId(),
                        '_current' => true
                    ]);
                }
            } catch (\Exception $e) {
                $this->messageManager->addErrorMessage(__($e->getMessage()));

                return $resultRedirect->setPath('*/*/edit', [
                    'id' => $this->getRequest()->getParam('id')
                ]);
            }
        }

        return $resultRedirect->setPath('*/*/');
    }
}
