<?php
/**
 * Mobicommerce
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Helper;

use Magento\Framework\App\ResourceConnection;

class CmsPage
{
    public const TBL_WIDGET_MAPPING = 'mobicommerce_cmspage_seo_widget_mapping';

    /**
     * @param ResourceConnection $resourceConnection
     */
    public function __construct(
        ResourceConnection $resourceConnection
    ) {
        $this->resourceConnection = $resourceConnection;
    }

    /**
     * GetMobicommerceSeoWidgets function
     *
     * @param Int $pageId
     */
    public function getMobicommerceSeoWidgets($pageId)
    {
        $connection = $this->resourceConnection->getConnection();
        $table = $this->resourceConnection->getTableName(self::TBL_WIDGET_MAPPING);

         $select = $connection->select()
            ->from(
                ['mapping' => $table],
                ['GROUP_CONCAT(widget_id ORDER BY position ASC) AS mobicommerce_seo_widget_ids']
            )->where('cms_page_id = ?', $pageId);

        return $connection->fetchOne($select);
    }

    /**
     * GetMobicommerceSeoWidgetsCollection function
     *
     * @param Collection $collection
     */
    public function getMobicommerceSeoWidgetsCollection($collection)
    {
        $table = $this->resourceConnection->getTableName(self::TBL_WIDGET_MAPPING);
        $collection->getSelect()->joinLeft(
            ['mapping' => $table],
            'mapping.cms_page_id = main_table.page_id',
            [new \Zend_Db_Expr(
                'GROUP_CONCAT(mapping.widget_id ORDER BY mapping.position ASC) AS mobicommerce_seo_widget_ids'
            )]
        )->group('main_table.page_id');

        return $collection;
    }
}
