<?php
namespace Mobicommerce\Mobiapp\Helper;
use Magento\Framework\Filesystem;
use Magento\Framework\Filesystem\Io\File;
use Magento\Framework\Module\Dir\Reader;
use Magento\Framework\App\Filesystem\DirectoryList;
use Magento\Framework\Xml\Parser;
use Mobicommerce\Mobiapp\Helper\Translation;
class LanguageFile extends \Magento\Framework\App\Helper\AbstractHelper {

	protected $driverFile;

	public function __construct(
	   \Magento\Framework\App\Helper\Context $context,
       \Magento\Framework\Filesystem\Driver\File $driverFile,
       Filesystem $filesystem,
       File $filesystemIo,
       Reader $reader,
       Parser $parser,
       Translation $translationHelper
) {
    $this->translationHelper = $translationHelper;
    $this->parser = $parser;
    $this->driverFile = $driverFile;
    $this->filesystem = $filesystem;
    $this->filesystemIo = $filesystemIo;
    $this->moduleReader = $reader;
   
    parent::__construct($context);
}

	public function getDirectory($filePath = "") {
		$etcDir = $this->moduleReader->getModuleDir(
			\Magento\Framework\Module\Dir::MODULE_ETC_DIR,
			'Mobicommerce_Mobiapp'
		);
		return $etcDir . $filePath;
	}

	public function getModuleDirectory($moduleName,$filePath = "") {
		$etcDir = $this->moduleReader->getModuleDir(
			\Magento\Framework\Module\Dir::MODULE_ETC_DIR,
			$moduleName
		);
		return $etcDir . $filePath;
	}

	


	function copyLangFiles($moduleName)
	{

		
		$base_translation = $this->getDirectory('/translations');
        
        $module_assets = $this->getModuleDirectory($moduleName,'/translations');

		//$mediapath = $this->filesystem->getDirectoryRead(DirectoryList::MEDIA)->getAbsolutePath();
		//$mobi_assets = $mediapath."/mobi_assets/multilanguage/v3";

		$mobi_assets = $base_translation;

		$array = $this->driverFile->readDirectory($mobi_assets);

		foreach($array as $key=>$file)
		{
			$file_name = str_replace($mobi_assets."/", "", $file);
			$file = explode(".", $file_name);

			if(count($file)==2 && $file[1]=="xml")
			{

				$local = $file[0];
				if(in_array($local, array('af_ZA', 'sq_AL', 'ar_DZ', 'ar_EG', 'ar_KW', 'ar_MA', 'ar_SA', 'az_Latn_AZ', 'bn_BD', 'eu_ES', 'be_BY', 'bs_Latn_BA', 'bg_BG', 'ca_ES', 'zh_Hans_CN', 'zh_Hant_HK', 'zh_Hant_TW' ,'hr_HR', 'cs_CZ', 'da_DK', 'nl_BE', 'nl_NL', 'en_AU', 'en_CA', 'en_IE', 'en_NZ', 'en_GB', 'en_US', 'et_EE', 'fil_PH', 'fi_FI', 'fr_BE', 'fr_CA', 'fr_FR', 'fr_LU', 'fr_CH', 'gl_ES', 'ka_GE', 'de_AT', 'de_DE', 'de_LU', 'de_CH', 'el_GR', 'gu_IN', 'he_IL', 'hi_IN', 'hu_HU', 'is_IS', 'id_ID', 'it_IT', 'it_CH', 'ja_JP', 'km_KH', 'ko_KR', 'lo_LA', 'lv_LV', 'lt_LT', 'mk_MK', 'ms_MY', 'nb_NO', 'nn_NO', 'fa_IR', 'pl_PL', 'pt_BR', 'pt_PT', 'ro_RO', 'ru_RU', 'sr_Cyrl_RS', 'sr_Latn_RS','sk_SK', 'sl_SI', 'es_AR', 'es_BO', 'es_CL', 'es_CO', 'es_CR', 'es_MX', 'es_PA', 'es_PE', 'es_ES', 'es_US', 'es_VE', 'sw_KE', 'sv_FI', 'sv_SE', 'th_TH', 'tr_TR', 'uk_UA', 'vi_VN', 'cy_GB')))
					{
						$this->copyFile($local,$mobi_assets."/",$module_assets."/");
					}	
			}
		}
	}

    protected function copyFile($locale,$mobiAssetsPath,$moduleAssetsPath)
	{
        $baseXml = $mobiAssetsPath . $locale . '.xml';
       
        $moduleXml = $moduleAssetsPath . $locale . '.xml';

		if(!$this->driverFile->isExists($baseXml) || !$this->driverFile->isReadable($baseXml) || !$this->driverFile->isWritable($baseXml))
		{
				return false;
		}

        if(!$this->driverFile->isExists($moduleXml) || !$this->driverFile->isReadable($moduleXml))
		{
			$moduleXml = $moduleAssetsPath . "en_US" . '.xml';
		}

        $baseXmldata = simplexml_load_file($baseXml);

        $languageArray = [];
		
        foreach ($baseXmldata as $_key => $items) {	
            
            foreach ($items as $_code => $_node) {	
                    if(is_array($_node))
                    {
                        $_node=$_node[0];  
                    }		
                    $languageArray[$_code] = $_node;		
                }	
		}


       
		$moduleXmldata = simplexml_load_file($moduleXml);   

		foreach ($moduleXmldata as $_key => $items) {	
            
            foreach ($items as $_code => $_node) {	
                    if(is_array($_node))
                    {
                        $_node=$_node[0];  
                    }		
                    $languageArray[$_code] = $_node;		
                }	
		}	


        $newbaseXml = $mobiAssetsPath . $locale . '.xml';
        $this->writeBaseXml($languageArray,$newbaseXml);
       



    }    

    protected function writeBaseXml($languageArray,$baseXml)
    {
       
        $doc = new \DOMDocument('1.0', 'utf-8');
		$doc->formatOutput = true;

		
        $config = $doc->createElement('config');
        $config = $doc->appendChild($config);
        $root = $doc->createElement('items');
		$root = $config->appendChild($root);

        foreach ($languageArray as $_key => $node) {
			$optioncodenode = $doc->createElement($_key);
			$newdoc = $root->appendChild($optioncodenode);

			$em = $doc->createElement('type');
			$text = $doc->createTextNode($node->type);
			$em->appendChild($text);
			$newdoc->appendChild($em);

			$em = $doc->createElement('label');
			$text = $doc->createTextNode($node->label);
			$em->appendChild($text);
			$newdoc->appendChild($em);

			$em = $doc->createElement('max_length');
			$text = $doc->createTextNode($node->max_length);
			$em->appendChild($text);
			$newdoc->appendChild($em);

            $em = $doc->createElement('value');
			$text = $doc->createTextNode($node->value);
			$em->appendChild($text);
			$newdoc->appendChild($em);

			$em = $doc->createElement('help');
			$text = $doc->createTextNode($node->help);
			$em->appendChild($text);
			$newdoc->appendChild($em);
		}
		$doc->save($baseXml);
    }

    protected function copyFilebk($locale,$mobiAssetsPath,$moduleAssetsPath)
	{



		$doc = new \DOMDocument('1.0');
		$doc->formatOutput = true;
		$root = $doc->createElement('mobicommerce_multilanguage');
		$root = $doc->appendChild($root);


		$xml = $mobiAssetsPath . $locale . '.xml';
		if(!$this->driverFile->isExists($xml) || !$this->driverFile->isReadable($xml) || !$this->driverFile->isWritable($xml))
		{
				return false;
		}
		
		$xmldata = simplexml_load_file($xml);

		$childxml = $mobiAssetsPath . $locale . '.xml';

		$languageArray = [];
		foreach ($xmldata as $_key => $_data) {			
			$languageArray[$_key] = $_data;			
		}

		$xml = $moduleAssetsPath . $locale . '.xml';
		if(!$this->driverFile->isExists($xml) || !$this->driverFile->isReadable($xml))
		{
			$xml = $moduleAssetsPath . "en_US" . '.xml';
		}
		$xmldata = simplexml_load_file($xml);


		

		foreach ($xmldata as $_key => $_data) {			
			$languageArray[$_key] = $_data;			
		}	

		foreach ($languageArray as $_key => $node) {
			$optioncodenode = $doc->createElement($_key);
			$newdoc = $root->appendChild($optioncodenode);

			$em = $doc->createElement('mm_text');
			$text = $doc->createTextNode($node->mm_text);
			$em->appendChild($text);
			$newdoc->appendChild($em);


			$em = $doc->createElement('mm_type');
			$text = $doc->createTextNode($node->mm_type);
			$em->appendChild($text);
			$newdoc->appendChild($em);


			$em = $doc->createElement('mm_label');
			$text = $doc->createTextNode($node->mm_label);
			$em->appendChild($text);
			$newdoc->appendChild($em);

			$em = $doc->createElement('mm_maxlength');
			$text = $doc->createTextNode($node->mm_maxlength);
			$em->appendChild($text);
			$newdoc->appendChild($em);

			$em = $doc->createElement('mm_help');
			$text = $doc->createTextNode($node->mm_help);
			$em->appendChild($text);
			$newdoc->appendChild($em);



		}



		$doc->save($childxml);


	}


	
}
