<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Helper;

use \Magento\Framework\App\Config\ScopeConfigInterface;
use \Magento\Store\Model\ScopeInterface;

class StaticFiles
{
    /**
     * @param Context $context
     * @param StoreManagerInterface $storeManager
     * @param Filesystem $fileSystem
     * @param DirectoryList $dir
     * @param File $driverFile
     * @param ScopeConfigInterface $scopeConfig
     * @param ListsInterface $localeLists
     */
    public function __construct(
        \Magento\Framework\Model\Context $context,
        \Magento\Store\Model\StoreManagerInterface $storeManager,
        \Magento\Framework\Filesystem $fileSystem,
        \Magento\Framework\Filesystem\DirectoryList $dir,
        \Magento\Framework\Filesystem\Driver\File $driverFile,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        \Magento\Framework\Locale\ListsInterface $localeLists
    ) {
        $this->scopeConfig = $scopeConfig;
        $this->_storeManager = $storeManager;
        $this->fileSystem = $fileSystem;
        $this->_dir = $dir;
        $this->driverFile = $driverFile;
        $this->localeLists = $localeLists;
    }
 
    /**
     * WriteAllStoreJs function
     */
    public function writeAllStoreJs()
    {
        $storeViews = $this->getAllStoreViews();
        $websites = $this->addWebsiteData();
        $introPopup = $this->addIntroPopupData();
        $storeFilePath = $this->_dir->getPath("media") . '/all_stores.js';
        $fp = $this->driverFile->fileOpen($storeFilePath, 'w+');
        $store_code = $this->_storeManager->getStore()->getCode();
        $this->driverFile->fileWrite($fp, "var stores = ".json_encode($storeViews).";");
        $this->driverFile->fileWrite($fp, "var websites = ".json_encode($websites).";");
        $this->driverFile->fileWrite($fp, "var server_store_code = ".json_encode($store_code).";");
        $this->driverFile->fileWrite($fp, "var intro_popup = ".json_encode($introPopup).";");
        $this->driverFile->fileClose($fp);
    }

    /**
     * GetAllStoreViews function
     *
     * @param Array $data
     */
    public function getAllStoreViews($data = [])
    {
        $AllStores = $this->_storeManager->getStores();
        foreach ($AllStores as $store) {
            if ($store->getIsActive() == '1') {
                $data[] = $this->processStore($store);
            }
        }
        return $data;
    }

    /**
     * ProcessStore function
     *
     * @param Store $store
     * @param Array $data
     */
    public function processStore($store = null, $data = [])
    {
        $data = $store->getData();
        $data['base_url'] = $this->getStoreConfig('web/unsecure/base_url', $store->getId());
        $data['base_secure_url'] = $this->getStoreConfig('web/secure/base_url', $store->getId());
        $data['config'] = [
            'web_url_use_store' => $this->getStoreConfig('web/url/use_store', $store->getId()),
            'default_country' => $this->getStoreConfig('general/country/default', $store->getId()),
            'display_state' => $this->getStoreConfig('general/region/display_all', $store->getId()),
        ];
        $data['root_category_id'] = $store->getRootCategoryId();
        $data['group_name'] = $store->getGroup()->getName();
        $data['website_name'] = $store->getWebsite()->getName();
        $data['language'] = $this->getStoreConfig('general/locale/code', $store->getId());
        $locale = $this->getStoreConfig('general/locale/code', $store->getId());
        if (strpos($locale, 'ar_') !== false || strpos($locale, 'fa_') !== false) {
                $data['rtl'] = '1';
        } else {
            $data['rtl'] = '0';
        }
        return $data;
    }
    /**
     * GetStoreConfig function
     *
     * @param String $path
     * @param Store $store
     * @param SCOPE_STORE $scope
     */
    public function getStoreConfig($path = '', $store = null, $scope = ScopeInterface::SCOPE_STORE)
    {
        $data = $this->scopeConfig->getValue($path, $scope, $store);
        return $data;
    }

    /**
     * GetLocaleLabel function
     *
     * @param String $locale
     */
    public function getLocaleLabel($locale)
    {
        $locales = $this->localeLists->getOptionLocales();
        foreach ($locales as $_locale) {
            if ($_locale['value'] == $locale) {
                return $_locale['label'];
            }
        }
        return "";
    }

    /**
     * AddWebsiteData function
     *
     * @param Array $data
     */
    public function addWebsiteData($data = [])
    {
        $module_status = $this->getStoreConfig('mobi_multiwebsite/general/is_enable');
        $gmpmodule_status = $this->getStoreConfig('mobi_advance/modules_features/gmp');
        $is_store_landing = $this->getStoreConfig('mobi_multiwebsite/config/is_store_landing');
        $store_cms_page = $this->getStoreConfig('mobi_multiwebsite/config/store_cms_page');
        $mc_reward_status = $this->getStoreConfig('mobi_advance/modules_features/reward');
        $mc_group_price = $this->getStoreConfig('mobi_advance/modules_features/cust_group_price');
        $data['mc_mw_enable'] = $module_status;
        $data['mc_mw_is_store_landing'] = $is_store_landing;
        $data['mc_mw_store_cms_page'] = $store_cms_page;
        $data['mc_gmp_enable'] = $gmpmodule_status;
        $data['mc_reward'] = $mc_reward_status;
        $data['mc_group_price'] = $mc_group_price;
        return $data;
    }
    public function addIntroPopupData($data = [])
    {

        $mobileApp = [];
        $pwa = [];
        $desktop = [];
       
        $allStores = $this->_storeManager->getStores();

        foreach ($allStores as $store) {

            // $locale = $this->getStoreConfig('general/locale/code', $store->getId());
            $locale = $store->getCode();
            
             /* Mobile APP */
            $mobileApp['status'] = $this->getStoreConfig('intro_popup/mobileapp/status', $store->getId());
            $mobileApp['type'] = $this->getStoreConfig('intro_popup/mobileapp/type', $store->getId());
            $mobileApp['landingpageid'] = $this->getStoreConfig('intro_popup/mobileapp/landing_page', $store->getId());
            $mobileApp['auto_close_timer'] = $this->getStoreConfig('intro_popup/mobileapp/auto_close_time', $store->getId());
            /* Mobile APP */

            /* PWA */
            $pwa['status'] = $this->getStoreConfig('intro_popup/pwa/status', $store->getId());
            $pwa['type'] = $this->getStoreConfig('intro_popup/pwa/type', $store->getId());
            $pwa['landingpageid'] = $this->getStoreConfig('intro_popup/pwa/landing_page', $store->getId());
            $pwa['auto_close_timer'] = $this->getStoreConfig('intro_popup/pwa/auto_close_time', $store->getId());
            /* PWA */  

            /* Desktop */
            $desktop['status'] = $this->getStoreConfig('intro_popup/desktop/status', $store->getId());
            $desktop['type'] = $this->getStoreConfig('intro_popup/desktop/type', $store->getId());
            $desktop['landingpageid'] = $this->getStoreConfig('intro_popup/desktop/landing_page', $store->getId());
            $desktop['auto_close_timer'] = $this->getStoreConfig('intro_popup/desktop/auto_close_time', $store->getId());
            /* Desktop */

            $data['mobileapp'][$locale] = $mobileApp;
            $data['pwa'][$locale] = $pwa;
            $data['desktop'][$locale] = $desktop;


        }
        
        return $data;
    }
}
