<?php
/**
 * Mobicommerce
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Model\Config\Source;

use Magento\Framework\Data\OptionSourceInterface;

class FirstLevelCategories implements OptionSourceInterface
{
    /**
     * FirstLevelCategories constructor.
     *
     * @param \Magento\Framework\App\RequestInterface $request
     * @param \Magento\Store\Model\StoreManagerInterface $storeManager
     * @param \Magento\Catalog\Model\CategoryFactory $categoryFactory
     */
    public function __construct(
        \Magento\Framework\App\RequestInterface $request,
        \Magento\Store\Model\StoreManagerInterface $storeManager,
        \Magento\Catalog\Model\CategoryFactory $categoryFactory
    ) {
        $this->request = $request;
        $this->storeManager = $storeManager;
        $this->categoryFactory = $categoryFactory;
    }

    /**
     * Convert to Array
     *
     * @return object
     */
    public function toOptionArray()
    {
        $result = [];

        $storeId = $this->request->getParam('store');
        $group = $this->storeManager->getStore($storeId)->getGroup();
        $rootCategoryId = $group->getRootCategoryId();
        $category = $this->categoryFactory->create()->load($rootCategoryId);
        $childrenCategories = $category->getChildrenCategories();

        if ($childrenCategories) {
            foreach ($childrenCategories as $child) {
                $result[] = [
                    'value' => $child->getId(),
                    'label' => $child->getName()
                ];
            }
        }

        return $result;
    }
}
