<?php
/**
 * Mobicommerce
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Model\Config\Source;

use Magento\Framework\Data\OptionSourceInterface;
use Magento\Framework\App\RequestInterface;
use Magento\Catalog\Model\CategoryFactory;

class StoreViewFirstLevelCategories implements OptionSourceInterface
{
    /**
     * StoreViewFirstLevelCategories constructor.
     *
     * @param Magento\Framework\App\RequestInterface $request
     * @param \Magento\Store\Model\StoreManagerInterface $storeManager
     * @param Magento\Catalog\Model\CategoryFactory $categoryFactory
     */
    public function __construct(
        RequestInterface $request,
        \Magento\Store\Model\StoreManagerInterface $storeManager,
        CategoryFactory $categoryFactory
    ) {
        $this->request = $request;
        $this->storeManager = $storeManager;
        $this->categoryFactory = $categoryFactory;
    }

    /**
     * Convert to Array
     *
     * @return object
     */
    public function toOptionArray()
    {
        $result = [];

        $storeId = $this->request->getParam('store', false);
        if ($storeId) {
            $store = $this->storeManager->getStore($storeId);
            $rootCategoryId = $store->getRootCategoryId();
            $rootCategory = $this->categoryFactory->create()->load($rootCategoryId);
            $categories = $rootCategory->getChildrenCategories();
            if ($categories) {
                foreach ($categories as $item) {
                    $result[] = [
                        'value' => $item->getId(),
                        'label' => $item->getName()
                    ];
                }
            }
        }

        return $result;
    }
}
