<?php
/**
 * Mobicommerce
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Model;

use Mobicommerce\Mobiapp\Api\MobiappRepositoryInterface;
use Magento\Framework\Exception\LocalizedException;
use Mobicommerce\Mobiapp\Model\ResourceModel\Mobiapp\CollectionFactory;
use Magento\Framework\Notification\NotifierInterface as NotifierPool;

class MobiappRepository implements
    MobiappRepositoryInterface
{
    /**
     * MobiappRepository constructor.
     *
     * @param Mobicommerce\Mobiapp\Model\ResourceModel\Mobiapp\CollectionFactory $collectionFactory
     * @param Magento\Framework\Notification\NotifierInterface $notifierPool
     */
    public function __construct(
        CollectionFactory $collectionFactory,
        NotifierPool $notifierPool
    ) {
        $this->collectionFactory = $collectionFactory;
        $this->notifierPool = $notifierPool;
    }

     /**
      * Get Appbycodekey
      *
      * @param string $appcode
      * @param string $appkey
      * @return array
      */
    private function getAppByCodeKey($appcode, $appkey)
    {
        $collection = $this->collectionFactory->create();
        $collection->addFieldToFilter('appcode', $appcode)
            ->addFieldToFilter('appkey', $appkey);

        return $collection;
    }

    /**
     * Check isonline
     *
     * @return boolean
     */
    public function isOnline()
    {
        return true;
    }

    /**
     * Push information from server
     *
     * @param string $appcode
     * @param string $appkey
     * @param array $params
     * @return boolean
     */
    public function pushInformationFromMobiServer($appcode, $appkey, $params)
    {
        $collection = $this->getAppByCodeKey($appcode, $appkey);

        if ($collection->getSize() > 0) {
            foreach ($collection as $item) {
                foreach ($params->getData() as $key => $value) {
                    if ($value) {
                        $item->setData($key, $value);
                    }
                }

                $item->save();

                $this->notifierPool->addNotice(
                    'Mobicommerce Update',
                    "Your application with appkey: " . $appkey . " has been updated"
                );
            }
        } else {
            throw new LocalizedException(__('Invalid appcode or appkey passed'));
        }

        return true;
    }

    /**
     * Delete mobiapp
     *
     * @param string $appcode
     * @param string $appkey
     * @return boolean
     */
    public function deleteMobiapp($appcode, $appkey)
    {
        $collection = $this->getAppByCodeKey($appcode, $appkey);

        if ($collection->getSize() > 0) {
            foreach ($collection as $item) {
                $item->delete();
            }
        } else {
            throw new LocalizedException(__('Invalid appcode or appkey passed'));
        }

        return true;
    }
}
