<?php
/**
 * Mobicommerce
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Model;

use Magento\Framework\DataObject\IdentityInterface;
use Magento\Framework\Model\AbstractModel;

class Section extends AbstractModel implements IdentityInterface
{
    /**
     * Mobiapp cache tag
     */
    public const CACHE_TAG = 'mobicommerce_section';

    /**
     * @var string
     */
    protected $_cacheTag = self::CACHE_TAG;

    /**
     * Prefix of model events names
     *
     * @var string
     */
    protected $_eventPrefix = self::CACHE_TAG;

    /**
     * Initialize resource model
     *
     * @return void
     */
    protected function _construct()
    {
        $this->_init(
            \Mobicommerce\Mobiapp\Model\ResourceModel\Section::class
        );
    }

    /**
     * Get identities
     *
     * @return array
     */
    public function getIdentities()
    {
        return [self::CACHE_TAG . '_' . $this->getId()];
    }

    /**
     * Get Widgets Data
     *
     * @return array
     */
    public function getWidgetsData()
    {
        $result = [];
        
        $sectionId = $this->getId();
        if ($sectionId) {
            $connection = $this->_getResource()->getConnection();
            $table = $this->_getResource()->getTable("mobicommerce_section_widget_mapping");
            $select = $connection->select()
                ->from(
                    ['mapping' => $table]
                )->join(
                    ['mobicommerce_widget' => $this->_getResource()->getTable('mobicommerce_widget')],
                    'mobicommerce_widget.id=mapping.widget_id'
                )->where('section_id = ?', $sectionId)
                ->order('position ASC');
                
            $result = $connection->fetchAll($select);
        }

        return $result;
    }
}
