<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Observer;

use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\Event\Observer;
use Magento\Framework\App\ResourceConnection;

class CmsPageSeoWidgetsProcess implements ObserverInterface
{
    public const TBL_WIDGET_MAPPING = 'mobicommerce_cmspage_seo_widget_mapping';

    /**
     * @param ResourceConnection $resourceConnection
     */
    public function __construct(
        ResourceConnection $resourceConnection
    ) {
        $this->resourceConnection = $resourceConnection;
    }

    /**
     * Execute action
     *
     * @param Observer $observer
     */
    public function execute(Observer $observer)
    {
        $page = $observer->getEvent()->getObject();
        
        $connection = $this->resourceConnection->getConnection();
        $table = $this->resourceConnection->getTableName(self::TBL_WIDGET_MAPPING);

        $dynamicRowsField = 'mobicommerce_seo_widgets_dynamic_rows';
        if ($seoWidgets = $page->getData($dynamicRowsField)) {
            $seoWidgets = $seoWidgets[$dynamicRowsField] ?? false;

            if ($seoWidgets) {
                $allWidgetIds = [];
                foreach ($seoWidgets as $row) {
                    $widgetId = $row['id'];
                    $position = $row['position'];

                    $allWidgetIds[] = $widgetId;

                    $select = $connection->select()
                        ->from(
                            ['mapping' => $table]
                        )->where('cms_page_id = ?', $page->getId())
                        ->where('widget_id = ?', $widgetId);

                    if ($record = $connection->fetchRow($select)) {
                        if ($record['position'] != $position) {
                            $connection->update($table, [
                                'position' => $position
                            ], [
                                'cms_page_id = ?' => $page->getId(),
                                'widget_id = ?' => $widgetId
                            ]);
                        }
                    } else {
                        $connection->insert($table, [
                            'cms_page_id' => $page->getId(),
                            'widget_id' => $widgetId,
                            'position' => $position
                        ]);
                    }
                }
                
                $connection->delete($table, [
                    'cms_page_id = ?' => $page->getId(),
                    'widget_id NOT IN (?)' => $allWidgetIds
                ]);
            }

            $page->unsetData($dynamicRowsField);
        } else {
            $connection->delete($table, [
                "cms_page_id = ?" => $page->getId()
            ]);
        }
    }
}
