<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Observer;

use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\Event\Observer;
use Mobicommerce\Mobiapp\Helper\Config as ConfigHelper;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\UrlInterface;
use Magento\Framework\App\Config\ScopeConfigInterface;

class CreateMobiappOnMobiServerObserver implements ObserverInterface
{
    /**
     * @param StoreManagerInterface $storeManager
     * @param ScopeConfigInterface $scopeConfig
     * @param Curl $curl
     * @param Json $json
     * @param Request $request
     * @param RemoteAddress $remoteAddress
     */
    public function __construct(
        \Magento\Store\Model\StoreManagerInterface $storeManager,
        ScopeConfigInterface $scopeConfig,
        \Magento\Framework\HTTP\Client\Curl $curl,
        \Magento\Framework\Serialize\Serializer\Json $json,
        \Magento\Framework\HTTP\PhpEnvironment\Request $request,
        \Magento\Framework\HTTP\PhpEnvironment\RemoteAddress $remoteAddress
    ) {
        $this->storeManager = $storeManager;
        $this->scopeConfig = $scopeConfig;
        $this->curl = $curl;
        $this->json = $json;
        $this->request = $request;
        $this->remoteAddress = $remoteAddress;
    }

    /**
     * Execute action
     *
     * @param Observer $observer
     */
    public function execute(Observer $observer)
    {
        $mobiapp = $observer->getEvent()->getDataObject();

        if ($mobiapp && $mobiapp->isObjectNew()) {
            $this->createMobiappOnMobiServer($mobiapp);
        }
    }

    /**
     * CreateMobiappOnMobiServer method
     *
     * @param String $mobiapp
     */
    private function createMobiappOnMobiServer($mobiapp)
    {
        $url = ConfigHelper::MOBICOMMERCE_SERVER_DOMAIN . "build/add";
        $params = $this->prepareParams($mobiapp);

        $this->curl->post($url, $params);
        $response = $this->curl->getBody();
        $response = $this->json->unserialize($response);
        
        $status = $response['status'] ?? 'error';
        $message = $response['message'] ?? 'Something went wrong, try after some time';
        if ($status == 'success') {
            $mobiapp->setAppkey($response['data']['appkey']);
            $mobiapp->setAppcode($response['data']['appcode']);
            $mobiapp->setMobiServerSuccessMessage($message);
        } else {
            throw new LocalizedException(__($message));
        }
    }

     /**
      * PrepareParams method

      * @param String $mobiapp
      */
    public function prepareParams($mobiapp)
    {
        $params = [
            "appname" => $mobiapp->getName(),
            "app_shortname" => $mobiapp->getName(),
            "apptheme" => "shopper",
            "theme_android" => "shopper",
            "theme_ios" => "shopper",
            "primary_theme" => $mobiapp->getPrimaryColor(),
            "secondary_theme" => $mobiapp->getSecondaryColor(),
            "primaryemail" => "admin@gmail.com",
            "phone_country_code" => "91",
            "phone" => "9756856321",
            "app_type" => $mobiapp->getType(),
            "store" => $mobiapp->getDefaultStoreview(),
            "email" => "admin@gmail.com",
            "appicon" => $mobiapp->getIcon(),
            "appsplash" => $mobiapp->getSplash(),
            "favicon" => $mobiapp->getFavicon(),
            "approoturl" => $this->storeManager->getStore(
                $mobiapp->getDefaultStoreview()
            )->getBaseUrl(UrlInterface::URL_TYPE_WEB),
            "media_url" => $this->storeManager->getStore(
                $mobiapp->getDefaultStoreview()
            )->getBaseUrl(UrlInterface::URL_TYPE_MEDIA),
            "applicencekey" => "",
            "backend_platform" => "magento",
            "venture" => ConfigHelper::VENTURE,
            "ipaddress" => $this->remoteAddress->getRemoteAddress(),
            "deeplink_hostname" => $this->request->getServer('HTTP_HOST'),
            "configurations" => [
                "connectorVersionCode" => ConfigHelper::CONNECTION_VERSION,
                "max_execution_time" => ini_get('max_execution_time'),
                "max_input_time" => ini_get('max_input_time'),
                "add_store_code_to_urls" => $this->scopeConfig->getValue('web/url/use_store'),
                "default_store_code" => $this->storeManager->getStore(
                    $mobiapp->getDefaultStoreview()
                )->getCode(),
                "mobicommerce_version" => ConfigHelper::MOBICOMMERCE_VERSION,
                "global_extensions" => "rtl-view",
                "onesignal_appid" => ConfigHelper::ONESIGNAL_APPID,
                "gcm_sender_id" => ConfigHelper::GCM_SENDER_ID
            ],
            'splash_screen_bg_color'     => '#FFFFFF',
            'splash_screenicon_bg_color' => '#FFFFFF',
            'pwa_last_build'             => date('Y-m-d H:i:s'),
            'desktop_last_build'         => date('Y-m-d H:i:s'),
            'app_last_build'             => date('Y-m-d H:i:s')
        ];

        return $params;
    }
}
