<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Observer;

use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\Event\Observer;
use Magento\Framework\App\ResourceConnection;

class PageBuilderDuplicateDefaultSubData implements ObserverInterface
{
    public const TBL_CATEGORY_MAPPING = 'mobicommerce_page_builder_category_mapping';
    public const TBL_LINK_BUILDER_WIDGET_MAPPING = 'mobicommerce_page_builder_link_builder_widget_mapping';
    public const TBL_SECTION_MAPPING = 'mobicommerce_page_builder_section_mapping';

    /**
     * @param ResourceConnection $resourceConnection
     */
    public function __construct(
        ResourceConnection $resourceConnection
    ) {
        $this->resourceConnection = $resourceConnection;
    }

    /**
     * Execute action
     *
     * @param Observer $observer
     */
    public function execute(Observer $observer)
    {
        $id = $observer->getEvent()->getId();
        $pagebuilder = $observer->getEvent()->getPagebuilder();

        $this->duplicateCategoryMapping($id, $pagebuilder);
        $this->duplicateLinkBuilderWidgetMapping($id, $pagebuilder);
        $this->duplicateSectionMapping($id, $pagebuilder);
    }

     /**
      * DuplicateCategoryMapping method
      *
      * @param Array $id
      * @param Object $pagebuilder
      */
    public function duplicateCategoryMapping($id, $pagebuilder)
    {
        $table = $this->resourceConnection->getTableName(self::TBL_CATEGORY_MAPPING);
        $connection = $this->resourceConnection->getConnection();

        $select = $connection->select()
            ->from(
                ['mapping' => $table]
            )->where('page_builder_id = ?', $id);

        $result = $connection->fetchAll($select);
        if ($result) {
            $bulkInsert = [];
            foreach ($result as $item) {
                $item['page_builder_id'] = $pagebuilder->getId();
                unset($item['mapping_id']);

                $bulkInsert[] = $item;
            }

            $connection->insertMultiple($table, $bulkInsert);
        }
    }

     /**
      * DuplicateLinkBuilderWidgetMapping method
      *
      * @param Int $id
      * @param Int $pagebuilder
      */
    public function duplicateLinkBuilderWidgetMapping($id, $pagebuilder)
    {
        $table = $this->resourceConnection->getTableName(self::TBL_LINK_BUILDER_WIDGET_MAPPING);
        $connection = $this->resourceConnection->getConnection();

        $select = $connection->select()
            ->from(
                ['mapping' => $table]
            )->where('page_builder_id = ?', $id);

        $result = $connection->fetchAll($select);
        if ($result) {
            $bulkInsert = [];
            foreach ($result as $item) {
                $item['page_builder_id'] = $pagebuilder->getId();
                unset($item['mapping_id']);

                $bulkInsert[] = $item;
            }

            $connection->insertMultiple($table, $bulkInsert);
        }
    }

     /**
      * DuplicateSectionMapping method
      *
      * @param Int $id
      * @param Int $pagebuilder
      */
    public function duplicateSectionMapping($id, $pagebuilder)
    {
        $table = $this->resourceConnection->getTableName(self::TBL_SECTION_MAPPING);
        $connection = $this->resourceConnection->getConnection();

        $select = $connection->select()
            ->from(
                ['mapping' => $table]
            )->where('page_builder_id = ?', $id);

        $result = $connection->fetchAll($select);
        if ($result) {
            $bulkInsert = [];
            foreach ($result as $item) {
                $item['page_builder_id'] = $pagebuilder->getId();
                unset($item['mapping_id']);

                $bulkInsert[] = $item;
            }

            $connection->insertMultiple($table, $bulkInsert);
        }
    }
}
