<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Observer;

use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\Event\Observer;
use Magento\Framework\App\ResourceConnection;

class SectionDuplicateDefaultSubData implements ObserverInterface
{
    public const TBL_WIDGET_MAPPING = 'mobicommerce_section_widget_mapping';

    /**
     * @param ResourceConnection $resourceConnection
     */
    public function __construct(
        ResourceConnection $resourceConnection
    ) {
        $this->resourceConnection = $resourceConnection;
    }

    /**
     * Execute action
     *
     * @param Observer $observer
     */
    public function execute(Observer $observer)
    {
        $id = $observer->getEvent()->getId();
        $section = $observer->getEvent()->getSection();

        $this->duplicateWidgetMapping($id, $section);
    }

    /**
     * DuplicateWidgetMapping method
     *
     * @param Int $id
     * @param Int $section
     */
    public function duplicateWidgetMapping($id, $section)
    {
        $table = $this->resourceConnection->getTableName(self::TBL_WIDGET_MAPPING);
        $connection = $this->resourceConnection->getConnection();

        $select = $connection->select()
            ->from(
                ['mapping' => $table]
            )->where('section_id = ?', $id);

        $result = $connection->fetchAll($select);
        if ($result) {
            $bulkInsert = [];
            foreach ($result as $item) {
                $item['section_id'] = $section->getId();
                unset($item['mapping_id']);

                $bulkInsert[] = $item;
            }

            $connection->insertMultiple($table, $bulkInsert);
        }
    }
}
