<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Observer;

use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\Event\Observer;
use Magento\Framework\App\ResourceConnection;

class WidgetDuplicateDefaultSubData implements ObserverInterface
{
    public const TBL_IMAGE_MAPPING = 'mobicommerce_widget_image_mapping';
    public const TBL_CATEGORY_MAPPING = 'mobicommerce_widget_category_mapping';
    public const TBL_LINK_BUILDER = 'mobicommerce_widget_link_builder';

    /**
     * @param ResourceConnection $resourceConnection
     */
    public function __construct(
        ResourceConnection $resourceConnection
    ) {
        $this->resourceConnection = $resourceConnection;
    }

    /**
     * Execute action
     *
     * @param Observer $observer
     */
    public function execute(Observer $observer)
    {
        $id = $observer->getEvent()->getId();
        $widget = $observer->getEvent()->getWidget();

        $this->duplicateWidgetImageMapping($id, $widget);
        $this->duplicateWidgetCategoryMapping($id, $widget);
        $this->duplicateWidgetLinkBuilder($id, $widget);
    }

     /**
      * DuplicateWidgetImageMapping method
      *
      * @param Int $id
      * @param Int $widget
      */
    public function duplicateWidgetImageMapping($id, $widget)
    {
        $table = $this->resourceConnection->getTableName(self::TBL_IMAGE_MAPPING);
        $connection = $this->resourceConnection->getConnection();

        $select = $connection->select()
            ->from(
                ['mapping' => $table]
            )->where('widget_id = ?', $id);

        $result = $connection->fetchAll($select);
        if ($result) {
            $bulkInsert = [];
            foreach ($result as $item) {
                $item['widget_id'] = $widget->getId();
                unset($item['mapping_id']);

                $bulkInsert[] = $item;
            }

            $connection->insertMultiple($table, $bulkInsert);
        }
    }

    /**
     * DuplicateWidgetCategoryMapping method
     *
     * @param Int $id
     * @param Int $widget
     */
    public function duplicateWidgetCategoryMapping($id, $widget)
    {
        $table = $this->resourceConnection->getTableName(self::TBL_CATEGORY_MAPPING);
        $connection = $this->resourceConnection->getConnection();

        $select = $connection->select()
            ->from(
                ['mapping' => $table]
            )->where('widget_id = ?', $id);

        $result = $connection->fetchAll($select);
        if ($result) {
            $bulkInsert = [];
            foreach ($result as $item) {
                $item['widget_id'] = $widget->getId();
                unset($item['mapping_id']);

                $bulkInsert[] = $item;
            }

            $connection->insertMultiple($table, $bulkInsert);
        }
    }

    /**
     * DuplicateWidgetLinkBuilder method
     *
     * @param Int $id
     * @param Int $widget
     */
    public function duplicateWidgetLinkBuilder($id, $widget)
    {
        $table = $this->resourceConnection->getTableName(self::TBL_LINK_BUILDER);
        $connection = $this->resourceConnection->getConnection();

        $select = $connection->select()
            ->from(
                ['mapping' => $table]
            )->where('widget_id = ?', $id);

        $result = $connection->fetchAll($select);
        if ($result) {
            $bulkInsert = [];
            foreach ($result as $item) {
                $item['widget_id'] = $widget->getId();
                unset($item['id']);

                $bulkInsert[] = $item;
            }

            $connection->insertMultiple($table, $bulkInsert);
        }
    }
}
