<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Plugin\Magento\Catalog\Model\Category;

use Mobicommerce\Mobiapp\Ui\DataProvider\PageBuilder\Form\PageBuilderOptionsDataProvider;
use Magento\Framework\App\RequestInterface;
use Mobicommerce\Mobiapp\Ui\DataProvider\Widget\Form\SeoWidgetMetaProvider;
use Mobicommerce\Mobiapp\Ui\DataProvider\Widget\Form\TopWidgetMetaProvider;
use Mobicommerce\Mobiapp\Model\ResourceModel\Widget\CollectionFactory as WidgetCollectionFactory;

class DataProvider
{
    public const FORM_NAME = 'category_form';

    /**
     * Constructor
     *
     * @param PageBuilderOptionsDataProvider $pageBuilderOptionsDataProvider
     * @param RequestInterface $request
     * @param SeoWidgetMetaProvider $seoWidgetMetaProvider
     * @param TopWidgetMetaProvider $topWidgetMetaProvider
     * @param WidgetCollectionFactory $widgetCollectionFactory
     */
    public function __construct(
        PageBuilderOptionsDataProvider $pageBuilderOptionsDataProvider,
        RequestInterface $request,
        SeoWidgetMetaProvider $seoWidgetMetaProvider,
        TopWidgetMetaProvider $topWidgetMetaProvider,
        WidgetCollectionFactory $widgetCollectionFactory
    ) {
        $this->pageBuilderOptionsDataProvider = $pageBuilderOptionsDataProvider;
        $this->seoWidgetMetaProvider = $seoWidgetMetaProvider;
        $this->topWidgetMetaProvider = $topWidgetMetaProvider;
        $this->widgetCollectionFactory = $widgetCollectionFactory;
    }

    /**
     * AfterGetData
     *
     * @param Subject $subject
     * @param Return $result
     */
    public function afterGetData($subject, $result)
    {
        $category = $subject->getCurrentCategory();

        if ($category->getId()) {
            $seoWidgets = $category->getData('mobicommerce_seo_widget_ids');
            if ($seoWidgets) {
                $seoWidgets = $this->getSeoWidgetsData($seoWidgets);
            }

            $seoFieldName = 'mobicommerce_seo_widgets_dynamic_rows';
            $result[$category->getId()][$seoFieldName][$seoFieldName] = $seoWidgets;


            $topWidgets = $category->getData('mobicommerce_top_widget_ids');
            if ($topWidgets) {
                $topWidgets = $this->getTopWidgetsData($topWidgets);
            }

            $topFieldName = 'mobicommerce_top_widgets_dynamic_rows';
            $result[$category->getId()][$topFieldName][$topFieldName] = $topWidgets;
        }

        return $result;
    }

    /**
     * GetTopWidgetsData
     *
     * @param Widget $topWidgets
     */
    public function getTopWidgetsData($topWidgets)
    {
        $result = [];

        if ($topWidgets) {
            $widgetIds = explode(',', $topWidgets);
            
            $collection = $this->widgetCollectionFactory->create();
            $collection->addFieldToFilter('id', [
                'in' => $widgetIds
            ]);

            if ($collection->getSize()) {
                foreach ($collection as $item) {
                    $position = array_search($item->getId(), $widgetIds);

                    $row = $item->getData();
                    $row['position'] = $position;
                    $row['record_id'] = $position;
                    $row['initialize'] = true;
                    $result[] = $row;
                }

                $position = [];
                foreach ($result as $key => $item) {
                    $position[$key] = $item['position'];
                }
                array_multisort($position, SORT_ASC, $result);
            }
        }

        return $result;
    }

    /**
     * GetSeoWidgetsData
     *
     * @param Widget $seoWidgets
     */
    public function getSeoWidgetsData($seoWidgets)
    {
        $result = [];

        if ($seoWidgets) {
            $widgetIds = explode(',', $seoWidgets);
            
            $collection = $this->widgetCollectionFactory->create();
            $collection->addFieldToFilter('id', [
                'in' => $widgetIds
            ]);

            if ($collection->getSize()) {
                foreach ($collection as $item) {
                    $position = array_search($item->getId(), $widgetIds);

                    $row = $item->getData();
                    $row['position'] = $position;
                    $row['record_id'] = $position;
                    $row['initialize'] = true;
                    $result[] = $row;
                }

                $position = [];
                foreach ($result as $key => $item) {
                    $position[$key] = $item['position'];
                }
                array_multisort($position, SORT_ASC, $result);
            }
        }

        return $result;
    }

    /**
     * AfterPrepareMeta
     *
     * @param Category $subject
     * @param Result $result
     * @param Input $meta
     */
    public function afterPrepareMeta($subject, $result, $meta)
    {
        $pageBuilderOptions = $this->pageBuilderOptionsDataProvider->getOptions([
            'prefix' => 'mobicommerce_',
            'scopeLabel' => '[store view]',
            'form_name' => self::FORM_NAME
        ]);
        foreach ($pageBuilderOptions as $key => $option) {
            $result['mobicommerce']['children'][$key] = $option;
        }
        
        $this->seoWidgetMetaProvider->getElement($result['mobicommerce']['children'], [
            'form_name' => self::FORM_NAME
        ]);

        $this->topWidgetMetaProvider->getElement($result['mobicommerce']['children'], [
            'form_name' => self::FORM_NAME
        ]);
          //  echo "<pre>"; print_r($result['mobicommerce']['children']); exit;
        return $result;
    }

    /**
     * MergeArray
     *
     * @param Array $arr1
     * @param Array $arr2
     */
    public function mergeArray($arr1, $arr2)
    {
        return array_merge($arr1, $arr2);
    }
}
