<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Plugin\Magento\Cms\Model\Page;

use Mobicommerce\Mobiapp\Ui\DataProvider\PageBuilder\Form\ModalMetaProvider as PageBuilderModalMetaProvider;
use Mobicommerce\Mobiapp\Ui\DataProvider\Productcollection\Form\ModalMetaProvider as ProductcollectionModalMetaProvider;
use Mobicommerce\Mobiapp\Ui\DataProvider\PageBuilder\Form\PageBuilderOptionsDataProvider;
use Magento\Framework\App\ResourceConnection;
use Magento\Framework\App\RequestInterface;
use Mobicommerce\Mobiapp\Ui\DataProvider\Widget\Form\SeoWidgetMetaProvider;

class DataProvider
{
    public const FORM_NAME = 'cms_page_form';
    public const TBL_WIDGET_MAPPING = 'mobicommerce_cmspage_seo_widget_mapping';

    /**
     * Constructor
     *
     * @param ProductcollectionModalMetaProvider $productcollectionModalMetaProvider
     * @param PageBuilderOptionsDataProvider $pageBuilderOptionsDataProvider
     * @param ResourceConnection $resourceConnection
     * @param RequestInterface $request
     * @param SeoWidgetMetaProvider $seoWidgetMetaProvider
     */
    public function __construct(
        ProductcollectionModalMetaProvider $productcollectionModalMetaProvider,
        PageBuilderOptionsDataProvider $pageBuilderOptionsDataProvider,
        ResourceConnection $resourceConnection,
        RequestInterface $request,
        SeoWidgetMetaProvider $seoWidgetMetaProvider
    ) {
        $this->productcollectionModalMetaProvider = $productcollectionModalMetaProvider;
        $this->pageBuilderOptionsDataProvider = $pageBuilderOptionsDataProvider;
        $this->resourceConnection = $resourceConnection;
        $this->request = $request;
        $this->seoWidgetMetaProvider = $seoWidgetMetaProvider;
    }

    /**
     * AfterGetData
     *
     * @param PostData $subject
     * @param Result $result
     */
    public function afterGetData($subject, $result)
    {
        $pageId = $this->request->getParam('page_id', null);

        if ($pageId) {
            $seoFieldName = 'mobicommerce_seo_widgets_dynamic_rows';
            $result[$pageId][$seoFieldName][$seoFieldName] = $this->getSeoWidgetsData($pageId);
        }

        return $result;
    }

    /**
     * AfterPrepareMeta
     *
     * @param PostData $subject
     * @param Result $result
     * @param Input $meta
     */
    public function afterPrepareMeta($subject, $result, $meta)
    {
        $modalName = ProductcollectionModalMetaProvider::DEFAULT_MODAL_NAME;
        $result['mobicommerce']['children'][$modalName] = $this->productcollectionModalMetaProvider->getModal();

        $pageBuilderOptions = $this->pageBuilderOptionsDataProvider->getOptions([
            'prefix' => 'mobicommerce_',
            'required' => true,
            'form_name' => 'cms_page_form'
        ]);
        foreach ($pageBuilderOptions as $key => $option) {
            $result['mobicommerce']['children'][$key] = $option;
        }

        $this->seoWidgetMetaProvider->getElement($result['mobicommerce']['children'], [
            'form_name' => self::FORM_NAME
        ]);

        return $result;
    }

    /**
     * GetSeoWidgetsData
     *
     * @param Int $pageId
     */
    public function getSeoWidgetsData($pageId)
    {
        $result = [];

        if ($pageId) {
            $connection = $this->resourceConnection->getConnection();
            $table = $this->resourceConnection->getTableName(self::TBL_WIDGET_MAPPING);

            $select = $connection->select()
                ->from(
                    ['mapping' => $table]
                )->join(
                    ['mobicommerce_widget' => $this->resourceConnection->getTableName('mobicommerce_widget')],
                    'mobicommerce_widget.id=mapping.widget_id'
                )->where('cms_page_id = ?', $pageId)
                ->order('position ASC');

            $result = $connection->fetchAll($select);
        }

        return $result;
    }
}
