<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Setup\Patch\Data;

use Magento\Framework\Setup\Patch\DataPatchInterface;
use Magento\Framework\Setup\Patch\PatchRevertableInterface;
use Magento\Eav\Setup\EavSetupFactory;
use Magento\Eav\Model\Entity\Attribute\ScopedAttributeInterface;
use Magento\Catalog\Model\Category;
use Mobicommerce\Mobiapp\Model\Category\Attribute\Source\MobicommercePageBuilder;
use Mobicommerce\Mobiapp\Model\Category\Attribute\Backend\SeoWidgetIds;
use Magento\Catalog\Model\Category\Attribute\Backend\Image;

class AddMobicommerceCategoryAttributes implements
    DataPatchInterface,
    PatchRevertableInterface
{
    /**
     * @var \Magento\Framework\Setup\ModuleDataSetupInterface
     */
    private $moduleDataSetup;

    /**
     * @param \Magento\Framework\Setup\ModuleDataSetupInterface $moduleDataSetup
     * @param EavSetupFactory $eavSetupFactory
     */
    public function __construct(
        \Magento\Framework\Setup\ModuleDataSetupInterface $moduleDataSetup,
        EavSetupFactory $eavSetupFactory
    ) {
        $this->moduleDataSetup = $moduleDataSetup;
        $this->eavSetupFactory = $eavSetupFactory;
    }

    /**
     * Apply patch
     */
    public function apply()
    {
        $this->moduleDataSetup->getConnection()->startSetup();
        $this->addMobicommerceCategoryAttributes();
        $this->moduleDataSetup->getConnection()->endSetup();
    }

    /**
     * GetDependencies patch
     */
    public static function getDependencies()
    {
        return [];
    }

    /**
     * Revert patch
     */
    public function revert()
    {
        $this->moduleDataSetup->getConnection()->startSetup();
        $this->moduleDataSetup->getConnection()->endSetup();
    }

    /**
     * GetAliases patch
     */
    public function getAliases()
    {
        return [];
    }

    /**
     * AddMobicommerceCategoryAttributes patch
     */
    private function addMobicommerceCategoryAttributes()
    {
        $eavSetup = $this->eavSetupFactory->create(['setup' => $this->moduleDataSetup]);

        $eavSetup->addAttribute(
            Category::ENTITY,
            'mobicommerce_mobile_image',
            [
                'type' => 'varchar',
                'label' => 'Mobicommerce Mobile Image',
                'input' => 'image',
                'sort_order' => 80,
                'source' => '',
                'global' => ScopedAttributeInterface::SCOPE_STORE,
                'visible' => true,
                'required' => false,
                'user_defined' => false,
                'default' => null,
                'group' => 'mobicommerce',
                'backend' => Image::class
            ]
        );

        $eavSetup->addAttribute(
            Category::ENTITY,
            'mobicommerce_desktop_image',
            [
                'type' => 'varchar',
                'label' => 'Mobicommerce Desktop Image',
                'input' => 'image',
                'sort_order' => 90,
                'source' => '',
                'global' => ScopedAttributeInterface::SCOPE_STORE,
                'visible' => true,
                'required' => false,
                'user_defined' => false,
                'default' => null,
                'group' => 'mobicommerce',
                'backend' => Image::class
            ]
        );

        $eavSetup->addAttribute(
            Category::ENTITY,
            'mobicommerce_landing_page_enable',
            [
                'type'         => 'int',
                'label'        => 'Enable Mobicommerce Landing Page',
                'input'        => 'checkbox',
                'sort_order'   => 95,
                'source'       => '',
                'global'       => ScopedAttributeInterface::SCOPE_STORE,
                'visible'      => true,
                'required'     => false,
                'user_defined' => false,
                'default'      => false,
                'group'        => 'mobicommerce',
                'backend'      => ''
            ]
        );

        $eavSetup->addAttribute(
            Category::ENTITY,
            'mobicommerce_pwa_landing_page_id',
            [
                'type'         => 'int',
                'label'        => 'Mobicommerce PWA Landing Page',
                'input'        => 'select',
                'sort_order'   => 100,
                'source'       => MobicommercePageBuilder::class,
                'global'       => ScopedAttributeInterface::SCOPE_STORE,
                'visible'      => true,
                'required'     => false,
                'user_defined' => false,
                'default'      => null,
                'group'        => 'mobicommerce',
                'backend'      => ''
            ]
        );

        $eavSetup->addAttribute(
            Category::ENTITY,
            'mobicommerce_desktop_landing_page_id',
            [
                'type'         => 'int',
                'label'        => 'Mobicommerce Desktop Landing Page',
                'input'        => 'select',
                'sort_order'   => 110,
                'source'       => MobicommercePageBuilder::class,
                'global'       => ScopedAttributeInterface::SCOPE_STORE,
                'visible'      => true,
                'required'     => false,
                'user_defined' => false,
                'default'      => null,
                'group'        => 'mobicommerce',
                'backend'      => ''
            ]
        );

        $eavSetup->addAttribute(
            Category::ENTITY,
            'mobicommerce_mobileapp_landing_page_id',
            [
                'type'         => 'int',
                'label'        => 'Mobicommerce Mobileapp Landing Page',
                'input'        => 'select',
                'sort_order'   => 120,
                'source'       => MobicommercePageBuilder::class,
                'global'       => ScopedAttributeInterface::SCOPE_STORE,
                'visible'      => true,
                'required'     => false,
                'user_defined' => false,
                'default'      => null,
                'group'        => 'mobicommerce',
                'backend'      => ''
            ]
        );

        $eavSetup->addAttribute(
            Category::ENTITY,
            'mobicommerce_seo_widget_ids',
            [
                'type'         => 'text',
                'label'        => 'Mobicommerce SEO Widget IDs',
                'input'        => 'text',
                'sort_order'   => 130,
                'source'       => MobicommercePageBuilder::class,
                'global'       => ScopedAttributeInterface::SCOPE_STORE,
                'visible'      => true,
                'required'     => false,
                'user_defined' => false,
                'default'      => null,
                'group'        => 'mobicommerce',
                'backend'      => SeoWidgetIds::class
            ]
        );
    }
}
