<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Setup\Patch\Data;

use Magento\Framework\Setup\Patch\DataPatchInterface;
use Magento\Framework\Setup\Patch\PatchRevertableInterface;
use Magento\Eav\Setup\EavSetupFactory;
use Magento\Eav\Model\Entity\Attribute\ScopedAttributeInterface;
use Magento\Catalog\Model\Category;
use Mobicommerce\Mobiapp\Model\Category\Attribute\Source\MobicommercePageBuilder;
use Mobicommerce\Mobiapp\Model\Category\Attribute\Backend\TopWidgetIds;
use Magento\Catalog\Model\Category\Attribute\Backend\Image;

class AddMobicommerceCategoryAttributesV2 implements
    DataPatchInterface,
    PatchRevertableInterface
{
    /**
     * @var \Magento\Framework\Setup\ModuleDataSetupInterface
     */
    private $moduleDataSetup;

    /**
     * @param \Magento\Framework\Setup\ModuleDataSetupInterface $moduleDataSetup
     * @param EavSetupFactory $eavSetupFactory
     */
    public function __construct(
        \Magento\Framework\Setup\ModuleDataSetupInterface $moduleDataSetup,
        EavSetupFactory $eavSetupFactory
    ) {
        $this->moduleDataSetup = $moduleDataSetup;
        $this->eavSetupFactory = $eavSetupFactory;
    }

    /**
     * Apply patch
     */
    public function apply()
    {
        $this->moduleDataSetup->getConnection()->startSetup();
        $this->addMobicommerceCategoryAttributes();
        $this->moduleDataSetup->getConnection()->endSetup();
    }

    /**
     * GetDependencies patch
     */
    public static function getDependencies()
    {
        return [];
    }

    /**
     * Revert patch
     */
    public function revert()
    {
        $this->moduleDataSetup->getConnection()->startSetup();
        $this->moduleDataSetup->getConnection()->endSetup();
    }

    /**
     * GetAliases patch
     */
    public function getAliases()
    {
        return [];
    }

    /**
     * AddMobicommerceCategoryAttributes patch
     */
    private function addMobicommerceCategoryAttributes()
    {
        $eavSetup = $this->eavSetupFactory->create(['setup' => $this->moduleDataSetup]);

      
        $eavSetup->addAttribute(
            Category::ENTITY,
            'mobicommerce_top_widget_ids',
            [
                'type'         => 'text',
                'label'        => 'Mobicommerce Top Widget IDs',
                'input'        => 'text',
                'sort_order'   => 130,
                'source'       => MobicommercePageBuilder::class,
                'global'       => ScopedAttributeInterface::SCOPE_STORE,
                'visible'      => true,
                'required'     => false,
                'user_defined' => false,
                'default'      => null,
                'group'        => 'mobicommerce',
                'backend'      => TopWidgetIds::class
            ]
        );
    }
}
