<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Setup\Patch\Schema;

use Magento\Framework\Setup\SchemaSetupInterface;
use Magento\Framework\Setup\Patch\SchemaPatchInterface;
use Magento\Framework\DB\Ddl\Table;
use Mobicommerce\Mobiapp\Model\Config\Source\MobicommerceCmsPageType;

class AddCmsPageMobicommerceColumns implements SchemaPatchInterface
{
    /**
     * @var SchemaSetupInterface
     */
    private $schemaSetup;

    /**
     * EnableSegmentation constructor.
     *
     * @param SchemaSetupInterface $schemaSetup
     */
    public function __construct(
        SchemaSetupInterface $schemaSetup
    ) {
        $this->schemaSetup = $schemaSetup;
    }

    /**
     * Apply patch
     */
    public function apply()
    {
        $this->schemaSetup->startSetup();
        $this->addMobicommerceColumns();
        $this->schemaSetup->endSetup();
    }

    /**
     * AddMobicommerceColumns patch
     */
    private function addMobicommerceColumns()
    {
        $setup = $this->schemaSetup;
        $connection = $setup->getConnection();
        $table = $setup->getTable('cms_page');
        $pageBuilderTable = $setup->getTable('mobicommerce_page_builder');
        $productcollectionTable = $setup->getTable('mobicommerce_productcollection');

        if ($connection->tableColumnExists($table, 'mobicommerce_page_type') === false) {
            $connection->addColumn(
                $table,
                'mobicommerce_page_type',
                [
                    'type' => Table::TYPE_TEXT,
                    'length' => 255,
                    'nullable' => false,
                    'default' => MobicommerceCmsPageType::DEFAULT,
                    'comment' => 'Mobicommerce CMS Page Type Column'
                ]
            );
        }

        $column = 'mobicommerce_pwa_landing_page_id';
        if ($connection->tableColumnExists($table, $column) === false) {
            $connection->addColumn(
                $table,
                $column,
                [
                    'type' => Table::TYPE_INTEGER,
                    'nullable' => true,
                    'unsigned' => true,
                    'comment' => 'Mobicommerce PWA Landing Page ID'
                ]
            );

            $connection->addForeignKey(
                $setup->getFkName(
                    'cms_page',
                    $column,
                    'mobicommerce_page_builder',
                    'id'
                ),
                $table,
                $column,
                $pageBuilderTable,
                'id',
                Table::ACTION_NO_ACTION
            );
        }

        $column = 'mobicommerce_desktop_landing_page_id';
        if ($connection->tableColumnExists($table, $column) === false) {
            $connection->addColumn(
                $table,
                $column,
                [
                    'type' => Table::TYPE_INTEGER,
                    'nullable' => true,
                    'unsigned' => true,
                    'comment' => 'Mobicommerce Desktop Landing Page ID'
                ]
            );

            $connection->addForeignKey(
                $setup->getFkName(
                    'cms_page',
                    $column,
                    'mobicommerce_page_builder',
                    'id'
                ),
                $table,
                $column,
                $pageBuilderTable,
                'id',
                Table::ACTION_NO_ACTION
            );
        }

        $column = 'mobicommerce_mobileapp_landing_page_id';
        if ($connection->tableColumnExists($table, $column) === false) {
            $connection->addColumn(
                $table,
                $column,
                [
                    'type' => Table::TYPE_INTEGER,
                    'nullable' => true,
                    'unsigned' => true,
                    'comment' => 'Mobicommerce Mobileapp Landing Page ID'
                ]
            );

            $connection->addForeignKey(
                $setup->getFkName(
                    'cms_page',
                    $column,
                    'mobicommerce_page_builder',
                    'id'
                ),
                $table,
                $column,
                $pageBuilderTable,
                'id',
                Table::ACTION_NO_ACTION
            );
        }

        $column = 'mobicommerce_product_collection_id';
        if ($connection->tableColumnExists($table, $column) === false) {
            $connection->addColumn(
                $table,
                $column,
                [
                    'type' => Table::TYPE_INTEGER,
                    'nullable' => true,
                    'unsigned' => true,
                    'comment' => 'Mobicommerce Product Collection ID'
                ]
            );

            $connection->addForeignKey(
                $setup->getFkName(
                    'cms_page',
                    $column,
                    'mobicommerce_productcollection',
                    'id'
                ),
                $table,
                $column,
                $productcollectionTable,
                'id',
                Table::ACTION_NO_ACTION
            );
        }
    }

    /**
     * GetDependencies patch
     */
    public static function getDependencies()
    {
        return [];
    }

    /**
     * GetAliases patch
     */
    public function getAliases()
    {
        return [];
    }
}
