<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Ui\Component\Form\Translation;

use Magento\Framework\View\Element\UiComponent\ContextInterface;
use Magento\Ui\Component\Form\FieldFactory;
use Magento\Ui\Component\Form\Fieldset;
use Magento\Framework\App\RequestInterface;
use Mobicommerce\Mobiapp\Helper\Translation as TranslationHelper;

class Message extends Fieldset
{
    /**
     * Message constructor.
     *
     * @param ContextInterface $context
     * @param FieldFactory $fieldFactory
     * @param RequestInterface $request
     * @param TranslationHelper $translationHelper
     * @param Array $components
     * @param Array $data
     */
    public function __construct(
        ContextInterface $context,
        FieldFactory $fieldFactory,
        RequestInterface $request,
        TranslationHelper $translationHelper,
        array $components = [],
        array $data = []
    ) {
        parent::__construct($context, $components, $data);
        $this->fieldFactory = $fieldFactory;
        $this->request = $request;
        $this->translationHelper = $translationHelper;
    }

    /**
     * Get child component
     *
     * @return object
     */
    public function getChildComponents()
    {
        $locale = $this->request->getParam('language');
        $items = $this->translationHelper->getTranslationsByLocale($locale);
        foreach ($items as $code => $item) {
            if ($item['type'] != 'message') {
                continue;
            }

            $type = "input";
            if( $item['max_length'] > 255)
            {
                $type = "textarea";
            }
            $fieldInstance = $this->fieldFactory->create();
            $fieldInstance->setData(
                [
                    'config' => [
                        'label' => $item['label'],
                        'value' => $item['value'],
                        'formElement' => $type,
                        'validation' => [
                            'required-entry' => true,
                            'max_text_length' => $item['max_length'] ?? 1000
                           
                        ],
                        'notice' => $item['help'] ?? false
                    ],
                    'name' => $code
                ]
            );
            $fieldInstance->prepare();
            $this->addComponent($code, $fieldInstance);
        }

        return parent::getChildComponents();
    }
}
