<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Ui\Component\Listing\Column;

use Magento\Framework\UrlInterface;
use Magento\Framework\View\Element\UiComponent\ContextInterface;
use Magento\Framework\View\Element\UiComponentFactory;
use Magento\Ui\Component\Listing\Columns\Column;

class CustomsegmentActions extends Column
{
    public const URL_PATH_QUEUE_ADD = 'mobicommerce/customsegment/queueadd';
    public const URL_PATH_SOFT_DELETE = 'mobicommerce/customsegment/queuesoftdelete';

    public const URL_PATH_DELETE = 'mobicommerce/customsegment/delete';

    public const URL_PATH_VIEW_LOGS = 'mobicommerce/customsegmentlog/index';

    /**
     * @var UrlInterface
     */
    protected UrlInterface $urlBuilder;

    /**
     * Constructor
     *
     * @param ContextInterface $context
     * @param UiComponentFactory $uiComponentFactory
     * @param UrlInterface $urlBuilder
     * @param array $components
     * @param array $data
     */
    public function __construct(
        ContextInterface $context,
        UiComponentFactory $uiComponentFactory,
        UrlInterface $urlBuilder,
        array $components = [],
        array $data = []
    ) {
        $this->urlBuilder = $urlBuilder;
        parent::__construct($context, $uiComponentFactory, $components, $data);
    }

    /**
     * Prepare data source
     *
     * @param array $dataSource
     * @return array
     */
    public function prepareDataSource(array $dataSource)
    {
        if (isset($dataSource['data']['items'])) {
            foreach ($dataSource['data']['items'] as & $item) {
                if (isset($item['id'])) {
                    $item[$this->getData('name')]['view_logs'] = [
                        'href' => $this->urlBuilder->getUrl(
                            static::URL_PATH_VIEW_LOGS,
                            [
                                'segment_id' => $item['id']
                            ]
                        ),
                        'label' => __('View Logs')
                    ];

                    if ($item['status'] == 0) {
                        $item[$this->getData('name')]['queueadd'] = [
                            'href' => $this->urlBuilder->getUrl(
                                static::URL_PATH_QUEUE_ADD,
                                [
                                    'id' => $item['id']
                                ]
                            ),
                            'label' => __('Queue')
                        ];
                    }

                    if ($item['status'] == 2) {
                        $item[$this->getData('name')]['soft_delete'] = [
                            'href' => $this->urlBuilder->getUrl(
                                static::URL_PATH_SOFT_DELETE,
                                [
                                    'id' => $item['id']
                                ]
                            ),
                            'label' => __('Soft Delete'),
                            'confirm' => [
                                'title' => __('Soft Delete'),
                                'message' => __('Are you sure you want to soft delete item?'),
                                '__disableTmpl' => true,
                            ],
                        ];
                    }

                    if (in_array($item['status'], [0,4])) {
                        $item[$this->getData('name')]['delete'] = [
                            'href' => $this->urlBuilder->getUrl(
                                static::URL_PATH_DELETE,
                                [
                                    'id' => $item['id']
                                ]
                            ),
                            'label' => __('Delete')
                        ];
                    }
                }
            }
        }

        return $dataSource;
    }
}
