<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Ui\Component\Listing\Column;

use Magento\Framework\UrlInterface;
use Magento\Framework\View\Element\UiComponent\ContextInterface;
use Magento\Framework\View\Element\UiComponentFactory;
use Magento\Ui\Component\Listing\Columns\Column;
use Mobicommerce\Mobiapp\Helper\Image as ImageHelper;

class Image extends Column
{
    /**
     * Image constructor.
     *
     * @param ContextInterface $context
     * @param UiComponentFactory $uiComponentFactory
     * @param UrlInterface $urlBuilder
     * @param ImageHelper $imageHelper
     * @param Array $components
     * @param Array $data
     */
    public function __construct(
        ContextInterface $context,
        UiComponentFactory $uiComponentFactory,
        UrlInterface $urlBuilder,
        ImageHelper $imageHelper,
        array $components = [],
        array $data = []
    ) {
        $this->urlBuilder = $urlBuilder;
        $this->imageHelper = $imageHelper;
        parent::__construct($context, $uiComponentFactory, $components, $data);
    }

    /**
     * Prepare data source
     *
     * @param Array $dataSource
     * @return string
     */
    public function prepareDataSource(array $dataSource)
    {
        if (isset($dataSource['data']['items'])) {
            $fieldName = $this->getData('name');
            foreach ($dataSource['data']['items'] as & $item) {
                if (isset($item['id'])) {
                    if ($item[$fieldName] != '') {
                        $url = $this->imageHelper->getFileUrl($item[$fieldName]);

                        $item[$fieldName . '_src'] = $url;
                        $item[$fieldName . '_alt'] = $this->getAlt($item) ?: '';
                        $item[$fieldName . '_link'] = $this->urlBuilder->getUrl(
                            'mobicommerce/image/edit',
                            ['id' => $item['id']]
                        );
                        $item[$fieldName . '_orig_src'] = $url;
                    }
                }
            }
        }

        return $dataSource;
    }

    /**
     * Get alt source
     *
     * @param Array $row
     * @return null|string
     */
    protected function getAlt($row)
    {
        $altField = $this->getData('config/altField');
        return isset($row[$altField]) ? $row[$altField] : null;
    }
}
