<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Ui\Component\Listing\Column;

use Magento\Framework\UrlInterface;
use Magento\Framework\View\Element\UiComponent\ContextInterface;
use Magento\Framework\View\Element\UiComponentFactory;
use Magento\Ui\Component\Listing\Columns\Column;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Mobicommerce\Mobiapp\Helper\Config;

class PageBuilderActions extends Column
{
    public const URL_PATH_EDIT = 'mobicommerce/pagebuilder/edit';
    public const URL_PATH_DUPLICATE = 'mobicommerce/pagebuilder/duplicate';
    public const URL_PATH_DELETE = 'mobicommerce/pagebuilder/delete';

    /**
     * @var Magento\Framework\UrlInterface
     */
    protected $urlBuilder;

    /**
     * PageBuilderActions constructor.
     *
     * @param ContextInterface $context
     * @param UiComponentFactory $uiComponentFactory
     * @param UrlInterface $urlBuilder
     * @param ScopeConfigInterface $scopeConfig
     * @param Array $components
     * @param Array $data
     */
    public function __construct(
        ContextInterface $context,
        UiComponentFactory $uiComponentFactory,
        UrlInterface $urlBuilder,
        ScopeConfigInterface $scopeConfig,
        \Mobicommerce\Mobiapp\Helper\Config $mobiconfig,
        array $components = [],
        array $data = []
    ) {
        $this->urlBuilder = $urlBuilder;
        $this->scopeConfig = $scopeConfig;
        $this->mobiconfig = $mobiconfig;
        parent::__construct($context, $uiComponentFactory, $components, $data);
    }

    /**
     * Prepare data source
     *
     * @param Array $dataSource
     */
    public function prepareDataSource(array $dataSource)
    {
        if (isset($dataSource['data']['items'])) {
            foreach ($dataSource['data']['items'] as & $item) {
                if (isset($item['id'])) {
                    $item[$this->getData('name')] = [
                        'edit' => [
                            'href' => $this->urlBuilder->getUrl(
                                static::URL_PATH_EDIT,
                                [
                                    'id' => $item['id']
                                ]
                            ),
                            'label' => __('Edit')
                        ],
                        'duplicate' => [
                            'href' => $this->urlBuilder->getUrl(
                                static::URL_PATH_DUPLICATE,
                                [
                                    'id' => $item['id']
                                ]
                            ),
                            'label' => __('Duplicate')
                        ],
                        'delete' => [
                            'href' => $this->urlBuilder->getUrl(
                                static::URL_PATH_DELETE,
                                [
                                    'id' => $item['id']
                                ]
                            ),
                            'label' => __('Delete'),
                            'confirm' => [
                                'title' => __('Delete'),
                                'message' => __('Are you sure you want to delete item?'),
                                '__disableTmpl' => true,
                            ],
                        ]
                    ];

                    if ($this->ifHeadlessFrontendEnabled() && $headlessUrl = $this->getHeadlessUrl()) {
                        if (substr($headlessUrl, -1) != '/') {
                            $headlessUrl .= '/';
                        }
                        $headlessUrl .= Config::PAGEBUILDER_PREVIEW_SLUG;
                        $headlessUrl .= '?pageid=' . $item['id'];
                        $item[$this->getData('name')]['preview'] = [
                            'href' => $headlessUrl,
                            'target' => '_blank',
                            'label' => __('Preview')
                        ];
                    }
                }
            }
        }

        return $dataSource;
    }

    /**
     * Check Headless url enalbe
     */
    public function ifHeadlessFrontendEnabled()
    {
        return $this->scopeConfig->getValue(
            'mobi_basic/headless/is_enable'
        );
    }

   /**
    * Check Headless url
    */
    public function getHeadlessUrl()
    {
       /* return $this->scopeConfig->getValue(
            'mobi_basic/headless/frontend_url'
        );
        */
        return $this->mobiconfig->getStoreUrl();
    }
}
