<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Ui\DataProvider\Deeplink\Form;

use Mobicommerce\Mobiapp\Model\Config\Source\DeeplinkType;
use Mobicommerce\Mobiapp\Block\Adminhtml\Deeplink\Container\Products as DeeplinkContainerProducts;
use Mobicommerce\Mobiapp\Block\Adminhtml\Deeplink\Container\Category\Tree as CategoryTree;
use Mobicommerce\Mobiapp\Block\Adminhtml\Deeplink\Container\Cmspage as DeeplinkContainerCmsPage;

class ModalMetaProvider
{
    public const DEFAULT_MODAL_NAME = 'deeplink_modal';
    public const DEFAULT_DYNAMIC_ROWS_HIDDEN_FEILD_NAME = 'dynamic_rows_links_current_row';

    /**
     * ModalMetaProvider constructor.
     *
     * @param DeeplinkType $deeplinkType
     * @param DeeplinkContainerProducts $deeplinkContainerProducts
     * @param CategoryTree $categoryTree
     * @param DeeplinkContainerCmsPage $deeplinkContainerCmsPage
     */
    public function __construct(
        DeeplinkType $deeplinkType,
        DeeplinkContainerProducts $deeplinkContainerProducts,
        CategoryTree $categoryTree,
        DeeplinkContainerCmsPage $deeplinkContainerCmsPage
    ) {
        $this->deeplinkType = $deeplinkType;
        $this->deeplinkContainerProducts = $deeplinkContainerProducts;
        $this->categoryTree = $categoryTree;
        $this->deeplinkContainerCmsPage = $deeplinkContainerCmsPage;
    }

    /**
     * GetDynamicRowsHiddenField
     *
     * @return array
     */
    public function getDynamicRowsHiddenField()
    {
        $data = [
            'arguments' => [
                'data' => [
                    'config' => [
                        'formElement' => 'input',
                        'componentType' => 'field',
                        'label' => false
                    ]
                ]
            ]
        ];

        return $data;
    }

    /**
     * GetModal
     *
     * @param string $dynamicRows
     * @param string $imageMapping
     * @return array
     */
    public function getModal($dynamicRows = false, $imageMapping = false)
    {
        $defaultVisibility = true;

        $deeplinkComponent = 'Mobicommerce_Mobiapp/js/deeplink/modal';
        if ($dynamicRows) {
            $deeplinkComponent = 'Mobicommerce_Mobiapp/js/deeplink/modal_dynamic_rows';
        }
        if ($imageMapping) {
            $deeplinkComponent = 'Mobicommerce_Mobiapp/js/deeplink/modal_image_mapping';
        }

        $data = [
            'arguments' => [
                'data' => [
                    'config' => [
                        'onCancel' => 'actionCancel',
                        'componentType' => 'modal',
                        'component' => $deeplinkComponent,
                        'options' => [
                            'buttons' => [
                                [
                                    'text' => 'Cancel',
                                    'class' => 'action-secondary',
                                    'actions' => ["actionCancel"]
                                ],
                                [
                                    'text' => 'Done',
                                    'class' => 'action-primary',
                                    'actions' => ["actionDone"]
                                ]
                            ]
                        ],
                        'valid' => false
                    ]
                ]
            ],
            'children' => [
                'general' => [
                    'arguments' => [
                        'data' => [
                            'config' => [
                                'componentType' => 'fieldset',
                                'label' => false
                            ]
                        ]
                    ],
                    'children' => [
                        'deeplink_type' => [
                            'arguments' => [
                                'data' => [
                                    'config' => [
                                        'formElement' => 'select',
                                        'componentType' => 'field',
                                        'component' => 'Mobicommerce_Mobiapp/js/deeplink/element/select_deeplink_type',
                                        'sortOrder' => 10,
                                        'label' => __('Deeplink Type'),
                                        'visible' => true,
                                        'options' => $this->deeplinkType->toOptionArray()
                                    ]
                                ]
                            ]
                        ],
                        'deeplink_product_value' => [
                            'arguments' => [
                                'data' => [
                                    'config' => [
                                        'formElement' => 'input',
                                        'elementTmpl' => 'Mobicommerce_Mobiapp/form/element/input-readonly',
                                        'componentType' => 'field',
                                        'sortOrder' => 20,
                                        'label' => __('Value'),
                                        'visible' => $defaultVisibility,
                                        'validation' => [
                                            'required-entry' => true
                                        ]
                                    ]
                                ]
                            ],
                        ],
                        'deeplink_container_products' => [
                            'arguments' => [
                                'data' => [
                                    'config' => [
                                        'componentType' => 'container',
                                        'sortOrder' => 30,
                                    ]
                                ]
                            ],
                            'children' => [
                                'html_content' => [
                                    'arguments' => [
                                        'data' => [
                                            'config' => [
                                                'componentType' => 'htmlContent',
                                                'visible' => $defaultVisibility,
                                                'additionalClasses' => implode(' ', [
                                                    'mobicommerce_deeplink_containers',
                                                    'deeplink_container_products'
                                                ])
                                            ]
                                        ],
                                        'block' => $this->deeplinkContainerProducts
                                    ]
                                ]
                            ]
                        ],
                        'deeplink_category_value' => [
                            'arguments' => [
                                'data' => [
                                    'config' => [
                                        'formElement' => 'input',
                                        'elementTmpl' => 'Mobicommerce_Mobiapp/form/element/input-readonly',
                                        'componentType' => 'field',
                                        'sortOrder' => 40,
                                        'label' => __('Value'),
                                        'visible' => $defaultVisibility,
                                        'validation' => [
                                            'required-entry' => true
                                        ]
                                    ]
                                ]
                            ]
                        ],
                        'deeplink_category_force_navigate_to_product_list' => [
                            'arguments' => [
                                'data' => [
                                    'config' => [
                                        'dataType' => 'boolean',
                                        'default' => 1,
                                        'formElement' => 'checkbox',
                                        'componentType' => 'field',
                                        'sortOrder' => 50,
                                        'label' => __('Force Navigate to Product Listing'),
                                        'visible' => $defaultVisibility,
                                        'prefer' => 'toggle',
                                        'valueMap' => [
                                            'false' => 0,
                                            'true' => 1
                                        ]
                                    ]
                                ]
                            ]
                        ],
                        'deeplink_container_category' => [
                            'arguments' => [
                                'data' => [
                                    'config' => [
                                        'componentType' => 'container',
                                        'sortOrder' => 60,
                                    ]
                                ]
                            ],
                            'children' => [
                                'html_content' => [
                                    'arguments' => [
                                        'data' => [
                                            'config' => [
                                                'componentType' => 'htmlContent',
                                                'visible' => $defaultVisibility,
                                                'additionalClasses' => implode(' ', [
                                                    'admin__field',
                                                    'mobicommerce_deeplink_containers',
                                                    'deeplink_container_category'
                                                ])
                                            ]
                                        ],
                                        'block' => $this->categoryTree
                                    ]
                                ]
                            ]
                        ],
                        'deeplink_cmspage_value' => [
                            'arguments' => [
                                'data' => [
                                    'config' => [
                                        'formElement' => 'input',
                                        'elementTmpl' => 'Mobicommerce_Mobiapp/form/element/input-readonly',
                                        'componentType' => 'field',
                                        'sortOrder' => 70,
                                        'label' => __('Value'),
                                        'visible' => $defaultVisibility,
                                        'validation' => [
                                            'required-entry' => true
                                        ]
                                    ]
                                ]
                            ]
                        ],
                        'deeplink_cmspage_container' => [
                            'arguments' => [
                                'data' => [
                                    'config' => [
                                        'componentType' => 'container',
                                        'sortOrder' => 80,
                                    ]
                                ]
                            ],
                            'children' => [
                                'html_content' => [
                                    'arguments' => [
                                        'data' => [
                                            'config' => [
                                                'componentType' => 'htmlContent',
                                                'visible' => $defaultVisibility,
                                                'additionalClasses' => implode(' ', [
                                                    'mobicommerce_deeplink_containers',
                                                    'deeplink_container_cmspage'
                                                ])
                                            ]
                                        ],
                                        'block' => $this->deeplinkContainerCmsPage
                                    ]
                                ]
                            ]
                        ],
                        'deeplink_phone' => [
                            'arguments' => [
                                'data' => [
                                    'config' => [
                                        'formElement' => 'input',
                                        'componentType' => 'field',
                                        'sortOrder' => 90,
                                        'label' => __('Phone Number'),
                                        'visible' => $defaultVisibility,
                                        'validation' => [
                                            'required-entry' => true,
                                            'validate-phoneStrict' => true
                                        ]
                                    ]
                                ]
                            ]
                        ],
                        'deeplink_email' => [
                            'arguments' => [
                                'data' => [
                                    'config' => [
                                        'formElement' => 'input',
                                        'componentType' => 'field',
                                        'sortOrder' => 100,
                                        'label' => __('Email Address'),
                                        'visible' => $defaultVisibility,
                                        'validation' => [
                                            'required-entry' => true,
                                            'validate-email' => true
                                        ]
                                    ]
                                ]
                            ]
                        ],
                        'deeplink_external_url' => [
                            'arguments' => [
                                'data' => [
                                    'config' => [
                                        'formElement' => 'input',
                                        'componentType' => 'field',
                                        'sortOrder' => 110,
                                        'label' => __('External URL'),
                                        'visible' => $defaultVisibility,
                                        'validation' => [
                                            'required-entry' => true,
                                            'validate-url' => true
                                        ]
                                    ]
                                ]
                            ]
                        ],
                    ]
                ]
            ]
        ];

        return $data;
    }
}
