<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Ui\DataProvider\Image\Form\Modifier;

use Magento\Framework\App\RequestInterface;
use Magento\Framework\UrlInterface;
use Mobicommerce\Mobiapp\Helper\Image as ImageHelper;

class DesktopImage extends AbstractModifier
{
    public const FIELD_NAME = 'desktop_image';

    /**
     * DesktopImage constructor.
     *
     * @param RequestInterface $request
     * @param UrlInterface $urlBuilder
     * @param ImageHelper $imageHelper
     */
    public function __construct(
        RequestInterface $request,
        UrlInterface $urlBuilder,
        ImageHelper $imageHelper
    ) {
        parent::__construct($request, $urlBuilder);
        $this->imageHelper = $imageHelper;
    }

    /**
     * ModifyData
     *
     * @param array $data
     * @return array
     */
    public function modifyData(array $data)
    {
        $item = $data['item'] ?? false;
        if ($item) {
            $image = $data['item']->getData(self::FIELD_NAME);
            if ($image) {
                if ($this->imageHelper->isExist($image)) {
                    $stat = $this->imageHelper->getStat($image);
                    $mime = $this->imageHelper->getMimeType($image);

                    $pathInfo = $this->imageHelper->getPathInfo($image);
                    $filename = $pathInfo['filename'];
                    $data[$item->getId()][self::FIELD_NAME] = [];
                    $data[$item->getId()][self::FIELD_NAME][] = [
                        'name' => $filename,
                        'url' => $this->imageHelper->getFileUrl($image),
                        'size' => isset($stat) ? $stat['size'] : 0,
                        'type' => $mime
                    ];
                }
            }
        }
        
        return $data;
    }

    /**
     * ModifyMeta
     *
     * @param array $meta
     * @return array
     */
    public function modifyMeta(array $meta)
    {
        return $meta;
    }
}
