<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Ui\DataProvider\Image\Form\Modifier;

class RelationsModal extends AbstractModifier
{
    public const FORM_NAME = 'mobicommerce_image_form';

    /**
     * ModifyData
     *
     * @param array $data
     * @return array
     */
    public function modifyData(array $data)
    {
        return $data;
    }

    /**
     * ModifyMeta
     *
     * @param array $meta
     * @return array
     */
    public function modifyMeta(array $meta)
    {
        $id = $this->request->getParam('id', false);
        if (!$id) {
            return $meta;
        }
        
        $meta['general']['children']['relations_modal_button'] = [
            'arguments' => [
                'data' => [
                    'config' => [
                        'title' => __('Relations'),
                        'visible' => true,
                        'buttonClasses' => [
                            'mobicommerce_hidden_element' => true
                        ],
                        'componentType' => 'button',
                        'component' => 'Magento_Ui/js/form/components/button',
                        'actions' => [
                            [
                                'targetName' => implode('.', [
                                    static::FORM_NAME,
                                    static::FORM_NAME,
                                    'general',
                                    'relations_modal',
                                    'relations_fieldset_widget',
                                    'relations_listing_widget'
                                ]),
                                'actionName' => 'destroyInserted'
                            ],
                            [
                                'targetName' => 'ns='.static::FORM_NAME.', index = relations_modal',
                                'actionName' => 'openModal'
                            ],
                            [
                                'targetName' => implode('.', [
                                    static::FORM_NAME,
                                    static::FORM_NAME,
                                    'general',
                                    'relations_modal',
                                    'relations_fieldset_widget',
                                    'relations_listing_widget'
                                ]),
                                'actionName' => 'render'
                            ]
                        ]
                    ]
                ]
            ]
        ];

        $meta['general']['children']['relations_modal'] = [
            'arguments' => [
                'data' => [
                    'config' => [
                        'title' => __('Relations'),
                        'onCancel' => 'actionCancel',
                        'componentType' => 'modal',
                        'component' => 'Magento_Ui/js/modal/modal-component',
                        'options' => [
                            'buttons' => [
                                [
                                    'text' => 'Close',
                                    'class' => 'action-secondary',
                                    'actions' => ["actionCancel"]
                                ]
                            ]
                        ],
                        'valid' => false
                    ]
                ]
            ],
            'children' => [
                'relations_fieldset_widget' => [
                    'arguments' => [
                        'data' => [
                            'config' => [
                                'componentType' => 'fieldset',
                                'label' => __('Relations with Widgets'),
                                'collapsible' => true,
                                'opened' => false
                            ]
                        ]
                    ],
                    'children' => [
                        'relations_listing_widget' => [
                            'arguments' => [
                                'data' => [
                                    'config' => [
                                        'autoRender' => false,
                                        'componentType' => 'insertListing',
                                        'dataScope' => 'relations_listing_widget',
                                        'externalProvider' => implode('.', [
                                            'mobicommerce_image_relations_with_widgets_listing',
                                            'mobicommerce_image_relations_with_widgets_listing_data_source'
                                        ]),
                                        'ns' => 'mobicommerce_image_relations_with_widgets_listing',
                                        'render_url' => $this->urlBuilder->getUrl('mui/index/render'),
                                        'realTimeLink' => true,
                                        'behaviourType' => 'simple',
                                        'externalFilterMode' => true,
                                        'imports' => [
                                            'id' => '${ $.provider }:data.id',
                                            '__disableTmpl' => [
                                                'id' => false
                                            ],
                                        ],
                                        'exports' => [
                                            'id' => '${ $.externalProvider }:params.image_id',
                                            '__disableTmpl' => [
                                                'id' => false
                                            ],
                                        ]
                                    ]
                                ]
                            ]
                        ]
                    ]
                ]
            ]
        ];

        return $meta;
    }
}
