<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Ui\DataProvider\Image\Relations;

use Mobicommerce\Mobiapp\Model\ResourceModel\Widget\CollectionFactory;
use Magento\Ui\DataProvider\AbstractDataProvider;
use Magento\Framework\App\RequestInterface;

class WidgetDataProvider extends AbstractDataProvider
{
    /**
     * MobileImage constructor.
     *
     * @param string $name
     * @param string $primaryFieldName
     * @param string $requestFieldName
     * @param CollectionFactory $collectionFactory
     * @param RequestInterface $request
     * @param Array $addFieldStrategies
     * @param Array $addFilterStrategies
     * @param Array $meta
     * @param Array $data
     */
    public function __construct(
        $name,
        $primaryFieldName,
        $requestFieldName,
        CollectionFactory $collectionFactory,
        RequestInterface $request,
        array $addFieldStrategies = [],
        array $addFilterStrategies = [],
        array $meta = [],
        array $data = []
    ) {
        $this->collection = $collectionFactory->create();
        $this->request = $request;
        parent::__construct($name, $primaryFieldName, $requestFieldName, $meta, $data);
    }

    /**
     * GetData
     *
     * @return array
     */
    public function getData()
    {
        if (!$this->getCollection()->isLoaded()) {
            $imageId = $this->request->getParam('image_id', false);
            $this->addImageIdFilter($imageId);
            $this->getCollection()->load();
        }

        $items = $this->getCollection()->getData();

        $data = [
            'totalRecords' => $this->getCollection()->getSize(),
            'items' => array_values($items),
        ];

        return $data;
    }

    /**
     * GetCollection
     *
     * @return collection
     */
    public function getCollection()
    {
        /** @var Collection $collection */
        $collection = parent::getCollection();
        return $collection;
    }

    /**
     * AddImageIdFilter
     *
     * @param int $imageId
     * @return collection
     */
    public function addImageIdFilter($imageId)
    {
        $mappingTable = $this->collection->getTable('mobicommerce_widget_image_mapping');
        
        $this->collection->getSelect()->join(
            ['mapping' => $mappingTable],
            'main_table.id = mapping.widget_id',
            null
        );

        $this->collection->getSelect()->where('mapping.image_id = ?', $imageId);
        $this->collection->getSelect()->group('main_table.id');
    }
}
