<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Ui\DataProvider\PageBuilder\Form\Modifier;

use Magento\Framework\App\RequestInterface;
use Magento\Framework\UrlInterface;
use Magento\Framework\App\ResourceConnection;

class BindCategorySelection extends AbstractModifier
{
    /**
     * BindCategorySelection constructor.
     *
     * @param RequestInterface $request
     * @param UrlInterface $urlBuilder
     * @param ResourceConnection $resourceConnection
     */
    public function __construct(
        RequestInterface $request,
        UrlInterface $urlBuilder,
        ResourceConnection $resourceConnection
    ) {
        parent::__construct($request, $urlBuilder);
        $this->resourceConnection = $resourceConnection;
    }

    /**
     * ModifyData data source
     *
     * @param Array $data
     */
    public function modifyData(array $data)
    {
        $id = $this->request->getParam('id');

        if ($id) {
            $connection = $this->resourceConnection->getConnection();
            $table = $this->resourceConnection->getTableName('mobicommerce_page_builder_category_mapping');
            $select = $connection->select()
                ->from(
                    ['mapping' => $table]
                )->where('page_builder_id = ?', $id)
                ->reset(\Magento\Framework\DB\Select::COLUMNS)
                ->columns(['GROUP_CONCAT(category_id) AS db_category_ids']);
            $dbCategoryIds = $connection->fetchOne($select);
            if ($dbCategoryIds) {
                $data[$id]['category_ids'] = explode(',', $dbCategoryIds);
            }
        }

        return $data;
    }

    /**
     * ModifyMeta data source
     *
     * @param Array $meta
     */
    public function modifyMeta(array $meta)
    {
        return $meta;
    }
}
