<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Ui\DataProvider\PageBuilder\Form\Modifier;

use Magento\Framework\Phrase;
use Magento\Framework\UrlInterface;
use Magento\Ui\Component\DynamicRows;
use Magento\Ui\Component\Form\Element\DataType\Number;
use Magento\Ui\Component\Form\Element\DataType\Text;
use Magento\Ui\Component\Form\Element\Input;
use Magento\Ui\Component\Form\Field;
use Magento\Ui\Component\Form\Fieldset;

class Sections extends AbstractModifier
{
    public const FORM_NAME = 'mobicommerce_pagebuilder_form';

    /**
     * ModifyData data source
     *
     * @param Array $data
     */
    public function modifyData(array $data)
    {
        $item = $data['item'] ?? false;
        if ($item) {
            $data[$item->getId()]['sections_dynamic_rows']['sections_dynamic_rows'] = $item->getSectionsData();
        }
        
        return $data;
    }

    /**
     * ModifyMeta data source
     *
     * @param Array $meta
     */
    public function modifyMeta(array $meta)
    {
        if (!isset($meta['main_container'])) {
            $meta['main_container'] = [
                'arguments' => [
                    'data' => [
                        'config' => [
                            'componentType' => Fieldset::NAME,
                            'collapsible' => true,
                            'label' => __('Main Container'),
                            'sortOrder' => 100
                        ]
                    ]
                ],
            ];
        }
        $meta['main_container']['children']['button_set'] = [
            'arguments' => [
                'data' => [
                    'config' => [
                        'formElement' => 'container',
                        'componentType' => 'container',
                        'label' => false,
                        'content' => false,
                        'template' => 'ui/form/components/complex',
                        'sortOrder' => 30
                    ]
                ]
            ],
            'children' => [
                'button_section' => [
                    'arguments' => [
                        'data' => [
                            'config' => [
                                'formElement' => 'container',
                                'componentType' => 'container',
                                'component' => 'Magento_Ui/js/form/components/button',
                                'actions' => [
                                    [
                                        'targetName' => 'ns='.static::FORM_NAME.', index = section_listing_modal',
                                        'actionName' => 'openModal'
                                    ],
                                    [
                                        'targetName' => implode('.', [
                                            static::FORM_NAME,
                                            static::FORM_NAME,
                                            'main_container',
                                            'section_listing_modal',
                                            'mobicommerce_pagebuilder_section_listing'
                                        ]),
                                        'actionName' => 'render'
                                    ]
                                ],
                                'title' => __('Add Sections'),
                                'provider' => null
                            ]
                        ]
                    ]
                ]
            ]
        ];

        $meta['main_container']['children']['section_listing_modal'] = [
            'arguments' => [
                'data' => [
                    'config' => [
                        'componentType' => 'modal',
                        'dataScope' => '',
                        'options' => [
                            'title' => __('Add Sections'),
                            'buttons' => [
                                [
                                    'text' => __('Cancel'),
                                    'actions' => ['closeModal']
                                ],
                                [
                                    'text' => __('Add Selected Sections'),
                                    'class' => 'action-primary',
                                    'actions' => [
                                        [
                                            'targetName' => 'index = mobicommerce_pagebuilder_section_listing',
                                            'actionName' => 'save',
                                        ],
                                        'closeModal'
                                    ]
                                ]
                            ]
                        ]
                    ]
                ]
            ],
            'children' => [
                'mobicommerce_pagebuilder_section_listing' => [
                    'arguments' => [
                        'data' => [
                            'config' => [
                                'autoRender' => false,
                                'componentType' => 'insertListing',
                                'dataScope' => 'mobicommerce_pagebuilder_section_listing',
                                'externalProvider' => implode('.', [
                                    'mobicommerce_pagebuilder_section_listing',
                                    'mobicommerce_pagebuilder_section_listing_data_source'
                                ]),
                                'selectionsProvider' => implode('.', [
                                    'mobicommerce_pagebuilder_section_listing',
                                    'mobicommerce_pagebuilder_section_listing',
                                    'spinner_columns',
                                    'ids'
                                ]),
                                'ns' => 'mobicommerce_pagebuilder_section_listing',
                                'render_url' => $this->urlBuilder->getUrl('mui/index/render'),
                                'realTimeLink' => true,
                                'dataLinks' => [
                                    'imports' => false,
                                    'exports' => true
                                ],
                                'behaviourType' => 'simple',
                                'externalFilterMode' => true,
                                // 'imports' => [
                                //     'id' => '${ $.provider }:data.pagebuilder.current_id'
                                // ],
                                // 'exports' => [
                                //     'id' => '${ $.externalProvider }:params.current_id'
                                // ]
                            ]
                        ]
                    ]
                ]
            ]
        ];

        $meta['main_container']['children']['sections_dynamic_rows'] = [
            'arguments' => [
                'data' => [
                    'config' => [
                        'additionalClasses' => 'admin__field-wide',
                        'componentType' => DynamicRows::NAME,
                        'label' => null,
                        'columnsHeader' => false,
                        'columnsHeaderAfterRender' => true,
                        'renderDefaultRecord' => false,
                        'template' => 'ui/dynamic-rows/templates/grid',
                        'component' => 'Magento_Ui/js/dynamic-rows/dynamic-rows-grid',
                        'addButton' => false,
                        'recordTemplate' => 'record',
                        'dataScope' => 'sections_dynamic_rows',
                        'deleteButtonLabel' => __('Remove'),
                        'dataProvider' => 'data.mobicommerce_pagebuilder_section_listing',
                        'map' => [
                            'id' => 'id',
                            'name' => 'name',
                            'description' => 'description'
                        ],
                        'links' => [
                            'insertData' => '${ $.provider }:${ $.dataProvider }',
                            '__disableTmpl' => ['insertData' => false],
                        ],
                        'sortOrder' => 40,
                    ]
                ]
            ],
            'children' => [
                'record' => [
                    'arguments' => [
                        'data' => [
                            'config' => [
                                'componentType' => 'container',
                                'isTemplate' => true,
                                'is_collection' => true,
                                'component' => 'Magento_Ui/js/dynamic-rows/record',
                                'dataScope' => '',
                            ],
                        ],
                    ],
                    'children' => [
                        'id' => $this->getUrlColumn('id', false, __('ID'), 0),
                        'name' => $this->getTextColumn('name', false, __('Name for Admin'), 20),
                        'description' => $this->getTextColumn('description', false, __('Description for Admin'), 30),
                        'actionDelete' => [
                            'arguments' => [
                                'data' => [
                                    'config' => [
                                        'additionalClasses' => 'data-grid-actions-cell',
                                        'componentType' => 'actionDelete',
                                        'dataType' => Text::NAME,
                                        'label' => __('Actions'),
                                        'sortOrder' => 70,
                                        'fit' => true,
                                    ],
                                ],
                            ],
                        ],
                        'position' => [
                            'arguments' => [
                                'data' => [
                                    'config' => [
                                        'dataType' => Number::NAME,
                                        'formElement' => Input::NAME,
                                        'componentType' => Field::NAME,
                                        'dataScope' => 'position',
                                        'sortOrder' => 80,
                                        'visible' => false,
                                    ],
                                ],
                            ],
                        ],
                    ],
                ]
            ]
        ];

        return $meta;
    }

    /**
     * GetTextColumn data
     *
     * @param String $dataScope
     * @param String $fit
     * @param Phrase $label
     * @param String $sortOrder
     */
    protected function getTextColumn($dataScope, $fit, Phrase $label, $sortOrder)
    {
        $column = [
            'arguments' => [
                'data' => [
                    'config' => [
                        'componentType' => Field::NAME,
                        'formElement' => Input::NAME,
                        'elementTmpl' => 'ui/dynamic-rows/cells/text',
                        'component' => 'Magento_Ui/js/form/element/text',
                        'dataType' => Text::NAME,
                        'dataScope' => $dataScope,
                        'fit' => $fit,
                        'label' => $label,
                        'sortOrder' => $sortOrder,
                    ],
                ],
            ],
        ];

        return $column;
    }

    /**
     * GetUrl data
     *
     * @param String $dataScope
     * @param String $fit
     * @param Phrase $label
     * @param String $sortOrder
     */
    protected function getUrlColumn($dataScope, $fit, Phrase $label, $sortOrder)
    {
        $column = [
            'arguments' => [
                'data' => [
                    'config' => [
                        'componentType' => Field::NAME,
                        'formElement' => Input::NAME,
                        'elementTmpl' => 'Mobicommerce_Mobiapp/dynamic-rows/cells/url',
                        'component' => 'Mobicommerce_Mobiapp/js/dynamic-rows/form/element/url',
                        'dataType' => Text::NAME,
                        'dataScope' => $dataScope,
                        'fit' => $fit,
                        'label' => $label,
                        'sortOrder' => $sortOrder,
                        'href' => $this->urlBuilder->getUrl(
                            'mobicommerce/section/edit',
                            [
                                'id' => '__ID__'
                            ]
                        )
                    ],
                ],
            ],
        ];

        return $column;
    }
}
