<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Ui\DataProvider\PageBuilder\Form;

use Magento\Ui\DataProvider\AbstractDataProvider;
use Mobicommerce\Mobiapp\Model\Config\Source\MobicommercePageBuilder;

class PageBuilderOptionsDataProvider extends AbstractDataProvider
{
    /**
     * PageBuilderOptionsDataProvider constructor.
     *
     * @param ModalMetaProvider $modalMetaProvider
     * @param MobicommercePageBuilder $mobicommercePageBuilder
     */
    public function __construct(
        ModalMetaProvider $modalMetaProvider,
        MobicommercePageBuilder $mobicommercePageBuilder
    ) {
        $this->modalMetaProvider = $modalMetaProvider;
        $this->mobicommercePageBuilder = $mobicommercePageBuilder;
    }

    /**
     * GetOption data
     *
     * @param array $params
     */
    public function getOptions($params = [])
    {
        $prefix = $params['prefix'] ?? '';
        $scopeLabel = $params['scopeLabel'] ?? false;
        $required = $params['required'] ?? false;
        $formName = $params['form_name'] ?? false;

        $data = [
            'mobicommerce_button_click_field' => [
                'arguments' => [
                    'data' => [
                        'config' => [
                            'formElement' => 'input',
                            'componentType' => 'field',
                            'sortOrder' => 10,
                            'label' => false,
                            'visible' => true
                        ]
                    ]
                ]
            ]
        ];

        $fields = ['pwa', 'desktop', 'mobileapp'];
        $sortOrder = 30;
        foreach ($fields as $field) {
            $data[$prefix.$field.'_landing_page_id'] = [
                'arguments' => [
                    'data' => [
                        'config' => [
                            'formElement' => 'select',
                            'componentType' => 'field',
                            'sortOrder' => $sortOrder,
                            'label' => __(ucfirst($field) . ' Landing Page'),
                            'options' => $this->mobicommercePageBuilder->toOptionArray(),
                            'validation' => [
                                'required-entry' => $required
                            ]
                        ]
                    ]
                ]
            ];

            if ($scopeLabel) {
                $data[$prefix.$field.'_landing_page_id']['arguments']['data']['config']['scopeLabel'] = $scopeLabel;
            }

            $data['assign_pagebuilder_button_'.$field] = [
                'arguments' => [
                    'data' => [
                        'config' => [
                            'componentType' => 'button',
                            'component' => 'Mobicommerce_Mobiapp/js/pagebuilder/form/components/button',
                            'sortOrder' => $sortOrder+1,
                            'title' => __('Choose from Modal'),
                            'actions' => [
                                [
                                    'targetName' => 'ns='.$formName.', index = pagebuilder_modal',
                                    'actionName' => 'openModal'
                                ]
                            ],
                            'template' => 'Mobicommerce_Mobiapp/form/components/button/container',
                            'associatedInputField' => $prefix.$field.'_landing_page_id'
                        ]
                    ]
                ]
            ];

            $sortOrder += 10;
        }

        $data[ModalMetaProvider::DEFAULT_MODAL_NAME] = $this->modalMetaProvider->getModal();

        return $data;
    }
}
