<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Ui\DataProvider\PageBuilder\Relations;

use Mobicommerce\Mobiapp\Model\ResourceModel\Mobiapp\CollectionFactory;
use Magento\Ui\DataProvider\AbstractDataProvider;
use Magento\Framework\App\RequestInterface;

class MobiappHomepageDataProvider extends AbstractDataProvider
{

    /**
     * MobiappHomepageDataProvider constructor.
     *
     * @param string $name
     * @param string $primaryFieldName
     * @param string $requestFieldName
     * @param CollectionFactory $collectionFactory
     * @param RequestInterface $request
     * @param array $addFieldStrategies
     * @param array $addFilterStrategies
     * @param array $meta
     * @param array $data
     */
    public function __construct(
        $name,
        $primaryFieldName,
        $requestFieldName,
        CollectionFactory $collectionFactory,
        RequestInterface $request,
        array $addFieldStrategies = [],
        array $addFilterStrategies = [],
        array $meta = [],
        array $data = []
    ) {
        $this->collection = $collectionFactory->create();
        $this->request = $request;
        parent::__construct($name, $primaryFieldName, $requestFieldName, $meta, $data);
    }

    /**
     * GetData method
     */
    public function getData()
    {
        if (!$this->getCollection()->isLoaded()) {
            $pagebuilderId = $this->request->getParam('pagebuilder_id', false);
            $this->addpagebuilderIdFilter($pagebuilderId);
            $this->getCollection()->load();
        }

        $items = $this->getCollection()->getData();

        $data = [
            'totalRecords' => $this->getCollection()->getSize(),
            'items' => array_values($items),
        ];

        return $data;
    }

    /**
     * GetCollection method
     */
    public function getCollection()
    {
        /** @var Collection $collection */
        $collection = parent::getCollection();
        return $collection;
    }

    /**
     * AddpagebuilderIdFilter method
     *
     * @param int $pagebuilderId
     */
    public function addpagebuilderIdFilter($pagebuilderId)
    {
        $mappingTable = $this->collection->getTable('mobicommerce_mobiapp_homepage');
        
        $this->collection->getSelect()->join(
            ['mapping' => $mappingTable],
            'main_table.id = mapping.mobiapp_id',
            null
        );

        $this->collection->addFieldToFilter(
            [
                'mapping.pwa_landing_page_id',
                'mapping.desktop_landing_page_id',
                'mapping.mobileapp_landing_page_id'
            ],
            [
                ['eq' => $pagebuilderId],
                ['eq' => $pagebuilderId],
                ['eq' => $pagebuilderId],
            ]
        );
        
        $this->collection->getSelect()->group('main_table.id');
    }
}
