<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Ui\DataProvider\Productcollection\Form;

use Magento\Ui\DataProvider\AbstractDataProvider;
use Mobicommerce\Mobiapp\Model\Config\Source\MobicommerceProductCollection;
use Mobicommerce\Mobiapp\Block\Adminhtml\Deeplink\Container\Productcollection as ProductcollectionBlock;

class ModalMetaProvider extends AbstractDataProvider
{
    public const DEFAULT_MODAL_NAME = 'productcollection_modal';

    /**
     * ModalMetaProvider constructor.
     *
     * @param MobicommerceProductCollection $mobicommerceProductCollection
     * @param ProductcollectionBlock $productcollectionBlock
     */
    public function __construct(
        MobicommerceProductCollection $mobicommerceProductCollection,
        ProductcollectionBlock $productcollectionBlock
    ) {
        $this->mobicommerceProductCollection = $mobicommerceProductCollection;
        $this->productcollectionBlock = $productcollectionBlock;
    }

    /**
     * GetModal method
     */
    public function getModal()
    {
        $data = [
            'arguments' => [
                'data' => [
                    'config' => [
                        'onCancel' => 'actionCancel',
                        'componentType' => 'modal',
                        'component' => 'Mobicommerce_Mobiapp/js/productcollection/modal',
                        'options' => [
                            'buttons' => [
                                [
                                    'text' => 'Cancel',
                                    'class' => 'action-secondary',
                                    'actions' => ["actionCancel"]
                                ],
                                [
                                    'text' => 'Done',
                                    'class' => 'action-primary',
                                    'actions' => ["actionDone"]
                                ]
                            ]
                        ],
                        'valid' => false
                    ]
                ]
            ],
            'children' => [
                'general' => [
                    'arguments' => [
                        'data' => [
                            'config' => [
                                'componentType' => 'fieldset',
                                'label' => false
                            ]
                        ]
                    ],
                    'children' => [
                        'deeplink_productcollection_value' => [
                            'arguments' => [
                                'data' => [
                                    'config' => [
                                        'formElement' => 'select',
                                        'componentType' => 'field',
                                        'sortOrder' => 10,
                                        'label' => __('Value'),
                                        'options' => $this->mobicommerceProductCollection->toOptionArray(),
                                        'validation' => [
                                            'required-entry' => false
                                        ]
                                    ]
                                ]
                            ]
                        ],
                        'deeplink_container_productcollection' => [
                            'arguments' => [
                                'data' => [
                                    'config' => [
                                        'componentType' => 'container',
                                        'sortOrder' => 20,
                                    ]
                                ]
                            ],
                            'children' => [
                                'html_content' => [
                                    'arguments' => [
                                        'data' => [
                                            'config' => [
                                                'componentType' => 'htmlContent',
                                                'visible' => true,
                                                'additionalClasses' => implode(' ', [
                                                    'deeplink_containers',
                                                    'deeplink_container_productcollection'
                                                ])
                                            ]
                                        ],
                                        'block' => $this->productcollectionBlock
                                    ]
                                ]
                            ]
                        ]
                    ]
                ]
            ]
        ];

        return $data;
    }
}
