<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Ui\DataProvider\Productcollection\Preview\Filter;

use Magento\Framework\Data\Collection;
use Magento\Ui\DataProvider\AddFilterToCollectionInterface;
use Laminas\Uri\Uri as ZendUri;
use Mobicommerce\Mobiapp\Model\ProductcollectionRepository;

class ConditionsFilter implements AddFilterToCollectionInterface
{
    public const MATCHED_FLAG = 'matched_products';

    /**
     * @var Zend_Uri
     */
    private $zendUri;

    /**
     * ConditionsFilter constructor.
     *
     * @param ZendUri $zendUri
     * @param ProductcollectionRepository $productcollectionRepository
     * @param \Magento\Catalog\Model\Product\Visibility $productVisibility
     */
    public function __construct(
        ZendUri $zendUri,
        ProductcollectionRepository $productcollectionRepository,
        \Magento\Catalog\Model\Product\Visibility $productVisibility
    ) {
        $this->zendUri = $zendUri;
        $this->productcollectionRepository = $productcollectionRepository;
        $this->productVisibility = $productVisibility;
    }

    /**
     * AddFilter
     *
     * @param Collection $collection
     * @param string $field
     * @param array $condition
     */
    public function addFilter(Collection $collection, $field, $condition = null)
    {
        $collection->setVisibility($this->productVisibility->getVisibleInSiteIds());

        $matchedProductIds = $this->getMatchedProducts($condition['eq']);

        if ($matchedProductIds) {
            $collection->addIdFilter($matchedProductIds);
        } else {
            $collection->getSelect()->where('null');
        }

        $collection->setFlag(self::MATCHED_FLAG, $matchedProductIds);
    }

    /**
     * GetMatchedProducts data
     *
     * @param string $queryCondition
     */
    private function getMatchedProducts(string $queryCondition): array
    {
        $conditions = $this->parseQueryToArray($queryCondition);

        return $this->productcollectionRepository->getMatchedProductIds($conditions);
    }

    /**
     * ParseQueryToArray data
     *
     * @param string $query
     */
    private function parseQueryToArray(string $query): array
    {
        $this->zendUri->setQuery($query);
        return $this->zendUri->getQueryAsArray();
    }
}
