<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Ui\DataProvider\Productcollection\Relations;

use Mobicommerce\Mobiapp\Model\ResourceModel\PageBuilder\CollectionFactory;
use Magento\Ui\DataProvider\AbstractDataProvider;
use Magento\Framework\App\RequestInterface;

class PageBuilderDataProvider extends AbstractDataProvider
{

    /**
     * PageBuilderDataProvider constructor.
     *
     * @param string $name
     * @param string $primaryFieldName
     * @param string $requestFieldName
     * @param CollectionFactory $collectionFactory
     * @param RequestInterface $request
     * @param array $addFieldStrategies
     * @param array $addFilterStrategies
     * @param array $meta
     * @param array $data
     */
    public function __construct(
        $name,
        $primaryFieldName,
        $requestFieldName,
        CollectionFactory $collectionFactory,
        RequestInterface $request,
        array $addFieldStrategies = [],
        array $addFilterStrategies = [],
        array $meta = [],
        array $data = []
    ) {
        $this->collection = $collectionFactory->create();
        $this->request = $request;
        parent::__construct($name, $primaryFieldName, $requestFieldName, $meta, $data);
    }

    /**
     * GetData method
     */
    public function getData()
    {
        if (!$this->getCollection()->isLoaded()) {
            $productcollectionId = $this->request->getParam('productcollection_id', false);
            $this->addproductcollectionIdFilter($productcollectionId);
            $this->getCollection()->load();
        }

        $items = $this->getCollection()->getData();

        $data = [
            'totalRecords' => $this->getCollection()->getSize(),
            'items' => array_values($items),
        ];

        return $data;
    }

    /**
     * GetCollection method
     */
    public function getCollection()
    {
        /** @var Collection $collection */
        $collection = parent::getCollection();
        return $collection;
    }

    /**
     * AddproductcollectionIdFilter method
     *
     * @param int $productcollectionId
     */
    public function addproductcollectionIdFilter($productcollectionId)
    {
        $this->collection->addFieldToFilter('mobicommerce_product_collection_id', $productcollectionId);

        $this->collection->getSelect()->group('id');
    }
}
