<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Ui\DataProvider\Widget\Form\Modifier;

use Mobicommerce\Mobiapp\Ui\DataProvider\Deeplink\Form\ModalMetaProvider as DeeplinkModalMetaProvider;

class ImageMapping extends AbstractModifier
{
    public const WIDGET_TYPE = 'image_mapping';

    /**
     * ModifyData data source
     *
     * @param Array $data
     */
    public function modifyData(array $data)
    {
        $masterData = $data['master_data'];
        if ($masterData['type'] == self::WIDGET_TYPE) {
            $this->bindGenericDefaultData($data);

            $id = $this->request->getParam('id');
            $image = $data[$id]['general']['image'] ?? null;
            $imagemap = $data[$id]['general']['imagemap'] ?? null;
            if ($image) {
                if ($this->imageHelper->isExist($image)) {
                    $stat = $this->imageHelper->getStat($image);
                    $mime = $this->imageHelper->getMimeType($image);

                    $pathInfo = $this->imageHelper->getPathInfo($image);
                    $filename = $pathInfo['filename'];
                    $data[$id]['image_mapping']['image'] = [];
                    $data[$id]['image_mapping']['image'][] = [
                        'name' => $filename,
                        'url' => $this->imageHelper->getFileUrl($image),
                        'size' => isset($stat) ? $stat['size'] : 0,
                        'type' => $mime
                    ];
                }
            }

            if ($imagemap) {
                $data[$id]['image_mapping']['imagemap'] = $imagemap;
            }
        }
        
        return $data;
    }

    /**
     * ModifyMeta data source
     *
     * @param Array $meta
     */
    public function modifyMeta(array $meta)
    {
        $widgetType = $this->request->getParam('type', false);
        if ($widgetType == self::WIDGET_TYPE) {
            $dynamicRowsHiddenField = $this->deeplinkModalMetaProvider->getDynamicRowsHiddenField();

            $fieldName = DeeplinkModalMetaProvider::DEFAULT_DYNAMIC_ROWS_HIDDEN_FEILD_NAME;
            $meta['image_mapping']['children'][$fieldName] = $dynamicRowsHiddenField;
            
            $deeplinkModel = $this->deeplinkModalMetaProvider->getModal(false, true);
            $meta['image_mapping']['children'][DeeplinkModalMetaProvider::DEFAULT_MODAL_NAME] = $deeplinkModel;
        }
        
        return $meta;
    }
}
