<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Ui\DataProvider\Widget\Form\Modifier;

class RelationsModal extends AbstractModifier
{
    /**
     * ModifyData data source
     *
     * @param Array $data
     */
    public function modifyData(array $data)
    {
        return $data;
    }

    /**
     * GetUiComponentFormName data source
     */
    public function getUiComponentFormName()
    {
        $widgetType = $this->request->getParam('type', false);
        if (in_array($widgetType, ['html'])) {
            return 'mobicommerce_widget_form_' . $widgetType;
        }

        return 'mobicommerce_widget_form_' . $widgetType;
    }

    /**
     * GetFormName data source
     */
    public function getFormName()
    {
        $widgetType = $this->request->getParam('type', false);
        if (in_array($widgetType, ['html'])) {
            return implode('.', [
                'mobicommerce_widget_form_' . $widgetType,
                'mobicommerce_widget_form_' . $widgetType . '.general'
            ]);
        }

        return 'mobicommerce_widget_form_' . $widgetType . '.areas.general.general';
    }

    /**
     * GetIdLiteral data source
     */
    public function getIdLiteral()
    {
        
        $widgetType = $this->request->getParam('type', false);
        if (in_array($widgetType, ['html'])) {
            return '${ $.provider }:data.id';
        }

        return '${ $.provider }:data.general.id';
    }

    /**
     * ModifyMeta data source
     *
     * @param Array $meta
     */
    public function modifyMeta(array $meta)
    {
        $id = $this->request->getParam('id', false);
        if (!$id) {
            return $meta;
        }

        $meta['general']['children']['relations_modal_button'] = [
            'arguments' => [
                'data' => [
                    'config' => [
                        'title' => __('Relations'),
                        'visible' => true,
                        'buttonClasses' => [
                            'mobicommerce_hidden_element' => true
                        ],
                        'componentType' => 'button',
                        'component' => 'Magento_Ui/js/form/components/button',
                        'actions' => [
                            [
                                'targetName' => implode('.', [
                                    $this->getFormName(),
                                    'relations_modal',
                                    'relations_fieldset_pagebuilder',
                                    'relations_listing_pagebuilder'
                                ]),
                                'actionName' => 'destroyInserted'
                            ],
                            [
                                'targetName' => 'ns='.$this->getUiComponentFormName().', index = relations_modal',
                                'actionName' => 'openModal'
                            ],
                            [
                                'targetName' => implode('.', [
                                    $this->getFormName(),
                                    'relations_modal',
                                    'relations_fieldset_pagebuilder',
                                    'relations_listing_pagebuilder'
                                ]),
                                'actionName' => 'render'
                            ]
                        ]
                    ]
                ]
            ]
        ];

        $meta['general']['children']['relations_modal'] = [
            'arguments' => [
                'data' => [
                    'config' => [
                        'title' => __('Relations'),
                        'onCancel' => 'actionCancel',
                        'componentType' => 'modal',
                        'component' => 'Magento_Ui/js/modal/modal-component',
                        'options' => [
                            'buttons' => [
                                [
                                    'text' => 'Close',
                                    'class' => 'action-secondary',
                                    'actions' => ["actionCancel"]
                                ]
                            ]
                        ],
                        'valid' => false
                    ]
                ]
            ],
            'children' => [
                'relations_fieldset_pagebuilder' => [
                    'arguments' => [
                        'data' => [
                            'config' => [
                                'componentType' => 'fieldset',
                                'label' => __('Relations with Page Builder'),
                                'collapsible' => true,
                                'opened' => false
                            ]
                        ]
                    ],
                    'children' => [
                        'relations_listing_pagebuilder' => [
                            'arguments' => [
                                'data' => [
                                    'config' => [
                                        'autoRender' => false,
                                        'componentType' => 'insertListing',
                                        'dataScope' => 'relations_listing_pagebuilder',
                                        'externalProvider' => implode('.', [
                                            'mobicommerce_widget_relations_with_pagebuilder_listing',
                                            'mobicommerce_widget_relations_with_pagebuilder_listing_data_source'
                                        ]),
                                        'ns' => 'mobicommerce_widget_relations_with_pagebuilder_listing',
                                        'render_url' => $this->urlBuilder->getUrl('mui/index/render'),
                                        'realTimeLink' => true,
                                        'behaviourType' => 'simple',
                                        'externalFilterMode' => true,
                                        'imports' => [
                                            'id' => $this->getIdLiteral(),
                                            '__disableTmpl' => [
                                                'id' => false
                                            ],
                                        ],
                                        'exports' => [
                                            'id' => '${ $.externalProvider }:params.widget_id',
                                            '__disableTmpl' => [
                                                'id' => false
                                            ],
                                        ]
                                    ]
                                ]
                            ]
                        ]
                    ]
                ]
            ]
        ];

        return $meta;
    }
}
