<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Ui\DataProvider\Widget\Form;

use Magento\Framework\UrlInterface;
use Magento\Ui\Component\DynamicRows;
use Magento\Ui\Component\Form\Element\DataType\Number;
use Magento\Ui\Component\Form\Element\DataType\Text;
use Magento\Ui\Component\Form\Element\Input;
use Magento\Ui\Component\Form\Element\Select;
use Magento\Ui\Component\Form\Field;
use Magento\Ui\Component\Form\Fieldset;
use Magento\Framework\Phrase;
use Magento\Framework\App\ResourceConnection;
use Magento\Framework\App\RequestInterface;

class SeoWidgetMetaProvider
{
    /**
     * SeoWidgetMetaProvider constructor.
     *
     * @param UrlInterface $urlBuilder
     */
    public function __construct(
        UrlInterface $urlBuilder
    ) {
        $this->urlBuilder = $urlBuilder;
    }

     /**
      * GetElement data
      *
      * @param array $meta
      * @param array $params
      */
    public function getElement(&$meta, $params = [])
    {
        $prefix = $params['prefix'] ?? '';
        $scopeLabel = $params['scopeLabel'] ?? false;
        $required = $params['required'] ?? false;
        $formName = $params['form_name'] ?? false;

        $meta['button_set'] = [
            'arguments' => [
                'data' => [
                    'config' => [
                        'formElement' => 'container',
                        'componentType' => 'container',
                        'label' => __('SEO Information'),
                        'content' => __('Add HTML and Link Builder type of widgets here'),
                        'template' => 'ui/form/components/complex',
                        'sortOrder' => 200
                    ]
                ]
            ],
            'children' => [
                'button_widget' => [
                    'arguments' => [
                        'data' => [
                            'config' => [
                                'formElement' => 'container',
                                'componentType' => 'container',
                                'component' => 'Magento_Ui/js/form/components/button',
                                'actions' => [
                                    [
                                        'targetName' => 'ns='.$formName.', index = widget_listing_modal',
                                        'actionName' => 'openModal'
                                    ],
                                    [
                                        'targetName' => implode('.', [
                                            $formName,
                                            $formName,
                                            'mobicommerce',
                                            'widget_listing_modal',
                                            'mobicommerce_seo_widget_listing'
                                        ]),
                                        'actionName' => 'render'
                                    ]
                                ],
                                'title' => __('Add Widgets'),
                                'provider' => null
                            ]
                        ]
                    ]
                ]
            ]
        ];

        $meta['widget_listing_modal'] = [
            'arguments' => [
                'data' => [
                    'config' => [
                        'componentType' => 'modal',
                        'dataScope' => '',
                        'options' => [
                            'title' => __('Add Widgets'),
                            'buttons' => [
                                [
                                    'text' => __('Cancel'),
                                    'actions' => ['closeModal']
                                ],
                                [
                                    'text' => __('Add Selected Widgets'),
                                    'class' => 'action-primary',
                                    'actions' => [
                                        [
                                            'targetName' => 'index = mobicommerce_seo_widget_listing',
                                            'actionName' => 'save',
                                        ],
                                        'closeModal'
                                    ]
                                ]
                            ]
                        ]
                    ]
                ]
            ],
            'children' => [
                'mobicommerce_seo_widget_listing' => [
                    'arguments' => [
                        'data' => [
                            'config' => [
                                'autoRender' => false,
                                'componentType' => 'insertListing',
                                'dataScope' => 'mobicommerce_seo_widget_listing',
                                'externalProvider' => implode('.', [
                                    'mobicommerce_seo_widget_listing',
                                    'mobicommerce_seo_widget_listing_data_source'
                                ]),
                                'selectionsProvider' => implode('.', [
                                    'mobicommerce_seo_widget_listing',
                                    'mobicommerce_seo_widget_listing',
                                    'widget_columns',
                                    'ids'
                                ]),
                                'ns' => 'mobicommerce_seo_widget_listing',
                                'render_url' => $this->urlBuilder->getUrl('mui/index/render'),
                                'realTimeLink' => true,
                                'dataLinks' => [
                                    'imports' => false,
                                    'exports' => true
                                ],
                                'behaviourType' => 'simple',
                                'externalFilterMode' => true,
                                // 'imports' => [
                                //     'id' => '${ $.provider }:data.pagebuilder.current_id'
                                // ],
                                // 'exports' => [
                                //     'id' => '${ $.externalProvider }:params.current_id'
                                // ]
                            ]
                        ]
                    ]
                ]
            ]
        ];

        $meta['mobicommerce_seo_widgets_dynamic_rows'] = [
            'arguments' => [
                'data' => [
                    'config' => [
                        'additionalClasses' => 'admin__field-wide',
                        'componentType' => DynamicRows::NAME,
                        'label' => null,
                        'columnsHeader' => false,
                        'columnsHeaderAfterRender' => true,
                        'renderDefaultRecord' => false,
                        'template' => 'ui/dynamic-rows/templates/grid',
                        'component' => 'Magento_Ui/js/dynamic-rows/dynamic-rows-grid',
                        'addButton' => false,
                        'recordTemplate' => 'record',
                        'dataScope' => 'mobicommerce_seo_widgets_dynamic_rows',
                        'deleteButtonLabel' => __('Remove'),
                        'dataProvider' => 'data.mobicommerce_seo_widget_listing',
                        'map' => [
                            'id' => 'id',
                            //'type' => 'type',
                            'name' => 'name',
                            'description' => 'description'
                        ],
                        'links' => [
                            'insertData' => '${ $.provider }:${ $.dataProvider }',
                            '__disableTmpl' => ['insertData' => false],
                        ],
                        'sortOrder' => 201,
                    ]
                ]
            ],
            'children' => [
                'record' => [
                    'arguments' => [
                        'data' => [
                            'config' => [
                                'componentType' => 'container',
                                'isTemplate' => true,
                                'is_collection' => true,
                                'component' => 'Magento_Ui/js/dynamic-rows/record',
                                'dataScope' => '',
                            ],
                        ],
                    ],
                    'children' => [
                        'id' => $this->getUrlColumn('id', false, __('ID'), 0),
                        //'type' => $this->getSelectColumn('type', false, __('Type'), 10),
                        'name' => $this->getTextColumn('name', false, __('Name for Admin'), 20),
                        'description' => $this->getTextColumn('description', false, __('Description for Admin'), 30),
                        'actionDelete' => [
                            'arguments' => [
                                'data' => [
                                    'config' => [
                                        'additionalClasses' => 'data-grid-actions-cell',
                                        'componentType' => 'actionDelete',
                                        'dataType' => Text::NAME,
                                        'label' => __('Actions'),
                                        'sortOrder' => 70,
                                        'fit' => true,
                                    ],
                                ],
                            ],
                        ],
                        'position' => [
                            'arguments' => [
                                'data' => [
                                    'config' => [
                                        'dataType' => Number::NAME,
                                        'formElement' => Input::NAME,
                                        'componentType' => Field::NAME,
                                        'dataScope' => 'position',
                                        'sortOrder' => 80,
                                        'visible' => false,
                                    ],
                                ],
                            ],
                        ],
                    ],
                ]
            ]
        ];

        return $meta;
    }

     /**
      * GetTextColumn data
      *
      * @param String $dataScope
      * @param String $fit
      * @param Phrase $label
      * @param String $sortOrder
      */
    protected function getTextColumn($dataScope, $fit, Phrase $label, $sortOrder)
    {
        $column = [
            'arguments' => [
                'data' => [
                    'config' => [
                        'componentType' => Field::NAME,
                        'formElement' => Input::NAME,
                        'elementTmpl' => 'ui/dynamic-rows/cells/text',
                        'component' => 'Magento_Ui/js/form/element/text',
                        'dataType' => Text::NAME,
                        'dataScope' => $dataScope,
                        'fit' => $fit,
                        'label' => $label,
                        'sortOrder' => $sortOrder,
                    ],
                ],
            ],
        ];

        return $column;
    }

     /**
      * GetUrlColumn data
      *
      * @param String $dataScope
      * @param String $fit
      * @param Phrase $label
      * @param String $sortOrder
      */
    protected function getUrlColumn($dataScope, $fit, Phrase $label, $sortOrder)
    {
        $column = [
            'arguments' => [
                'data' => [
                    'config' => [
                        'componentType' => Field::NAME,
                        'formElement' => Input::NAME,
                        'elementTmpl' => 'Mobicommerce_Mobiapp/dynamic-rows/cells/url',
                        'component' => 'Mobicommerce_Mobiapp/js/dynamic-rows/form/element/url',
                        'dataType' => Text::NAME,
                        'dataScope' => $dataScope,
                        'fit' => $fit,
                        'label' => $label,
                        'sortOrder' => $sortOrder,
                        'href' => $this->urlBuilder->getUrl(
                            'mobicommerce/widget/edit',
                            [
                                'id' => '__ID__'
                            ]
                        )
                    ],
                ],
            ],
        ];

        return $column;
    }
}
