<?php
/**
 * Mobicommerce
 *
 * Copyright (C) 2021 Mobicommerce <info@mobicommerce.net>
 *
 * @category Mobicommerce
 * @package Mobicommerce_Mobiapp
 * @copyright Copyright (c) 2021 Mobicommerce (http://www.mobicommerce.net/)
 * @license http://opensource.org/licenses/gpl-3.0.html GNU General Public License,version 3 (GPL-3.0)
 * @author Mobicommerce <info@mobicommerce.net>
 */

namespace Mobicommerce\Mobiapp\Ui\DataProvider\Widget\Relations;

use Mobicommerce\Mobiapp\Model\ResourceModel\PageBuilder\CollectionFactory;
use Magento\Ui\DataProvider\AbstractDataProvider;
use Magento\Framework\App\RequestInterface;

class PageBuilderDataProvider extends AbstractDataProvider
{
    /**
     * PageBuilderDataProvider constructor.
     *
     * @param string $name
     * @param string $primaryFieldName
     * @param string $requestFieldName
     * @param CollectionFactory $collectionFactory
     * @param RequestInterface $request
     * @param array $addFieldStrategies
     * @param array $addFilterStrategies
     * @param array $meta
     * @param array $data
     */
    public function __construct(
        $name,
        $primaryFieldName,
        $requestFieldName,
        CollectionFactory $collectionFactory,
        RequestInterface $request,
        array $addFieldStrategies = [],
        array $addFilterStrategies = [],
        array $meta = [],
        array $data = []
    ) {
        $this->collection = $collectionFactory->create();
        $this->request = $request;
        parent::__construct($name, $primaryFieldName, $requestFieldName, $meta, $data);
    }

    /**
     * GetData method
     */
    public function getData()
    {
        if (!$this->getCollection()->isLoaded()) {
            $widgetId = $this->request->getParam('widget_id', false);
            $this->addWidgetIdFilter($widgetId);
            $this->getCollection()->load();
        }

        $items = $this->getCollection()->getData();

        $data = [
            'totalRecords' => $this->getCollection()->getSize(),
            'items' => array_values($items),
        ];

        return $data;
    }

    /**
     * GetCollection method
     */
    public function getCollection()
    {
        /** @var Collection $collection */
        $collection = parent::getCollection();
        return $collection;
    }

    /**
     * AddWidgetIdFilter method
     *
     * @param int $widgetId
     */
    public function addWidgetIdFilter($widgetId)
    {
        $sectionMappingTable = $this->collection->getTable('mobicommerce_page_builder_section_mapping');
        $widgetMappingTable = $this->collection->getTable('mobicommerce_section_widget_mapping');
        
        $this->collection->getSelect()->join(
            ['section_mapping' => $sectionMappingTable],
            'main_table.id = section_mapping.page_builder_id',
            null
        );

        $this->collection->getSelect()->join(
            ['widget_mapping' => $widgetMappingTable],
            'section_mapping.section_id = widget_mapping.section_id',
            null
        );

        $linkWidgetMappingTable = $this->collection->getTable('mobicommerce_page_builder_link_builder_widget_mapping');
        
        $this->collection->getSelect()->join(
            ['link_widget_mapping' => $linkWidgetMappingTable],
            'main_table.id = link_widget_mapping.page_builder_id',
            null
        );
        
        $this->collection->getSelect()->where('widget_mapping.widget_id = ?', $widgetId);

        $this->collection->getSelect()->orWhere('link_widget_mapping.link_builder_widget_id = ?', $widgetId);

        $this->collection->getSelect()->group('main_table.id');
    }
}
