/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */

define([
        'underscore',
        'jquery',
        'Magento_Ui/js/modal/modal-component',
        'uiRegistry'
    ],
    function (_, $, Modal, uiRegistry) {
        'use strict';

        const SEPARATOR = "|";

        return Modal.extend(
            {
                /**
                 * Initializes modal on opened function
                 */
                initModal: function () {
                    this.options.opened = this.onOpened.bind(this);
                    this.options.closed = this.onClosed.bind(this);
                    this._super();

                    this.hideDefaultInvisibleElements();
                },

                getDefaultFieldsToHide: function() {
                    return [
                        'deeplink_category_value',
                        'deeplink_category_force_navigate_to_product_list',
                        'deeplink_product_value',
                        'deeplink_cmspage_value',
                        'deeplink_phone',
                        'deeplink_email',
                        'deeplink_external_url'
                    ];
                },

                hideDefaultInvisibleElements: function() {
                    var self = this;
                    $(self.getDefaultFieldsToHide()).each(function(k, field) {
                        self.hideSpecificField(field);
                    });
                },

                hideSpecificField: function(field) {
                    var self = this;
                    if (uiRegistry.get("index = " + field)) {
                        uiRegistry.get("index = " + field).visible(false);
                    } else {
                        setTimeout(function(){
                            self.hideSpecificField(field);
                        }, 800);
                    }
                },

                getExistingDeeplinkValue: function() {
                    return uiRegistry.get("index = deeplink").value();
                },

                setDefaultSelectedDeeplink: function() {
                    var value = this.getExistingDeeplinkValue();

                    if (value) {
                        var exploded = value.split(SEPARATOR);
                        if (exploded) {
                            var deeplink_type = exploded[0];
                            var deeplink_value = exploded[1];

                            uiRegistry.get("index = deeplink_type").value(deeplink_type);
                            var subField = this.getSubField(deeplink_type);
                            if (subField) {
                                uiRegistry.get('index = ' + subField).value(deeplink_value);
                            }
                        }
                    } else {
                        uiRegistry.get("index = deeplink_type").value('');
                    }
                },

                getSubField: function(deeplink_type) {
                    var subField = false;
                    switch (deeplink_type) {
                        case 'category':
                            subField = 'deeplink_category_value';
                            break;
                        case 'product':
                            subField = 'deeplink_product_value';
                            break;
                        case 'cms':
                            subField = 'deeplink_cmspage_value';
                            break;
                        case 'phone':
                            subField = 'deeplink_phone';
                            break;
                        case 'email':
                            subField = 'deeplink_email';
                            break;
                        case 'external_url':
                            subField = 'deeplink_external_url';
                            break;
                        case 'qr_scan':
                            break;
                        default:
                            break;
                    }

                    return subField;
                },

                /**
                 * Once the modal is opened it hides the X
                 */
                onOpened: function () {
                    this.setDefaultSelectedDeeplink();
                    //$('.modal-header button.action-primary').attr('disabled', true);
                },

                /**
                 * Once the modal is closed it hides the X
                 */
                onClosed: function () {
                    //uiRegistry.get('index = deeplink_type').value('').visible(false);
                },

                actionDone: function() {
                    this.valid = true;
                    this.elems().forEach(this.validate, this);

                    if (this.valid) {
                        this.closeModal();
                        this.bindDeeplinkMainFieldValue();
                    }
                },

                getDeeplinkModalSelectedValue: function() {
                    var deeplink_type = uiRegistry.get("index = deeplink_type").value();
                    if (deeplink_type) {
                        var value = this.getSelectedValue(deeplink_type);
                        return (deeplink_type + SEPARATOR + value);
                    } else {
                        return '';
                    }
                },

                getSelectedValue: function(deeplink_type) {
                    var value = "";
                    switch (deeplink_type) {
                        case 'category':
                            value = uiRegistry.get('index = deeplink_category_value').value();
                            break;
                        case 'product':
                            value = uiRegistry.get('index = deeplink_product_value').value();
                            break;
                        case 'cms':
                            value = uiRegistry.get('index = deeplink_cmspage_value').value();
                            break;
                        case 'phone':
                            value = uiRegistry.get('index = deeplink_phone').value();
                            break;
                        case 'email':
                            value = uiRegistry.get('index = deeplink_email').value();
                            break;
                        case 'external_url':
                            value = uiRegistry.get('index = deeplink_external_url').value();
                            break;
                        case 'qr_scan':
                            value = "1";
                            break;
                        default:
                            break;
                    }

                    return value;
                },

                bindDeeplinkMainFieldValue: function() {
                    var deeplinkValue = this.getDeeplinkModalSelectedValue();
                    uiRegistry.get("index = deeplink").value(deeplinkValue);
                }
            }
        );
    }
);
