<?php
/**
 * @author Mobicommerce Team
 * @copyright Copyright (c) 2018 Mobicommerce (https://www.Mobicommerce.com)
 * @package Mobicommerce_BookingUi
 */

namespace Mobicommerce\PwaSitemap\Plugin;

use Magento\Store\Model\ScopeInterface;

class Sitemap
{
    /**
     * @param Context $context
     */

    const MOBI_HEADLESS_ENABLE = 'mobi_basic/headless/is_enable';
    const MOBI_HEADLESS_URL = 'mobi_basic/headless/frontend_url';
    public function __construct(
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        \Magento\Framework\HTTP\Client\Curl $curl
    ) {
         $this->scopeConfig = $scopeConfig;
         $this->curl = $curl;
    }

    public function getHeadlessUrl()
    {
        $customEmailUrl = $this->scopeConfig->getValue(
            self::MOBI_HEADLESS_URL
        );

        return $customEmailUrl;
    }

    public function getBackendUrl()
    {
        $webUrls = $this->scopeConfig->getValue(
            \Magento\Framework\UrlInterface::URL_TYPE_WEB
        );
        
        return $webUrls['unsecure']['base_web_url'];
    }

    public function isEnable()
    {
        $is_enable = $this->scopeConfig->getValue(
            self::MOBI_HEADLESS_ENABLE,
            ScopeInterface::SCOPE_STORE
        );
        if ($is_enable) {
            return true;
        } else {
            return false;
        }
        return $is_enable;
    }
    /**
     * @param \Magento\Framework\Event\Observer $observer
     */
    public function afterGenerateXml(
        \Magento\Sitemap\Model\Sitemap $sitemap,
        \Magento\Sitemap\Model\Sitemap $result
    ) {
        
        if (!$this->isEnable() || empty($this->getHeadlessUrl())) {
            return $result;
        }
        $curlData=[];
        $curlData['url'] = $sitemap->getSitemapUrl($sitemap->getSitemapPath(), $sitemap->getSitemapFilename());
        $curlData['path'] = $sitemap->getSitemapPath();
        $curlData['filename'] = $sitemap->getSitemapFilename();
        $curlData['headlessUrl'] = $this->getHeadlessUrl();
        $curlData['backendUrl'] = $this->getBackendUrl();
        // echo "<pre>";
        // print_r($curlData);
        $url = rtrim($this->getHeadlessUrl(), '/') .'/generateXml.php';
        $this->curl->setOption(CURLOPT_RETURNTRANSFER, true);
        $this->curl->setOption(CURLOPT_HEADER, false);
       // $this->curl->setOption(CURLOPT_NOBODY, true);
        $this->curl->post($url, $curlData);
        $res = $this->curl->getBody();
        // print_r($res);exit;
        return $result;
    }
}
